checkRequire("Lua_EventOwner");
Lua_DisplayObject = class("Lua_DisplayObject", Lua_EventOwner, 1);
function Lua_DisplayObject:ctor(p, skin, frameBuild)
	self:superCall("ctor");

	self.parent = p;
	self.content = UICreate.createGameObject(p, 0, 0, 0);
	self.content.name = self.classname;

	self.isActive = true;
	self.depth = 1;
	self.skinName = skin;

	self.list = Array();
	self.delayCallList = Array();
	self.exceptionDic = {};

	self:addExceptions();

	self.frameBuild = frameBuild == nil and false or frameBuild;
	if self.frameBuild == true and self.skinName ~= nil then
		self.skinBuilded = false;
		self.skinTable = checkRequire(self.skinName);
		self.conTable = {};
		self.conTable["content"] = self["content"];
		self.itemIndex = 1;
		Lua_CommonUtil.addTimer("BuildItem", 0.001, self, self.onBuildingItem);
	else
		self.skinBuilded = true;
		self:buildShowItem();
	end
end

function Lua_DisplayObject:addExceptions()
	self.exceptionDic["onBuildingItem"] = 1;
	self.exceptionDic["checkSaveParam"] = 1;
	self.exceptionDic["saveFunKey"] = 1;
	self.exceptionDic["saveParam"] = 1;
	self.exceptionDic["classname"] = 1;
	self.exceptionDic["super"] = 1;
	self.exceptionDic["setLocation"] = 1;
	self.exceptionDic["addExceptions"] = 1;
	self.exceptionDic["saveParamKey"] = 1;
	self.exceptionDic["superCall"] = 1;
	self.exceptionDic["dispose"] = 1;
end

function Lua_DisplayObject:saveParamKey(key, val)
	self.delayCallList:add({funStr=key, param=val, isFun=false});
end

function Lua_DisplayObject:saveParam(...)
	if self.curKey == nil then
		return 0;
	end

	local params = {};
	params[1], params[2], params[3], params[4], params[5], params[6], params[7], params[8],
	params[9], params[10], params[11] = ...;
	self.delayCallList:add({funStr = self.curKey, param = params, isFun = true});
	self.curKey = nil;
end

function Lua_DisplayObject:saveFunKey(key)
	self.curKey = key;
end

function Lua_DisplayObject:checkSaveParam(key)
	if self.skinBuilded == nil or self.exceptionDic[key] == 1 then
		return false;
	end
	return self.skinBuilded == false;
end

function Lua_DisplayObject:onBuildingItem()
	if self.skinBuilded == true or self.isDispose_3 == true then
		Lua_CommonUtil.removeTimer(self, self.onBuildingItem);
		return;
	end

	local isEnd = false;
	local st = getTime();
	while getTime() - st < 0.005 do
		isEnd = Lua_WindowUtil.buildFromSkinEachFrame(self, self.skinTable, self.conTable, self.itemIndex);
		if isEnd == true then
			break;
		else
			self.itemIndex = 1 + self.itemIndex;
		end
	end

	if isEnd == true then
		self.conTable = nil;
		self.skinTable = nil;
		Lua_CommonUtil.removeTimer(self, self.onBuildingItem);
		self.skinBuilded = true;
		self:buildShowItem();
		local len = self.delayCallList:getSize();
		for i = 1, len do
			local fitem = self.delayCallList[i];
			if fitem.isFun == true then
				local f = self[fitem.funStr];
				local params = fitem.param;
				f(self, params[1], params[2], params[3], params[4], params[5], params[6], params[7], params[8],
					params[9], params[10], params[11]);
			else
				self[fitem.funStr] = fitem.param;
			end
			
		end
		self.delayCallList:clear();
	end
end

function Lua_DisplayObject:setParent(p)
	self.parent = p;
	self.content.transform.parent = p.transform;
end

function Lua_DisplayObject:buildFromSetSkin(skinName, itemName)
	local skinTable = checkRequire(skinName);
	local posState = nil;
	for i,v in ipairs(skinTable) do
		if v.type == 6 and v.name == itemName then
			posState = v;
			break;
		end
	end

	if posState ~= nil then
		Lua_WindowUtil.buildFromSkin(self, posState.target_item, self.content);
		self:setLocation(posState.x, posState.y, 0);
	end
end

function Lua_DisplayObject:buildFromSkin()
	if self.frameBuild ~= true and self.skinName ~= nil then
		Lua_WindowUtil.buildFromSkin(self, self.skinName, self.content);
	end
end

function Lua_DisplayObject:buildShowItem()
	self:buildFromSkin();
end

function Lua_DisplayObject:setLocation(posX, posY, posZ)
	posX = posX == nil and 0 or posX;
	posY = posY == nil and 0 or posY;
	posZ = posZ == nil and 0 or posZ;
	LuaUtil.setObjPos(self.content, posX, posY, posZ);
end

function Lua_DisplayObject.Get:x()
	return self.content.transform.localPosition.x;
end

function Lua_DisplayObject.Get:y()
	return self.content.transform.localPosition.y;
end

function Lua_DisplayObject:getLocation()
	if self.content.transform ~= nil then
		return self.content.transform.localPosition;
	end
	return nil;
end

function Lua_DisplayObject:setEnable(val)
	self.isActive = val;
	self.content:SetActive(val);
end

function Lua_DisplayObject:setScale(sx, sy)
	-- self.content.transform.localScale = Vector3(sx, sy, 1);
	LuaUtil.setObjScale(self.content, sx, sy, 1);
end

function Lua_DisplayObject.Get:mainContent()
	return self.content;
end

function Lua_DisplayObject:setDepth(val)
	self.depth = val;
end

function Lua_DisplayObject:dispose()
	Lua_CommonUtil.removeTimer(self, self.onBuildingItem);
	Lua_EventOwner.dispose(self);
	if self.isDispose_3 ~= true then
		self.isDispose_3 = true;
		if self.content ~= nil and IsNil(self.content) == false then
			WindowMananger.getInstance():returnToPool(self.content.transform);
			UnityEngine.GameObject.Destroy(self.content);
			self.content = nil;
		end
	end
end