Lua_DragContainer = class("Lua_DragContainer", Lua_DisplayObject);
function Lua_DragContainer:ctor(p, ltype, vsize)
	self.ltype = ltype;
	self.vsize = vsize;
	self.maxSize = 0;
	self.minX = 0;
	self.minY = 0;
	self.maxX = 0;
	self.maxY = 0;
	self.cminX = 0;
	self.cminY = 0;
	self.cmaxX = 0;
	self.cmaxY = 0;
	self.childrenList = Array();
	self.canDrag = true;
	self._isClick = false;
	self.startMouse = -1;
	self.startContainer = -1;
	self.offsetY = 0;
	self.offsetX = 0;
	self:superCall("ctor", p);
	self.addNum = 0;
	self.checkSizeDrag = false;
end

function Lua_DragContainer:buildShowItem()
	self.content.name = "Lua_DragContainer";
	self.sub = UICreate.createGameObject(self.content, 0, 0, 0);
	self.sub.name = "sub";

	self.uiPanel = self.content:AddComponent(typeof(UIPanel));
	self.uiPanel.cullWhileDragging = false;
	self.uiPanel.softBorderPadding = false;

	self.uiPanel.clipSoftness = Vector2(0, 0);
	self.uiPanel.clipOffset = Vector2(0, 0);
	self.uiPanel.anchorOffset = false;
	self.uiPanel.widgetsAreStatic = false;
	self.uiPanel.baseClipRegion = self.vsize;
	self.uiPanel.clipping = UIDrawCall.Clipping.SoftClip;

	self.bg = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_black_50", self.vsize.x, self.vsize.y, 0, 0);
	self.bg.name = "bg";
	self.bg.alpha = 0.01;
	self.bg:SetDimensions(self.vsize.z, self.vsize.w);
	self.bg:setDepth(0);
	self.bg:addClickFuntion(self, self.onMouseDownHandle);
	self.bg:addMouseUpFuntion(self, self.onMouseUpHandle);

	self:addTimer("thunderStrikeExitMapCD",0.2,self,self.onDelayUpdateDepth,nil,-1);
	LuaUtil.updateWindowDepth(nil);
end

function Lua_DragContainer:onDelayUpdateDepth()
	LuaUtil.updateWindowDepth(nil);
	Lua_CommonUtil.removeTimer(self, self.onDelayUpdateDepth);
end

function Lua_DragContainer:removeAllChildren()
	local len = self.childrenList:getSize();
	for i = 1, len do
		self.childrenList[i]:dispose();
	end
	self.childrenList:clear();
end

function Lua_DragContainer:updateClipRegion(vsize)
	self.vsize = vsize;
	self.bg:setLocation(vsize.x, vsize.y, 0);
	self.bg:SetDimensions(vsize.z, vsize.w);
	if self.uiPanel ~= nil then
		 self.uiPanel.baseClipRegion = vsize;
	end
end

function Lua_DragContainer:getChildrenList()
	return self.childrenList:getSize();
end

function Lua_DragContainer:addSubContainer(val, updatePos)
	val:setParent(self.sub);
	self.childrenList:add(val);
	if updatePos == true then
		self:updateChildPos();
	end
end

function Lua_DragContainer:removeSubContainer(val, updatePos)
	if val == nil then
		return;
	end

	local len = self.childrenList:getSize();
	for i = 1, len do
		if self.childrenList[i] == val then
			self.childrenList:remove(i);
			if updatePos == true then
				self:updateChildPos();
			end
			return;
		end
	end
end

function Lua_DragContainer:updateChildPos()
	local len = self.childrenList:getSize();
	self.maxSize = 0;
	for i = 1, len do
		local ox = 0;
		local oy = 0;
		if self.childrenList[i].getOffsetX ~= nil then
			ox = self.childrenList[i]:getOffsetX();
		end

		if self.childrenList[i].getOffsetY ~= nil then
			oy = self.childrenList[i]:getOffsetY();
		end

		if ox == nil or type(ox) ~= "number" then
			ox = 0;
		end

		if oy == nil or type(oy) ~= "number" then
			oy = 0;
		end

		if self.ltype == 2 then
			self.childrenList[i]:setLocation(self.maxSize + self.offsetY + ox, self.offsetX + oy, 0);
			self.maxSize = self.maxSize + self.childrenList[i]:getWidth();
		else
			self.childrenList[i]:setLocation(self.offsetY + ox, self.maxSize + self.offsetX + oy, 0);
			self.maxSize = self.maxSize - self.childrenList[i]:getHeight();
		end
	end

	if self.ltype == 2 then
		self.cminX = self.vsize.z - self.maxSize;
		self.cmaxX = 0;
	else
		self.cminY = 0;
		self.cmaxY = -(self.maxSize + self.vsize.w + self.addNum);
	end
end

function Lua_DragContainer:onMouseDownHandle(go, state)
	self:onPress(go, true);
end

function Lua_DragContainer:onMouseUpHandle(go, state)
	self:onPress(go, false);
end

function Lua_DragContainer:onPress(go, state)
	if state == true then
		if self.ltype == 2 then
			if self.checkSizeDrag == true and self.cminX < self.cmaxX then
				return;
			end
		else
			if self.checkSizeDrag == true and self.cminY > self.cmaxY then
				return;
			end
		end

		if self.startMouse == -1 then
			if self.ltype == 1 then
				self.startMouse = UnityEngine.Input.mousePosition.y;
				self.startContainer = self.sub.transform.localPosition.y;
			else
				self.startMouse = UnityEngine.Input.mousePosition.x;
				self.startContainer = self.sub.transform.localPosition.x;
			end
		end

		if self._isClick == false then
			self._isClick = true;
			Lua_CommonUtil.addTimer("onEnterFrame", 0.01, self, self.onEnterFrame);
		end
		Lua_CommonUtil.removeTimer(self, self.onBackPostion);
	else
		if self.ltype == 1 then
			local endPos = self.sub.transform.localPosition.y;
			local co = endPos - self.startContainer;
			if co < 2 and co > -2 then
				local screenpos = UICamera.mainCamera:ScreenToWorldPoint(UnityEngine.Input.mousePosition);
				local winPos = self.sub.transform:InverseTransformPoint(screenpos);

				for i = 1, self.childrenList:getSize() do
					local ty = self.childrenList[i].y;
					local dy = self.childrenList[i].y - self.childrenList[i]:getHeight(); 
					if ty >= winPos.y and dy <= winPos.y then
						self.childrenList[i]:onPlayerSoundClick();
					end
				end
			end
		end
		self.startMouse = -1;
		self.startContainer = -1;
		if self._isClick == true then
			self._isClick = false;
			Lua_CommonUtil.removeTimer(self, self.onEnterFrame);
		end
		self:checkPosFix();
	end
end

function Lua_DragContainer:onEnterFrame()
	local d = 0;
	if self.ltype == 1 then
		d = UnityEngine.Input.mousePosition.y - self.startMouse;
	else
		d = UnityEngine.Input.mousePosition.x - self.startMouse;
	end

	if self.startContainer ~= -1 then
		local rs = d + self.startContainer;
		if self.ltype == 1 then
			self:updateSubPos(0, rs, 0);
		else
			self:updateSubPos(rs, 0, 0);
		end
	end

	if self.onMoveingOwner ~= nil and self.onMoveingCallBack ~= nil then
		self.onMoveingCallBack(self.onMoveingOwner, d);
	end
end

function Lua_DragContainer:updateSubPos(px, py, pz)
	if self.canDrag == false then
		return;
	end

	LuaUtil.setObjPos(self.sub, px, py, pz);
	self.showRect = Lua_Rectangle.new(-px + self.vsize.x - self.vsize.z / 2, -py + self.vsize.y - self.vsize.w / 2, self.vsize.z, self.vsize.w);

	for i = 1, self.childrenList:getSize() do
		if self.childrenList[i].checkOutBound ~= nil then
			self.childrenList[i]:checkOutBound(self.showRect);
		end
	end
end

function Lua_DragContainer:checkPosFix()
	if self.ltype == 1 then
		local py = self.sub.transform.localPosition.y;
		if self.cminY >= self.cmaxY or py < self.cminY then
			self.targetPos = self.cminY;
			Lua_CommonUtil.addTimer("onBackPostion", 0.01, self, self.onBackPostion);
		elseif py > self.cmaxY then
			self.targetPos = self.cmaxY;
			Lua_CommonUtil.addTimer("onBackPostion", 0.01, self, self.onBackPostion);
		end
	else
		local px = self.sub.transform.localPosition.x;
		if self.cminX >= self.cmaxX or px < self.cminX then
			self.targetPos = self.cminX;
			Lua_CommonUtil.addTimer("onBackPostion", 0.01, self, self.onBackPostion);
		elseif px > self.cmaxX then
			self.targetPos = self.cmaxX;
			Lua_CommonUtil.addTimer("onBackPostion", 0.01, self, self.onBackPostion);
		end
	end
end

function Lua_DragContainer:onBackPostion()
	local isEnd = false;
	if self.ltype == 1 then
		local py = self.sub.transform.localPosition.y;
		if math.abs(self.targetPos - py) < 2 then
			self:updateSubPos(0, self.targetPos, 0);
			isEnd = true;
		else
			self:updateSubPos(0,(self.targetPos - py) * 0.15 + py, 0);
			isEnd = false;
		end
	else
		local px = self.sub.transform.localPosition.x;
		if math.abs(self.targetPos - px) < 2 then
			self:updateSubPos(self.targetPos, 0, 0);
			isEnd = true;
		else
			self:updateSubPos((self.targetPos - px) * 0.15 + px, 0, 0);
			isEnd = false;
		end
	end

	if isEnd == true then
		Lua_CommonUtil.removeTimer(self, self.onBackPostion);
	end
end

function Lua_DragContainer:moveToChildIndex(val, isNow, isBottom)
	local tp = 0;
	local lastPos = self.targetPos;
	if self.ltype == 1 then
		if val < 0 then
			tp = self.cminY
		elseif val > self.childrenList:getSize() then
			tp = self.cmaxY
		else
			tp = -self.childrenList[val].y;
		end
		self.targetPos = tp;

		if self.cminY >= self.cmaxY or tp < self.cminY then
			self.targetPos = self.cminY;
		elseif tp > self.cmaxY then 
			self.targetPos = self.cmaxY;
		end

		if isBottom then
			local py = self.sub.transform.localPosition.y;
			if self.targetPos >= py and self.targetPos <= py + self.vsize.w then
				self.targetPos = lastPos;
				return;
			end
		end

		if isNow == true then
			self:updateSubPos(0, self.targetPos, 0);
		else
			Lua_CommonUtil.addTimer("onBackPostion", 0.01,self, self.onBackPostion);
		end
	else
		if val < 0 then
			tp = self.cminX
		elseif val > self.childrenList:getSize() then
			tp = self.cmaxX
		else
			tp = self.childrenList[val].x;
		end
		self.targetPos = tp;

		if self.cminX >= self.cmaxX or tp < self.cminX then
			self.targetPos = self.cminX;
		elseif tp > self.cmaxX then 
			self.targetPos = self.cmaxX;
		end

		if isBottom then
			local px = self.sub.transform.localPosition.x;
			if self.targetPos >= px and self.targetPos <= px + self.vsize.z then
				self.targetPos = lastPos;
				return;
			end
		end

		if isNow == true then
			self:updateSubPos(self.targetPos, 0, 0);
		else
			Lua_CommonUtil.addTimer("onBackPostion", 0.01,self, self.onBackPostion);
		end
	end
end

function Lua_DragContainer:dispose()
	self.onMoveingOwner = nil;
	self.onMoveingCallBack = nil;
	Lua_CommonUtil.removeTimer(self, self.onEnterFrame);
	Lua_CommonUtil.removeTimer(self, self.onBackPostion);

	self:superCall("dispose");
end





--------------------------------------------------





Lua_DragContainerItem = class("Lua_DragContainerItem", Lua_DisplayObject);
function Lua_DragContainerItem:ctor(p, skin, frameBuild)
	self:superCall("ctor", p, skin, frameBuild);
end

function Lua_DragContainerItem:addExceptions()
	self:superCall("addExceptions");

	self.exceptionDic["getWidth"] = 1;
	self.exceptionDic["getHeight"] = 1;
end

function Lua_DragContainerItem:getWidth()
	return 0;
end

function Lua_DragContainerItem:getHeight()
	return 0;
end

function Lua_DragContainerItem:getOffsetX()
	return 0;
end

function Lua_DragContainerItem:getOffsetY()
	return 0;
end

function Lua_DragContainerItem:onPlayerSoundClick()
end