checkRequire("Lua_ListCell");
checkRequire("Lua_DragListInsideCell");
checkRequire("Lua_DragCellData");
Lua_DragList = class("Lua_DragList", Lua_DisplayObject);
function Lua_DragList:ctor(p, ltype, vsize)
	self.ltype = ltype;
	self.vsize = vsize;
	self.viewRect = Lua_Rectangle.new(vsize.x - vsize.z / 2, vsize.y - vsize.w / 2, vsize.z, vsize.w);
	self.subPosX = 0;
	self.subPosY = 0;
	self.ox = 0;
	self.oy = 0;
	self.canDrag = true;
	self.isNeedToLoadNextData = false;
	self.showList = Array();
	self.hideList = Array();
	self.showDragDataList = Array();
	self.lastCreate = 0;
	self.startMouse = -1;
	self.startContainer = -1;
	self._isClick = false;
	self.minX = 0;
	self.minY = 0;
	self.maxX = 0;
	self.maxY = 0;
	self.cminX = 0;
	self.cminY = 0;
	self.cmaxX = 0;
	self.cmaxY = 0;
	self.doScale = false;
	self.is_pack = false;
	self.curSelectedIdx = 0;
	self:superCall("ctor", p);
	self.offsetMin = 0;
	self.offsetMax = 0;
	self.tempAngle = 0;
end

function Lua_DragList:setRect(vsize)
	self.vsize = vsize;
	self.viewRect = Lua_Rectangle.new(vsize.x - vsize.z / 2, vsize.y - vsize.w / 2, vsize.z, vsize.w);
	if self.uiPanel ~= nil then
		self.uiPanel.baseClipRegion = self.vsize;
	end
	
	self:setBgSize(vsize);
	self:checkPosFix();
end

function Lua_DragList:setEnable(val)
	self:superCall("setEnable", val);
	LuaUtil.updateWindowDepth(nil);
end

function Lua_DragList:buildShowItem()
	self.content.name = "Lua_DragList";
	self.sub = UICreate.createGameObject(self.content, self.subPosX, self.subPosY, 0);
	self.sub.name = "sub";

	self.requireNext = false;
	self.sendTime = 0;

	self.mpos = {};
	self.mpos.x = (self.vsize.x + self.vsize.z) / 2;
	self.mpos.y = (self.vsize.y + self.vsize.w) / 2;

	self.uiPanel = self.content:AddComponent(typeof(UIPanel));  
	self.uiPanel.cullWhileDragging = false;
	self.uiPanel.softBorderPadding = false;
	self.uiPanel.clipSoftness = Vector2(0, 0);
	self.uiPanel.clipOffset = Vector2(0, 0);
	self.uiPanel.anchorOffset = false;
	self.uiPanel.widgetsAreStatic = false;
	self.uiPanel.baseClipRegion = self.vsize;
	self.uiPanel.clipping = UIDrawCall.Clipping.SoftClip;

	self.bg = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_black_50", self.vsize.x, self.vsize.y, self.vsize.z, self.vsize.w);
	self.bg.alpha = 0.01;
	self.bg:setDepth(-1);
	self.bg:addClickFuntion(self, self.onMouseDownHandle);
	self.bg:addMouseUpFuntion(self, self.onMouseUpHandle);

	LuaUtil.updateWindowDepth(nil);
end

function Lua_DragList:setBgSize(vsize)
	self.bg:setLocation(vsize.x, vsize.y, 0);
	self.bg:SetDimensions(vsize.z, vsize.w);
end

function Lua_DragList:setListCell(cell, cellHeight, cellWidth, perLine, circle, angle)
	self.cell = cell;
	self.cellWidth = cellWidth;
	self.cellHeight = cellHeight;
	self.perLine = perLine;
	self.circle = circle;
	self.angle = angle;

	-- 每日充值
	-- if self.angle ~= nil and self.circle ~= nil and self.checkPos == nil then
	-- 	self.checkPos = UICreate.createGameObject(self.sub, self:LocalCircle().x, self:LocalCircle().y, 0);
	-- 	self.checkPos.name = "checkPos";
	-- 	self.checkPos.transform.parent = self.content.transform;
	-- end
end

function Lua_DragList:onMouseDownHandle(go,state)
	self:onPress(go, true);
end

function Lua_DragList:onMouseUpHandle(go,state)
	self:onPress(go, false);
end

function Lua_DragList:setCellScaleChange(val, minScale, maxScale, distance, owner, callBack)
	self.doScale = val;
	self.minScale = minScale;
	self.maxScale = maxScale;
	self.viewOffset = self.vsize.z / 2;
	self.distance = distance;
	self.pageOwner = owner;
	self.pageCallBack = callBack;
end

function Lua_DragList:setSubPos(posX, posY, posZ)
	self.subPosX = posX;
	self.subPosY = posY;
	if posZ == nil then
		posZ = 0;
	end
	-- self.sub.transform.localPosition = Vector3(posX, posY, posZ);
	LuaUtil.setObjPos(self.sub, posX, posY, posZ);
	self:updateBounds();
end

function Lua_DragList:moveToIndex(val, immediately)
	if self.data == nil then
		return;
	end

	if val <= 0 then
		val = 1;
	end

	if val > self.data:getSize() then
		val = self.data:getSize();
	end

	self.targetPos = 0;
	if self.doScale == true then
		if self.ltype == 1 then
			self.targetPos = - (val - 1) * self.cellHeight + self.subPosY;
			self.targetPos = self.targetPos < self.cminY and self.cminY or self.targetPos;
			self.targetPos = self.targetPos > self.cmaxY and self.cmaxY or self.targetPos;
		else
			self.targetPos = - (val - 0.5) * self.cellWidth + self.subPosX + self.viewOffset;
		end

		if immediately == true then
			if self.ltype == 1 then
				self:updateSubPos(self.subPosX, self.targetPos, 0);
			else
				self:updateSubPos(self.targetPos, self.subPosY, 0);
			end
		else
			Lua_CommonUtil.addTimer("onBackPostion", 0.01, self, self.onBackPostion);
		end
	else
		if self.ltype == 1 then
			local min_y = self.cminY + self.offsetMin;
			local max_y = self.cmaxY + self.offsetMax;
			self.targetPos = (val - 1) * self.cellHeight + self.subPosY;
			self.targetPos = self.targetPos < min_y and min_y or self.targetPos;
			self.targetPos = self.targetPos > max_y and max_y or self.targetPos;
		else
			local min_x = self.cminX + self.offsetMin;
			local max_x = self.cmaxX + self.offsetMax;
			self.targetPos = - (val - 1) * self.cellWidth + self.subPosX;
			self.targetPos = self.targetPos < min_x and min_x or self.targetPos;
			self.targetPos = self.targetPos > max_x and max_x or self.targetPos;
		end

		if immediately == true then
			if self.ltype == 1 then
				self:updateSubPos(self.subPosX, self.targetPos, 0);
			else
				self:updateSubPos(self.targetPos, self.subPosY, 0);
			end
		else
			Lua_CommonUtil.addTimer( "onBackPostion", 0.01, self, self.onBackPostion);
		end
	end
	if self.pageOwner ~= nil and self.pageCallBack ~= nil then
		self.pageCallBack(self.pageOwner, val);
	end
end

function Lua_DragList:updateBounds()
	self.cminX = self.minX + self.subPosX;
	self.cmaxX = self.maxX + self.subPosX;
	self.cmaxY = self.maxY + self.subPosY;
	self.cminY = self.minY + self.subPosY;
end

function Lua_DragList:setDepth(val)
	self.uiPanel.depth = val;
	self.uiPanel.startingRenderQueue = val;
	self.uiPanel.renderQueue = UIPanel.RenderQueue.StartAt;
end

function Lua_DragList:addNewData(data)
	if self.data == nil then
		self.data = data;
	else
		for i = 1, data:getSize() do
			self.data:add(data[i]);
		end
	end
	self:setLuaArrayData(self.data);
end

function Lua_DragList:setLuaArrayData(data, delayCreate)
	if delayCreate == nil then
		delayCreate = true;
	end
	self.delayCreate = delayCreate;

	-- self:clearList();
	self.data = data;
	local len = self.data:getSize();
	local offsetx = self.vsize.x - self.vsize.z / 2 + self.cellWidth / 2;
	self.b_offsetx = offsetx;
	local offsety = self.vsize.y + self.vsize.w / 2 - self.cellHeight / 2;
	self.b_offsety = offsety;

	-- for i = 1, len do
	-- 	local h_index = math.floor((i - 1) / self.perLine);
	-- 	local w_index = math.floor((i - 1) % self.perLine);
	-- 	local l = Lua_DragCellData.new(self.cellWidth * w_index + offsetx, - self.cellHeight * h_index + offsety, 
	-- 	self.cellWidth, self.cellHeight, self.data[i], self);
	-- 	l.index = i;
	-- 	l.cellWidth = self.cellWidth;
	-- 	l.cellHeight = self.cellHeight;
	-- 	self.showDragDataList:add(l);
	-- end

	local l;
	local num = self.showDragDataList:getSize() - len;
	while (num > 0) do
		l = self.showDragDataList:remove();
		l:clean();
		num = num - 1;
	end

	while (num < 0) do
		local l = Lua_DragCellData.new(0, 0, 0, 0, nil, self);
		self.showDragDataList:add(l);
		num = num + 1;
	end

	local h_index;
	local w_index;
	local cellX;
	local cellY;
	for i = 1, len do
		h_index = math.floor((i - 1) / self.perLine);
		w_index = math.floor((i - 1) % self.perLine);
        cellX = self.cellWidth * w_index + offsetx;
        cellY = -self.cellHeight * h_index + offsety;

		-- 每日充值
		if self.angle ~= nil and self.circle ~= nil and i > 1 then
			local firstAngle = self:getAngleFirst(offsetx, offsety);
			cellX = self:LocalCircle().x + self.radius * math.cos(math.rad(firstAngle - self.angle * (i - 1)));
			cellY = self:LocalCircle().y + self.radius * math.sin(math.rad(firstAngle - self.angle * (i - 1)));
		end
		l = self.showDragDataList[i];
		l:init(cellX, cellY, self.cellWidth, self.cellHeight, self.data[i]);
		l.index = i;
		l.cellWidth = self.cellWidth;
		l.cellHeight = self.cellHeight;
	end

	local mh = math.ceil(len / self.perLine);
	self.maxY = mh * self.cellHeight - self.vsize.w;
	if self.maxY < self.minY then
		self.maxY = self.minY;
	end

	local mw = math.min(self.perLine, len);
	self.minX = - mw * self.cellWidth + self.vsize.z;
	if self.maxX < self.minX then
		self.minX = self.maxX;
	end
	self:updateBounds();

	local p = self.sub.transform.localPosition;
	self:updateSubPos(p.x, p.y, p.z);
	if delayCreate ~= true and self.onLuaComplete ~= nil then
		self.onLuaComplete();
	end
	self:checkPosFix();
end

function Lua_DragList:updateSubPos(px, py, pz)
	-- 每日充值
	-- if self.circle ~= nil and self.angle ~= nil then
	-- 	local cellX = -365 + 98 + self.radius * math.cos(math.rad(self.tempAngle));
	-- 	local cellY = 0 + self.radius * math.sin(math.rad(self.tempAngle));
	-- 	self.sub.transform.localPosition = Vector3(cellX, cellY, pz);
	-- 	self.tempAngle = self.tempAngle + 0.1;
	-- 	self.sub.transform:RotateAround(Vector3(-415, 0, 0), Vector3(0, 1, 0), 0.1);
	-- else
	-- 	self.sub.transform.localPosition = Vector3(px, py, pz);
	-- end
	self.sub.transform.localPosition = Vector3(px, py, pz);
	LuaUtil.setObjPos(self.sub, px, py, pz);

	local len = self.showDragDataList:getSize();
	for i = 1, len do
		local ll = self.showDragDataList[i]:checkInBound(self.sub.transform.localPosition, self.viewRect, self.b_offsetx, self.b_offsety);
		if ll then
			self.showDragDataList[i]:getCellFromPool(self);
		else
			self.showDragDataList[i]:returnCellToPool();
		end
	end

	len = self.showList:getSize();
	local miny = self.vsize.y - self.vsize.w / 2;
	local maxy = self.vsize.y + self.vsize.w / 2;
	self.showRect = Lua_Rectangle.new(-px + self.vsize.x - self.vsize.z / 2, -py + self.vsize.y - self.vsize.w / 2, self.vsize.z, self.vsize.w);
	for i = 1, len do
		if self.is_pack then
			local b = self.showList[i].content.transform.localPosition.y;
			local sy = b - py-10;
			local by = b + py-10;
			self.showList[i].content:SetActive((by+30) > miny and (by-20) < maxy);
		end
		self.showList[i]:checkOutBound(self.showRect);

		if self.doScale == true then
			self.showList[i]:checkScale(self.sub.transform.localPosition, self.mpos, self.b_offsetx, self.b_offsety, self.minScale, self.maxScale, self.distance);
		end
	end
end

-- 每日充值
function Lua_DragList:getAngleFirst(fx, fy)
	self.radius = math.sqrt(math.pow((fx - self:LocalCircle().x), 2) + math.pow((fy - self:LocalCircle().y), 2));
	local firstAngle = math.deg(math.acos((fx - self:LocalCircle().x) / self.radius));
	return firstAngle;
end
-- 每日充值
function Lua_DragList:LocalCircle()
	if self.ltype == 1 then
		return Vector2(-self.circle, 0);
	else
		return Vector2(0, -self.circle);
	end
end

function Lua_DragList:onPress(go, state)
	if self.setDispose then
		return;
	end

	if self.canDrag == false then
		self:checkClick();
		return;
	end

	if state then
		if self.startMouse == -1 then
			if self.ltype == 1 then
				self.startMouse = UnityEngine.Input.mousePosition.y;
				self.startContainer = self.sub.transform.localPosition.y;
			else
				self.startMouse = UnityEngine.Input.mousePosition.x;
				self.startContainer = self.sub.transform.localPosition.x;
			end
		end

		if self._isClick == false then
			self._isClick = true;
			Lua_CommonUtil.addTimer( "onEnterFrame", 0.01, self, self.onEnterFrame);
		end
		Lua_CommonUtil.removeTimer(self,self.onBackPostion);  
	else
		self:checkPosFix();
		self:setRequireNext(false);
		local endPos = 0;
		if self.ltype == 1 then
			endPos = self.sub.transform.localPosition.y;
		else
			endPos = self.sub.transform.localPosition.x;
		end

		local co = endPos - self.startContainer;
		if co < 2 and co > -2 then
			self:checkClick();
		elseif co > 0 then
			if self.onMoveLeftUp ~= nil then
				self.onMoveLeftUp();
			end
		elseif co < 0 then
			if self.onMoveRightUp ~= nil then
				self.onMoveRightUp();
			end
		end

		self.startMouse = -1;
		self.startContainer = -1;
		if self._isClick == true then
			self._isClick = false;
			Lua_CommonUtil.removeTimer(self,self.onEnterFrame);
		end
	end
end

function Lua_DragList:checkClick()
	local screenpos = UICamera.mainCamera:ScreenToWorldPoint(UnityEngine.Input.mousePosition);
	local winPos = self.sub.transform:InverseTransformPoint(screenpos);
	for i = 1, self.showList:getSize() do
		if self.showList[i]:isBounds(winPos.x, winPos.y) == true then
			self:setSelected(self.showList[i]);
			self.showList[i]:onPlayerSoundClick(go);
			break;
		end
	end
end

function Lua_DragList:setScaleSelected(val)
	self.scaleSelected = val;
end

function Lua_DragList:checkPosFix()
	if self.setDispose == true then
		return;
	end
	if self.doScale == true then
		local index = 0;
		local s = 99999999;
		for i = 1, self.showDragDataList:getSize() do
			local t = self.showDragDataList[i]:checkScale(self.sub.transform.localPosition, self.mpos, self.b_offsetx, self.b_offsety, 
			self.minScale, self.maxScale, self.distance);
			if t < s then
				s = t;
				index = self.showDragDataList[i].index;
			end 
		end

		if self.scaleSelected == nil then
			self:moveToIndex(index);
		else
			self:moveToIndex(self.scaleSelected);
		end
	else
		if self.ltype == 1 then
			local py = self.sub.transform.localPosition.y;
			local min_y = self.cminY + self.offsetMin;
			local max_y = self.cmaxY + self.offsetMax;
			if py < min_y or py > max_y then
				if py < min_y then
					self.targetPos = min_y;
				elseif py > max_y then
					self.targetPos = max_y;
				end
				Lua_CommonUtil.addTimer("onBackPostion", 0.01, self, self.onBackPostion);
			end
		else
			local px = self.sub.transform.localPosition.x;
			local min_x = self.cminX + self.offsetMin;
			local max_x = self.cmaxX + self.offsetMax;
			if px < min_x or px > max_x then
				if px < min_x then
					self.targetPos = min_x;
				elseif px > max_x then
					self.targetPos = max_x;
				end
				Lua_CommonUtil.addTimer( "onBackPostion", 0.01,self,  self.onBackPostion);
			end
		end
	end
end

function Lua_DragList:isDragingEnd()
	if self.ltype == 1 then
		local py = self.sub.transform.localPosition.y;
		if py > self.cmaxY then
			return true;
		end
	else
		local px = self.sub.transform.localPosition.x;
		if px > self.cmaxX then
			return true;
		end
	end
	return false;
end

function Lua_DragList:onBackPostion()
	local isEnd = false;
	if self.ltype == 1 then
		local py = self.sub.transform.localPosition.y;
		if math.abs(self.targetPos - py) < 2 then
			self:updateSubPos(self.subPosX, self.targetPos, 0);
			isEnd = true;
		else
			self:updateSubPos(self.subPosX, (self.targetPos - py) * 0.15 + py, 0);
			isEnd = false;
		end
	else
		local px = self.sub.transform.localPosition.x;
		if math.abs(self.targetPos - px) < 2 then
			self:updateSubPos(self.targetPos, self.subPosY, 0);
			isEnd = true;
		else
			self:updateSubPos((self.targetPos - px) * 0.15 + px, self.subPosY, 0);
			isEnd = false;
		end
	end

	if isEnd then
		Lua_CommonUtil.removeTimer(self,self.onBackPostion);
	end
end

function Lua_DragList:onEnterFrame()
	local d = 0;
	if self.ltype == 1 and self.minY == self.maxY then
		return;
	end

	if self.ltype == 2 and self.minX == self.maxX then
		return;
	end

	if self.ltype == 1 then
		d = UnityEngine.Input.mousePosition.y - self.startMouse;
	else
		d = UnityEngine.Input.mousePosition.x - self.startMouse;
	end

	if self.startContainer ~= -1 then
		local rs = d + self.startContainer;
		if self.ltype == 1 then
			self:updateSubPos(self.subPosX, rs, 0);
		else
			self:updateSubPos(rs, self.subPosY, 0);
		end

		if self.isNeedToLoadNextData == true and self:isDragingEnd() == true then
			self:setRequireNext(true);
		end
	end
end

function Lua_DragList:setRequireNext(val)
	if self.requireNext == val then
		return;
	end
	self.requireNext = val;

	if self.requireNext == true then
		if getTime()- self.sendTime > 2 then
			self.sendTime = getTime();
			if self.pageScrollCallBack ~= nil then
				self.pageScrollCallBack();
			end
		end
		self.nextLabel:setEnable(true);
	else
		self.nextLabel:setEnable(false);
	end
end

function Lua_DragList.Get:nextLabel()
	if self._nextLabel == nil then
		self._nextLabel = UICreate.createLabel(content, "Load Next", 0, 0, 100, 30, 22);
		self._nextLabel.pivot = UIWidget.Pivot.Center;
		-- self._nextLabel.mainContent.transform.localPosition = Vector3(self.vsize.x, self.vsize.y - self.vsize.w / 2 + 30, 0);
		LuaUtil.setObjPos(self._nextLabel.mainContent, self.vsize.x, self.vsize.y - self.vsize.w / 2 + 30, 0);
		self._nextLabel.mainContent:SetActive(false);
	end
	return self._nextLabel;
end

function Lua_DragList:createCellItem()
	local rs = nil;
	if self.hideList:getSize() > 0 then
		rs = self.hideList[1];
		rs:setDragParant(self);
		rs:setEnable(true);
		self.hideList:remove(1);
	else
		rs = self.cell.new(self.sub,nil,nil);
		rs:setDragParant(self);
	end
	self.showList:add(rs);
	return rs;
end

function Lua_DragList:returnCell(cell)
	if cell == nil then
		return;
	end

	for i = 1, self.showList:getSize() do
		if self.showList[i] == cell then
			cell:setEnable(false);
			self.showList:remove(i);
			break;
		end
	end
	self.hideList:add(cell);
end

function Lua_DragList:clearList()
	for i = 1, self.showList:getSize() do
		if self.showList[i] ~= nil then
			self.showList[i]:setEnable(false);
			self.hideList:add(self.showList[i]);
		end
	end
	self.showList:clear();
	self.showDragDataList:clear();
end

function Lua_DragList:setSelected(val)
	if self.data == nil then
		return;
	end

	local item = nil
	if type(val) == "number" then
		if self.showDragDataList:getSize() > 0 then
			item = self.showDragDataList:getItem(val).cell;
		end
	elseif type(val) == "table" then
		item = val
	end

	if item ~= nil then
		for i = 1, self.showList:getSize() do
			local showItem = self.showList:getItem(i)
			local rs = showItem == item and true or false ;
			if showItem.selected ~= rs and  showItem.onSelectionChange ~= nil then--
				showItem:onSelectionChange(rs);
				if rs == true then
					self.curSelectedIdx = showItem.cellSeqIndex;
				end

				if showItem == item then
					self:onSelectionCallBack(showItem)
				end
			end
		end
	end
end

function Lua_DragList:onSelectionCallBack(cell)
	if self.selectionChangeCallBack ~= nil then
		self.selectionChangeCallBack(cell)
	end
end

function Lua_DragList:dispose()
	for i = 1, self.showList:getSize() do
		self.showList[i].ownerList = nil;
		self.showList[i]:dispose();
	end
	for i = 1, self.hideList:getSize() do
		self.hideList[i].ownerList = nil;
		self.hideList[i]:dispose();
	end
	self.pageOwner = nil;
	self.pageCallBack = nil;
	self.setDispose = true;
	Lua_CommonUtil.removeTimer(self, self.onEnterFrame);
	Lua_CommonUtil.removeTimer(self, self.onBackPostion);

	self:superCall("dispose");
end