Lua_RewardDragItem = class("Lua_RewardDragItem", Lua_DisplayObject);
function Lua_RewardDragItem:ctor(p, width, cellWith, height)
	self.width = width;
	self.cellWith = cellWith == nil and 100 or cellWith;
	self.height = height == nil and 100 or height;
	self:superCall("ctor", p);
end

function Lua_RewardDragItem:buildShowItem()
	self:superCall("buildShowItem");

	self.content.name = "Lua_RewardDragItem";

	self.pivot = 1;

	self.dragList = Lua_DragList.new(self.content, 2, Vector4(0, 0, self.width, self.height));
	self.dragList:setListCell(Lua_RewardToolImgItem, self.height, self.cellWith, 9999);
	self.dragList:setLocation(0, 0, 0);
end

function Lua_RewardDragItem:setRewardByRewardList(rewardIdArr)
	local rewardInfo;
	local tvoInfo;
	local itemList = Array();
	for i = 1, rewardIdArr:getSize() do
		rewardInfo = Lua_RewardsUtil.getRewardList(rewardIdArr[i]);
		for k,v in ipairs(rewardInfo.rewards) do
			tvoInfo = nil;
			for j = 1, itemList:getSize() do
				if itemList[j].id == v.id and itemList[j].bind == v.bind and itemList[j].star == v.star then
					tvoInfo = itemList[j];
					break;
				end
			end

			if tvoInfo == nil then
				tvoInfo = {};
				tvoInfo.id = v.id;
				tvoInfo.amount = v.amount;
				tvoInfo.bind = v.bind;
				tvoInfo.star = v.star;
				tvoInfo.attr = v.attr;
				tvoInfo.roundEffect = v.roundEffect;
				if rewardInfo.dropMarks ~= nil and table.indexOf(rewardInfo.dropMarks, k - 1) ~= -1 then
					tvoInfo.mustDrop = true;
				end
				itemList:add(tvoInfo);
			else
				tvoInfo.amount = tvoInfo.amount + v.amount;
			end
		end
	end
	self:setRewardByArray(itemList);
end

-- 根据array数组({道具id：id，道具数量：count是tvo的数量 amount是服务端下发或Lua_RewardData的数量，是否绑定：bind 0非绑定 1绑定})
function Lua_RewardDragItem:setRewardByArray(val)
	local num;
	local tvo;
	local arr = Array();
	for i = 1, val:getSize() do
		num = val[i].amount == nil and val[i].count or val[i].amount;

		tvo = Lua_ToolVo.createToolVo(val[i].id, num, val[i].bind);
		tvo.packType = 999;
		tvo.star = val[i].star;
		tvo.mustDrop = val[i].mustDrop;
		tvo.roundEffect = val[i].roundEffect;
		tvo.bShowItemBg = val[i].bShowItemBg;
		tvo.soul_level = val[i].soul_level;
		if val[i].equipment ~= nil then
			tvo.equipment = val[i].equipment;
			tvo.star = tvo.equipment.star;
		elseif val[i].attr ~= nil then
			tvo.equipment = {star = val[i].star, attr = val[i].attr};
		end
		arr:add(tvo);
	end
	self.dragList:setLuaArrayData(arr);

	local len = arr:getSize() * self.cellWith;
	if len < self.width and self.pivot == 2 then
		self.dragList:setLocation((self.width - len) / 2, 0, 0);
	end
end

-- 根据ToolVo Array数组
function Lua_RewardDragItem:setRewardByToolArr(arr)
	self.dragList:setLuaArrayData(arr);
	local len = arr:getSize() * self.cellWith;
	if len < self.width and self.pivot == 2 then
		self.dragList:setLocation((self.width - len) / 2, 0, 0);
	end
end

function Lua_RewardDragItem:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	self:superCall("dispose");
end





--------------------------------------------------





Lua_RewardToolImgItem = class("Lua_RewardToolImgItem", Lua_ListCell);
function Lua_RewardToolImgItem:buildShowItem()
	self:superCall("buildShowItem");

	self.toolImg = Lua_ToolImage.new(self.content);
	self.toolImg:setCanClick(false);
end

function Lua_RewardToolImgItem:setData(data)
	self._data = data;
	self.toolImg.data = data;
end

function Lua_RewardToolImgItem:onPlayerSoundClick(go)
	if self._data ~= nil then
		Lua_PackUtil.showItemInfo(self._data);
	end
end

function Lua_RewardToolImgItem:checkOutBound(showRect)
	if self._data == nil then
		self.inViewEffect = false;
		self:updateEffectState();
		return;
	end
	local rect = Lua_Rectangle.new(self.itemX - self.boxW / 2, self.itemY - self.boxH / 2, self.boxW, self.boxH);
	self.inViewEffect = showRect:containeRect(rect);
	self:updateEffectState();
end

function Lua_RewardToolImgItem:updateEffectState()
	if self.inViewEffect == true then
		if self.toolImg.roundEff == nil and self.toolImg.data.show_effect == 1 then
			self.toolImg:showRoundEff(true);
		end
	else
		if self.toolImg.roundEff ~= nil then
			self.toolImg:showRoundEff(false);
		end
	end
end

function Lua_RewardToolImgItem:dispose()
	if self.toolImg ~= nil then
		self.toolImg:dispose();
		self.toolImg = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end