-- 用法：
-- self.rItem = Lua_RewardItem.new(self.content);
-- self.rItem:setLayout(70, 70, 4);
-- self.rItem:setMaxShow(4);
-- self.rItem:setDepth(self.depth+10);
-- self.rItem:setClickWin(true);
-- self.rItem:setMouseEnble(true);
-- self.rItem:setItemScale(0.8, 0.8);
-- self.rItem:setLocation(-317,-305, 0);
-- self.rItem:setRewardByRewardList(Array(rewardId));

Lua_RewardItem = class("Lua_RewardItem", Lua_DisplayObject);
function Lua_RewardItem:ctor(p, showDropMark, bMustShowItemBg)
	self.showDropMark = showDropMark == nil and false or showDropMark;
	-- bMustShowItemBg 所有都显示底框，false所有都不显示底框，nil根据配置表notShowItemBg字段判断是否显示
	self.bMustShowItemBg = bMustShowItemBg;

	self:superCall("ctor", p);
end

function Lua_RewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.content.name = "Lua_RewardItem";

	self.awords = {};
	self.itemList = Array();

	self.rowInterval = 91;
	self.colInterval = 91;
	self.rowLimit = 1000;

	self._pivot = 1;
	self._clickWin = false;
	self._mouseEnble = true;
	self._maxShow = -1;
	self._itemScaleX = 1;
	self._itemScaleY = 1;
end

function Lua_RewardItem.Set:pivot(val)
	self._pivot = val;
end

-- 设置点击图标是否弹出窗口
function Lua_RewardItem:setClickWin(val)
	self._clickWin = val;
	for i, v in ipairs(self.awords) do
		v:setCanClick(val);
	end
end

-- 设置鼠标是否可点击图标
function Lua_RewardItem:setMouseEnble(val)
	self._mouseEnble = value;
	for i, v in ipairs(self.awords) do
		v.mouseEnble = val;
	end
end

-- 设置图标缩放
function Lua_RewardItem:setItemScale(scaleX, scaleY)
	self._itemScaleX = scaleX;
	self._itemScaleY = scaleY;
	for i, v in ipairs(self.awords) do
		v:setScale(self._itemScaleX, self._itemScaleY);
	end
end

-- 设置魂印图标特效缩放
function Lua_RewardItem:setStampEffectScale(scaleX, scaleY, scaleZ)
	for i, v in ipairs(self.awords) do
		if v.stampEff ~= nil then
			v.stampEff:setScale(scaleX,scaleY,scaleZ);
		end
	end
end

-- 设置图标深度
function Lua_RewardItem:setDepth(val)
	self:superCall("setDepth", val);
	for i, v in ipairs(self.awords) do
		v:setDepth(val);
	end
end

-- 设置最大显示图标数
function Lua_RewardItem:setMaxShow(val)
	self._maxShow = val;
	for i, v in ipairs(self.awords) do
		v:setEnable(self._maxShow == -1 or self._maxShow > i);
	end
end

-- 行间距，列间距，每行限制显示多少个
function Lua_RewardItem:setLayout(rowInterval, colInterval, rowLimit)
	self.rowInterval = rowInterval == nil and 90 or rowInterval;
	self.colInterval = colInterval == nil and 90 or colInterval;
	self.rowLimit = rowLimit == nil and 1000 or rowLimit;
end

-- 设置奖励id数组(id对应->奖励总表.xml)，并生成图标显示
function Lua_RewardItem:setRewardByRewardList(val, bShowItemBg, roundEffect)
	local rewardData;
	local idStr;
	local step = 1;
	local tvoInfo;
	local itemDic = {};
	for i = 1, val:getSize() do
		rewardData = Lua_RewardsUtil.getRewardList(val[i]);
		for k,v in ipairs(rewardData.rewards) do
			idStr = v.id..v.bind..v.star;
			tvoInfo = itemDic[idStr];
			if tvoInfo == nil then
				tvoInfo = {};
				tvoInfo.id = v.id;
				tvoInfo.count = v.amount;
				tvoInfo.bind = v.bind;
				tvoInfo.star = v.star;
				tvoInfo.attr = v.attr;
				tvoInfo.bShowItemBg = bShowItemBg;
				tvoInfo.roundEffect = roundEffect ~= nil and roundEffect or v.roundEffect;

				tvoInfo.step = step;
				step = step + 1;
				if rewardData.dropMarks ~= nil and table.indexOf(rewardData.dropMarks, k - 1) ~= -1 then
					tvoInfo.mustDrop = true;
				end
				itemDic[idStr] = tvoInfo;
			else
				tvoInfo.count = tvoInfo.count + v.amount;
			end
		end
	end

	local itemList = Array();
	for k,v in pairs(itemDic) do
		itemList:add(v);
	end
	itemList:sort("step", false);
	self:setRewardByArray(itemList);
	self.itemList = itemList;
end

-- 根据array数组({道具id：id，道具数量：count是tvo的数量 amount是服务端下发或Lua_RewardData的数量，是否绑定：bind 0非绑定 1绑定})
function Lua_RewardItem:setRewardByArray(arr)
	local len = arr:getSize();
	local w = self.rowInterval * math.min(len, self.rowLimit);
	if self._pivot == 1 then
		w = 0;
	elseif self._pivot == 2 then
		w = -w / 2 + self.rowInterval / 2;
	else
		w = -w;
	end

	local info;
	local num;
	local tvo;
	local posX;
	local posY;
	local item;
	for i = 1, len do
		info = arr[i];
		num = info.count ~= nil and info.count or info.amount;

		tvo = Lua_ToolVo.createToolVo(info.id, num, info.bind);
		tvo.star = info.star;
		tvo.packType = 999;
		tvo.bShowItemBg = info.bShowItemBg;
		if self.bMustShowItemBg ~= nil then
			tvo.bShowItemBg = self.bMustShowItemBg;
		end
		tvo.roundEffect = info.roundEffect;
		tvo.mustDrop = info.mustDrop;
		if info.attr ~= nil then
			tvo.equipment = {};
			tvo.equipment.star = info.star;
			tvo.equipment.attr = info.attr;
		end

		posX = w + self.rowInterval * ((i - 1) % self.rowLimit);
		posY = -self.colInterval * math.floor((i - 1) / self.rowLimit);

		item = self.awords[i] or Lua_ToolImage.new(self.content);
		item.data = tvo;
		item:setDepth(self.depth);
		item:setCanClick(self._clickWin);
		item:setLocation(posX, posY, 0);
		item:setScale(self._itemScaleX, self._itemScaleY);
		item:setEnable(self._maxShow == -1 or self._maxShow > (i - 1));

		if i > #self.awords then
			self.awords[i] = item;
		end
	end

	for i = len + 1, #self.awords do
		self.awords[i]:setEnable(false);
	end
end

-- 根据table数组({道具id：id，道具数量：amount，是否绑定：bind 0非绑定 1绑定})
function Lua_RewardItem:setRewardByItemList(tabDic)
	local len = #tabDic;
	local w = self.rowInterval * math.min(len, self.rowLimit);
	if self._pivot == 1 then
		w = 0;
	elseif self._pivot == 2 then
		w = -w / 2 + self.rowInterval / 2;
	else
		w = -w;
	end

	local tvo;
	local posX;
	local posY;
	local item;
	for i, v in ipairs(tabDic) do
		tvo =  Lua_ToolVo.createToolVo(v.id, v.amount, v.bind);
		tvo.star = v.star;
		tvo.packType = 999;
		if self.bMustShowItemBg ~= nil then
			tvo.bShowItemBg = self.bMustShowItemBg;
		end
		if v.equipment ~= nil then
			tvo.equipment = v.equipment;
		elseif v.attr ~= nil then
			tvo.equipment = {};
			tvo.equipment.star = v.star;
			tvo.equipment.attr = v.attr;
		end

		posX = w + self.rowInterval * ((i - 1) % self.rowLimit);
		posY = -self.colInterval * math.floor((i - 1) / self.rowLimit);

		item = self.awords[i] or Lua_ToolImage.new(self.content);
		item.data = tvo;
		item.mouseEnble = self._mouseEnble;
		item:setDepth(self.depth);
		item:setCanClick(self._clickWin);
		item:setLocation(posX, posY, 0);
		item:setScale(self._itemScaleX, self._itemScaleY);
		item:setEnable(self._maxShow == -1 or self._maxShow > (i - 1));
		if i > #self.awords then
			self.awords[i] = item;
		end
	end

	for i = len + 1, #self.awords do
		self.awords[i]:setEnable(false);
	end
end

-- 根据ToolVo数组
function Lua_RewardItem:setRewardByToolVoList(arr)
	self.itemList = arr;
	local len = arr:getSize();
	local w = self.rowInterval * math.min(len, self.rowLimit);
	if self._pivot == 1 then
		w = 0;
	elseif self._pivot == 2 then
		w = -w / 2 + self.rowInterval / 2;
	else
		w = -w;
	end

	local tvo;
	local posX;
	local posY;
	local item;
	for i = 1, len do
		tvo = arr[i];
		tvo.packType = 999;
		if self.bMustShowItemBg ~= nil then
			tvo.bShowItemBg = self.bMustShowItemBg;
		end

		posX = w + self.rowInterval * ((i - 1) % self.rowLimit);
		posY = -self.colInterval * math.floor((i - 1) / self.rowLimit);

		item = self.awords[i] or Lua_ToolImage.new(self.content);
		item.data = tvo;
		item.mouseEnble = self._mouseEnble;
		item:setDepth(self.depth);
		item:setCanClick(self._clickWin);
		item:setLocation(posX, posY, 0);
		item:setScale(self._itemScaleX, self._itemScaleY);
		item:setEnable(self._maxShow == -1 or self._maxShow > (i - 1));
		if i > #self.awords then
			self.awords[i] = item;
		end
	end

	for i = len + 1, #self.awords do
		self.awords[i]:setEnable(false);
	end
end

function Lua_RewardItem:getToolImageById(id)
	for i = 1, #self.awords do
		if self.awords[i].data.id == tonumber(id) then
			return self.awords[i];
		end
	end
end

-- 清理销毁图标
function Lua_RewardItem:clearReward()
	for i = 1, #self.awords do
		self.awords[i]:dispose();
		self.awords[i] = nil;
	end
	self.awords = {};
end

-- 销毁
function Lua_RewardItem:dispose()
	self:clearReward();
	self:superCall("dispose");
end