--服务器列表 Data
Lua_ServerData = class("Lua_ServerData");

function Lua_ServerData:ctor()
    self.KEY_ZONE = "zone";
    self.KEY_SERVER = "server";
    self.KEY_USER = "user";

    self:dispose();
end

function Lua_ServerData:dispose()
    self.selectServerData = nil;
    self.selectTitleIdx = nil;

    self.isBan = false;

    self.allZoneList = Array();
    self.allServerDic = {};
    self.myServerList = Array();

    self.serverRoleData = nil;
end

function Lua_ServerData:readFromJson(json)
    if json == nil or json[self.KEY_ZONE] == nil or json[self.KEY_SERVER] == nil then
        print("服务器列表解析失败");
        return;
    end

    self:dispose();

    local zoneList = json[self.KEY_ZONE];
    local serverList = json[self.KEY_SERVER];
    print("server len = ", #serverList);
    for i = 1, #serverList do
        local serverVo = Lua_OneServerVo.new(serverList[i]);
        local str = tonumber(serverVo.zone);
        serverVo.zoneName = tostring(zoneList[str]);
        if self.allServerDic[str] == nil then
            self.allServerDic[str] = Array();
        end
        self.allServerDic[str]:add(serverVo);

        -- 已有角色服务器
        if serverVo.roleList ~= nil and serverVo.roleList:getSize() > 0 then
            self.myServerList:add(serverVo);
        end
    end

    local btnListVo;
    if self.myServerList:getSize() > 0 then -- 我的服务器
        btnListVo = Lua_ServerBtnListVo.new();
        btnListVo.name = LanUtil.getValue(123608);
        btnListVo.zone = -1;
        self.allZoneList:add(btnListVo);
    end

    for k, v in pairs(zoneList) do
        btnListVo = Lua_ServerBtnListVo.new();
        btnListVo.zone = tonumber(tostring(k));
        btnListVo.name = tostring(v);
        self.allZoneList:add(btnListVo);
    end
    self.allZoneList:sort("zone", false);

    local userInfo = json[self.KEY_USER];
    ServerConfig.userID = userInfo.openId;

    if userInfo.callback ~= nil then
        ServerConfig.Callback37 = tostring(userInfo.callback);
    end
    if userInfo.package ~= nil then
        ServerConfig.market = tonumber(tostring(userInfo.package));
        SDKPlatform.ChannelID = tostring(userInfo.package);
    end
    if userInfo.guid ~= nil then
        ServerConfig.Chenglu_guid = userInfo.guid;
    end
    if userInfo.channel ~= nil then
        ServerConfig.channel = userInfo.channel;
    end

    self.isBan = false;
    if userInfo.is_ban ~= nil then -- is_ban=1就是被封
        if tonumber(tostring(userInfo.is_ban)) == 1 then
            self.isBan = true;
        end
    end
end

function Lua_ServerData.Get:getDefaultServer()
    local st = 0;
    local rs = nil;
    local defaultRs = nil;
    local firstRs = nil;
    local sltServer = UnityEngine.PlayerPrefs.GetString("selectServer");

    for k, list in pairs(self.allServerDic) do
        for i = 1, list:getSize() do
            local os = list[i];
            if os.flag == sltServer then
                return os;
            end

            if os.defaultV == 1 then
                defaultRs = os;
            elseif st <= os.open_time and os.online < os.max_online then
                if st == os.open_time then
                    if rs ~= nil and rs.online > os.online then
                        st = os.open_time;
                        rs = os;
                    end
                else
                    st = os.open_time;
                    rs = os;
                end
            end

            if firstRs == nil then -- 防止一个都没有
                firstRs = os;
            end
        end
    end
    if self.myServerList:getSize() > 0 then
        return self.myServerList[1];
    elseif defaultRs ~= nil then
        return defaultRs;
    elseif rs ~= nil then
        return rs;
    elseif firstRs ~= nil then
        return firstRs;
    end
    return nil;
end










Lua_ServerBtnListVo = class("Lua_ServerBtnListVo");

function Lua_ServerBtnListVo:ctor()
    self.name = nil;
    self.zone = nil;
    self.index = nil;
    self.selected = nil;
end







Lua_ServerRoleData = class("Lua_ServerRoleData");

function Lua_ServerRoleData:ctor()
    self.role_name = nil;
    self.level = nil;
    self.gender = nil;
end







Lua_OneServerVo = class("Lua_OneServerVo");

function Lua_OneServerVo:ctor(config)
    self.config = config;

    self.zoneName = nil;
    self.role_List = nil;
    self._open_time = -1;
    self.signStates = string.split(LanUtil.getValue(123610), '、');
    self.statesIcon = string.split(LanUtil.getValue(123623), '、');
end

function Lua_OneServerVo:getStringValue(str)
    if str == nil or str == "" then
        return nil;
    end

    str = self.config[str];
    if str ~= nil then
        return tostring(str);
    end
    return nil;
end

function Lua_OneServerVo:getIntValue(str)
    if str == nil or str == "" then
        return 0;
    end

    str = self.config[str];
    if str ~= nil then
        return tonumber(tostring(str));
    end
    return 0;
end

function Lua_OneServerVo.Get:name()
    return self:getStringValue("name");
end

function Lua_OneServerVo.Get:is_create_role()
    return self:getIntValue("is_create_role");
end

function Lua_OneServerVo.Get:flag()
    return self:getStringValue("flag");
end

function Lua_OneServerVo.Get:server_addr()
    return self:getStringValue("server_addr");
end

function Lua_OneServerVo.Get:server_port()
    return self:getIntValue("server_port");
end

function Lua_OneServerVo.Get:chat_addr()
    return self:getStringValue("chat_addr");
end

function Lua_OneServerVo.Get:text()
    return self:getStringValue("text");
end

function Lua_OneServerVo.Get:sign()
    return self:getStringValue("sign");
end

function Lua_OneServerVo.Get:open_time()
    return self:getIntValue("open_time");
end

function Lua_OneServerVo.Get:defaultV()
    return self:getIntValue("default");
end

function Lua_OneServerVo.Get:chat_port()
    return self:getIntValue("chat_port");
end

function Lua_OneServerVo.Get:roleList()
    if self._roleList == nil then
        self._roleList = Array();
        if self.is_create_role == 1 then
            local list = self.config.role_list;
            if list ~= nil and #list > 0 then
                for i = 1, #list do
                    local obj = list[i];
                    local roleData = Lua_ServerRoleData.new();
                    roleData.role_name = tostring(obj.role_name);
                    roleData.level = tonumber(tostring(obj.level));
                    roleData.gender = tonumber(tostring(obj.gender));
                    self._roleList:add(roleData);
                end
            end
        end
    end
    return self._roleList;
end

function Lua_OneServerVo.Get:is_show()
    return self:getIntValue("is_show");
end

function Lua_OneServerVo.Get:online()
    return self:getIntValue("online");
end

-- -1:维护 0:未开服 2:流畅 4:火爆
function Lua_OneServerVo.Get:status()
    return self:getIntValue("status");
end

-- 0:无 1:新服 2:推荐
function Lua_OneServerVo.Set:ad_status(val)
    self._ad_status = val;
end

function Lua_OneServerVo.Get:ad_status()
    if self._ad_status ~= nil then
        return self._ad_status;
    end
    return self:getIntValue("ad_status");
end

function Lua_OneServerVo.Get:max_online()
    return self:getIntValue("max_online");
end

function Lua_OneServerVo.Get:zone()
    return self:getIntValue("zone");
end
function Lua_OneServerVo.Get:tick()
    return self:getIntValue("tick");
end

function Lua_OneServerVo.Get:sort()
    return self:getIntValue("sort");
end

function Lua_OneServerVo.Get:group_id()
    return self:getIntValue("group_id");
end

function Lua_OneServerVo.Get:getState()
    return self.signStates[self.ad_status + 1];
end

function Lua_OneServerVo.Get:getStateIcon()
    local num = self.status + 1;
    if num < 1 then
        num = 1;
    elseif num > self.statesIcon:getSize() then
        num = self.statesIcon:getSize();
    end
    return self.statesIcon[num];
end

function Lua_OneServerVo.Get:is_create()
    return self:getIntValue("is_create");
end