--登录模块 Proxy
checkRequire("Lua_LoginData");
checkRequire("Lua_ServerData");
Lua_LoginProxy = class("Lua_LoginProxy");

function Lua_LoginProxy:ctor()
	DataCenter.loginData = Lua_LoginData.new();
	DataCenter.serverData = Lua_ServerData.new();

	LuaUtil.addLuaMsg("80400101", self, self.aRoleEnterScene); -- 角色本人进入场景(主动)

    LuaUtil.addLuaMsg("50600101", self, self.rAddress); -- 网关登录验证(返回)
    LuaUtil.addLuaMsg("50600102", self, self.rCreateRoleBack); -- 创建角色(回复)
    LuaUtil.addLuaMsg("50600103", self, self.rLogin); -- 请求登录(返回)
    LuaUtil.addLuaMsg("50600105", self, self.rRandom); -- 选择随机名字(返回)
    LuaUtil.addLuaMsg("50600107", self, self.rRoleInfoUpdate); -- 账号信息（返回）
    LuaUtil.addLuaMsg("50700101", self, self.rGatewayValReturn); -- 验证模块的登录前验证(回复)
    LuaUtil.addLuaMsg("50999999", self, self.rConnectClose); -- 心跳包请求(返回)

    Lua_MsgUtil.addEventListener("START_LOGIN_GAME", self, self.onMainConnected);
    Lua_MsgUtil.addEventListener("GET_ANNOUNCEMENT_INFO", self, self.onGetAnnouncement);
    Lua_MsgUtil.addEventListener("LOGIN_BACK_SEVER_SELECTED", self, self.paltformLoginBack);

    MsgUtil.addEventListener("userInfoComplete", self, self.onUserInfoComplete);
    MsgUtil.addEventListener(EventsDefine.CONNECT_SUCCESS, self, self.valiConnected);
    MsgUtil.addEventListener(EventsDefine.RESET_ISRETURNLOGIN, self, self.onResetReturnLogin);

    self:dispose();
end

function Lua_LoginProxy:dispose()
	self.isTimer = false;
    self:onResetReturnLogin();
    self:clearHerat();
end

function Lua_LoginProxy:onResetReturnLogin()
    self._isReturnLogin1 = false;
    self._isReturnLogin2 = false;
end

function Lua_LoginProxy:clearHerat()
    self.isCheckHerat = false;
    self.checkHeartTime = 0;
    self.isReturnAddress = false;
end

-------------------------------------- 上行 --------------------------------------

-- 网关登录验证
function Lua_LoginProxy:sMainConnect()
	self.isTimer = false;
	Lua_CommonUtil.removeTimer(self, self.sMainConnect);

	local cmd = getProtoMsg("Proto10600101");
	cmd.account = ServerConfig.userID;
	cmd.session = ServerConfig.flag;
	cmd.tick = ServerConfig.time;
	cmd.platform = ServerConfig.paltform;
	cmd.agent = ServerConfig.channel;
	cmd.net_type = SDKInfo.NetState;

	if SDKInfo.SystemVersion ~= nil then
		cmd.sys_version = SDKInfo.SystemVersion;
	end
	if SDKInfo.PhoneModel ~= nil then
		cmd.sys_model = SDKInfo.PhoneModel;
	end
	if SDKInfo.MACAddress ~= nil then
		cmd.mac = SDKInfo.MACAddress;
	end
	
	cmd.c_sid = ServerConfig.sId;
	cmd.server_flag = ServerConfig.sign;
	cmd.market = ServerConfig.market;
	cmd.role_id = self.loginRoleId;
	-- cmd.pid = PlayerData.getInstance().pid;
	-- cmd.gid = PlayerData.getInstance().gid;
    
	local tokenStr;
	if Lua_PlatformUtil.IsAndroid() then
		-- tokenStr = PlayerData.getInstance().appcid;
		cmd.client_type = 1;
	elseif Lua_PlatformUtil.IsIPhonePlayer() then
		-- tokenStr = PlayerData.getInstance().push_token;
		cmd.client_type = 2;
	else
		cmd.client_type = 0;
	end
	if tokenStr ~= nil then
		cmd.token = tokenStr;
	end

	cmd.server_name = DataCenter.serverData.selectServerData.name;
	sendMsg(10600101, cmd);
end

-- 创建角色
function Lua_LoginProxy:sCreateRoleBack(name, sex, market, career)
    local cmd = getProtoMsg("Proto10600102");
    cmd.name = name;
    cmd.sex = sex;
    cmd.account = ServerConfig.userID;
    cmd.session = ServerConfig.flag;
    cmd.agent =  ServerConfig.channel;
    cmd.platform = ServerConfig.paltform;
    cmd.market = market;
    cmd.career = career;
    sendMsg(10600102, cmd);
end

-- 请求登录
function Lua_LoginProxy:sLogin()
	sendMsg(10600103);
end

-- 选择随机名字
function Lua_LoginProxy:sRandomName(sex)
	local cmd = getProtoMsg("Proto10600105");
	cmd.sex = sex;
	sendMsg(10600105, cmd);
end

-- 账号信息
function Lua_LoginProxy:sGetRoleInfo(socketType)
	if socketType ~= Connection.MAIN_SOCKET then
		return;
	end

	local cmd = getProtoMsg("Proto10600107");
	cmd.account = ServerConfig.userID;
	cmd.session = ServerConfig.flag;
	sendMsg(10600107, cmd);

	GlobalVar.fromReConnect = GlobalVar.reconnect == 1;
	ConnectionManager.getInstace():stopReconnect();
end

-- 验证模块的登录前验证
function Lua_LoginProxy:sGatewayValReturn(account, session, tick, socketType)
    local cmd = getProtoMsg("Proto10700101");
    cmd.account = account;
    cmd.session = session;
    cmd.tick = tick;
    print("请求进入服务器：account:", account, "session:", session, "tick:", tick, "socketType:", socketType);
    sendMsg(10700101, cmd, socketType);

    self:clearHerat();
end

-- 心跳包请求
function Lua_LoginProxy:sConnectClose()
    -- print(ConnectionManager.getInstace():isConnection(Connection.MAIN_SOCKET),self.isCheckHerat,self.checkHeartTime,self.isReturnAddress);
	if ConnectionManager.getInstace():isConnection(Connection.MAIN_SOCKET) == true then
		sendMsg(10999999);
	end

    if self.isReturnAddress and self.isCheckHerat then
        self.checkHeartTime = self.checkHeartTime + 1;
    end

    if self.checkHeartTime >= 5 then
        self.checkHeartTime = 0;
        CommonUtil.logError("心跳包报错");
        ConnectionManager.getInstace():errorAlert(LanUtil.getValue(10003), true);
    end
    self.isCheckHerat = true;
end







-------------------------------------- 下行 --------------------------------------

-- 角色本人进入场景(主动)
function Lua_LoginProxy:aRoleEnterScene(mp)
	local msg = ProtoPublic_pb.Proto80400101();
    msg:ParseFromString(mp.data);

	PlayerData.getInstance():initData(mp);

	GlobalVar.cur_tick = msg.cur_tick;
	self:onUserInfoComplete();
    
    DataCenter.sdkInterface:UpdatePlayerInfo(msg.create_time);
end

-- 网关登录验证(返回)
function Lua_LoginProxy:rAddress(mp)
	if mp.errno == 0 then
		local msg = ProtoPublic_pb.Proto50600101();
    	msg:ParseFromString(mp.data);

        self.isReturnAddress = true;

		if tonumber(tostring(msg.role_id)) == 0 and self.loginRoleId ~= 0 then
			if self.isTimer == false then
				self.isTimer = true;
				Lua_CommonUtil.addTimer("sMainConnect", 1.5, self, self.sMainConnect);
			end
			return;
		end

		DataCenter.loginData:addAddress(msg.scene_addrs);

		if GlobalVar.reconnect == 1 then
			self:sLogin();
		end

		if tonumber(tostring(msg.role_id)) ~= 0 then
			Lua_WindowUtil.openWin("LoginBgWindow", WinParam.ACTION_CLOSE);
			Lua_WindowUtil.openWin("Lua_ActivityIndicatorWindow", WinParam.ACTION_CLOSE);
			Lua_WindowUtil.openWin("Lua_ServerSelectWindow", WinParam.ACTION_CLOSE);
			Lua_WindowUtil.openWin("Lua_CreateRoleWindow", WinParam.ACTION_CLOSE);
			Lua_WindowUtil.openWin("Lua_SelectRoleWindow", WinParam.ACTION_CLOSE);
    	end

    	if msg.ban_type ~= 0 then
    		local str1;
    		local str2;
    		if msg.ban_type == 1 then
    			str1 = LanUtil.getValue(10020);
    			str2 = LanUtil.getValue(10023);
    		elseif msg.ban_type == 2 then
    			str1 = LanUtil.getValue(10021);
    			str2 = LanUtil.getValue(10023);
    		elseif msg.ban_type == 3 then
    			str1 = LanUtil.getValue(10022);
    			str2 = LanUtil.getValue(10023);
    		elseif msg.ban_type == 5 then
    			str1 = LanUtil.getValue(10021);
    			str2 = LanUtil.getValue(10024);
    		elseif msg.ban_type == 7 then
    			str1 = LanUtil.getValue(10025);
    			str2 = LanUtil.getValue(10023);
    		end

    		local tipData = {};
    		tipData.type = 1;
    		tipData.titleName = LanUtil.getValue(10008);
    		tipData.des = string.Format(LanUtil.getValue(10014), str1, str2, str2, (msg.left_ban_sec + 59) / 60);
    		Lua_WindowUtil.openWin("Lua_TipsWindow", WinParam.ACTION_OPEN, tipData);
    	end
    end
end

-- 创建角色(回复)
function Lua_LoginProxy:rCreateRoleBack(mp)
    if mp.errno == 0 then
        self:sLogin();
        DataCenter.sdkInterface.isCreateRole = true;
    end
end

--请求登录(返回)
function Lua_LoginProxy:rLogin(mp)
	print("请求登录返回");
    if mp.errno == 0 then
        self._isReturnLogin1 = true;
        self:enterNext();
    end
end

-- 选择随机名字(返回)
function Lua_LoginProxy:rRandom(mp)
	if mp.errno == 0 then
		local msg = ProtoPublic_pb.Proto50600105();
    	msg:ParseFromString(mp.data);
    	Lua_MsgUtil.callFunc("BACK_RANDOM_NAME", msg.name);
    end
end

-- 账号信息（返回）
function Lua_LoginProxy:rRoleInfoUpdate(mp)
	if mp.errno == 0 then
		local msg = ProtoPublic_pb.Proto50600107();
    	msg:ParseFromString(mp.data);

    	AudioManager.stopLogin("denglubgm");
    	GlobalVar.serverDefaultCareer = msg.career;
    	if msg.server_type == 1 then--不用选角创角直接进入
            self:doEnterGameDirect(msg);
        else
        	if msg.role_data == nil or #msg.role_data <= 0 then  --没角色才要创建
        		self:onMainConnected(0);
        		DataCenter.serverData.serverRoleData = nil;

        		Lua_WindowUtil.openWin("LoginBgWindow", WinParam.ACTION_CLOSE);
        		Lua_WindowUtil.openWin("Lua_ActivityIndicatorWindow", WinParam.ACTION_CLOSE);
        		Lua_WindowUtil.openWin("Lua_CreateRoleWindow", WinParam.ACTION_OPEN);
        		Lua_WindowUtil.openWin("Lua_ServerSelectWindow", WinParam.ACTION_CLOSE);
        		Lua_WindowUtil.openWin("Lua_SelectRoleWindow", WinParam.ACTION_CLOSE);
           	else -- 有角色进入选角
            	if msg.role_data ~= nil and #msg.role_data < 3 then-- 用于增加角色而创角需要
                    self:onMainConnected(0);
                end

                table.sort(msg.role_data, function(a, b)
                	local aWeight = a.level * 1000 + a.career * 100 + strlen(a.name);
					local bWeight = b.level * 1000 + b.career * 100 + strlen(b.name);
					return aWeight > bWeight;
            	end);
            	
                DataCenter.serverData.serverRoleData = msg.role_data;
 
                Lua_WindowUtil.openWin("LoginBgWindow", WinParam.ACTION_CLOSE);
                Lua_WindowUtil.openWin("Lua_ActivityIndicatorWindow", WinParam.ACTION_CLOSE);
                Lua_WindowUtil.openWin("Lua_ServerSelectWindow", WinParam.ACTION_CLOSE);
                Lua_WindowUtil.openWin("Lua_CreateRoleWindow", WinParam.ACTION_CLOSE);

                if GlobalVar.fromReConnect == true then
                    self:onMainConnected(GlobalVar.roleId)
                else
                	Lua_WindowUtil.openWin("Lua_SelectRoleWindow", WinParam.ACTION_OPEN, msg.role_data);
                end
            end
        end
    end
end

-- 跳过创角选角处理
function Lua_LoginProxy:doEnterGameDirect(msg)
    Lua_WindowUtil.openWin("LoginBgWindow", WinParam.ACTION_CLOSE);
    Lua_WindowUtil.openWin("Lua_ActivityIndicatorWindow", WinParam.ACTION_CLOSE);
    Lua_WindowUtil.openWin("Lua_ServerSelectWindow", WinParam.ACTION_CLOSE);
    Lua_WindowUtil.openWin("Lua_CreateRoleWindow", WinParam.ACTION_CLOSE);

    if msg.role_data == nil or #msg.role_data <= 0 then  --没角色先创建
        self:onMainConnected(0);

        local market;
        if Lua_PlatformUtil.IsWindowsEditor or Lua_PlatformUtil.IsWindowsPlayer then
            local s = SDKPlatform.ChannelID;
            if s == nil or s == "" then
                s = "0";
            end
            market = tonumber(s);
        else
            market = ServerConfig.market;
        end
        self:sCreateRoleBack(name, msg.rand_name, market, msg.career == 2 and 1 or 2);
    else
        self:sRandomName(tonumber(tostring(msg.role_data[1].role_id)));
    end
end

--验证模块的登录前验证(回复)
function Lua_LoginProxy:rGatewayValReturn(mp)
    Lua_CommonUtil.addTimer("onHeart", 5, self, self.sConnectClose);
    if mp.errno == 0 then
        local con = ConnectionManager.getInstace():getConnection(Connection.VALIDATION_SOCKET);
        if con:isConnect() == true then
            ConnectionManager.getInstace():closeConnenction(Connection.VALIDATION_SOCKET);
        end

        local msg = ProtoPublic_pb.Proto50700101();
        msg:ParseFromString(mp.data);
        local hostname = msg.domain;
        if LanUtil.IsNullOrEmpty(hostname) ~= true then
            local str = ConnectionManager.getInstace():decodeServerAddresses(hostname);
            if str == nil or str == "" then
                ServerConfig.single_server = hostname;
            else
                ServerConfig.single_server = str;
            end
        else
            ServerConfig.single_server = msg.gate_ip;
        end
        ServerConfig.single_port = msg.gate_port;
        ConnectionManager.getInstace():connectionSocket(Connection.MAIN_SOCKET, ServerConfig.single_server, ServerConfig.single_port, true, true);
    end
end

-- 心跳包请求(返回)
function Lua_LoginProxy:rConnectClose(mp)
	local msg = ProtoPublic_pb.Proto50999999();
	msg:ParseFromString(mp.data);

    self.isCheckHerat = false;
    self.checkHeartTime = 0;

	if mp.errno < -9900 then -- 当接收到-99XX时，服务器会主动断开客户端连接
		local tipsStr = "服务端主动断开socket " .. mp.errno .. ",drop_reason:" .. msg.drop_reason;

		local tipData = {};
		tipData.type = 2;
		tipData.titleName = LanUtil.getValue(10008);
		tipData.des = tipsStr
		Lua_WindowUtil.openWin("Lua_TipsWindow", WinParam.ACTION_OPEN, tipData);

		OperateAlert.show(tipsStr);
	end

   	if msg.drop_reason == 1 then--顶号
   		ConnectionManager.getInstace():errorAlert(LanUtil.getValue(10026), false);
   	elseif msg.drop_reason == 2 then--服务端掉线
        CommonUtil.logError("服务端掉线");
        ConnectionManager.getInstace():errorAlert(LanUtil.getValue(10003), false);
    elseif msg.drop_reason == 3 then--封禁
        local str = nil;
        if msg.ban_type == 1 then--账户
            str = LanUtil.formateStr(LanUtil.getValue(10027), LanUtil.getValue(10020));
        elseif msg.ban_type == 2 then--角色
            str = LanUtil.formateStr(LanUtil.getValue(10027), LanUtil.getValue(10021));
        elseif msg.ban_type == 3 then--IP
            str = LanUtil.formateStr(LanUtil.getValue(10027), LanUtil.getValue(10022));
        elseif msg.ban_type == 7 then--MAC
            str = LanUtil.formateStr(LanUtil.getValue(10027), LanUtil.getValue(10025));
        end

        if str == nil then
            CommonUtil.logError("封禁");
        	str = LanUtil.getValue(10003);
        end
        ConnectionManager.getInstace():errorAlert(str, false);
    end
end  



















-------------------------------------- 调用方法 --------------------------------------

function Lua_LoginProxy:onMainConnected(roleId)
	if roleId == nil then
		return;
	end
	self.loginRoleId = tonumber(tostring(roleId));
	self:sMainConnect();
end

function Lua_LoginProxy:valiConnected(socketType)
    if socketType == Connection.VALIDATION_SOCKET then
       self:sGatewayValReturn(ServerConfig.userID, ServerConfig.flag, ServerConfig.time, socketType);
    end
    self:sGetRoleInfo(socketType);
end

function Lua_LoginProxy:onUserInfoComplete()
    self._isReturnLogin2 = true;
    self:enterNext();
end

function Lua_LoginProxy:enterNext()
    DataCenter.serverData.serverRoleData = nil;
    GlobalVar.bShowAnnouncement = false;
    CreateRoleModel.DestoryCreateRoleModel();
    CreateRoleSceneController.DestoryCreateRoleScene();
    
    local main_camera = UnityEngine.Camera.main;
    main_camera.nearClipPlane = 0.3;
    main_camera.farClipPlane = 60;
    main_camera.fieldOfView = 40;
    LuaUtil.setObjPos(main_camera.gameObject, 0, 0, 0);
    LuaUtil.setObjRot(main_camera.gameObject, 0, 0, 0);

    local main_cameraRoot = ContainerUtil.getConainer("camRoot");
    LuaUtil.setObjPos(main_cameraRoot, 0, 0, 0);
    LuaUtil.setObjRot(main_cameraRoot, 0, 0, 0);

    if self._isReturnLogin1 == false then
        return;
    end

    if self._isReturnLogin2 == false then
        return;
    end

    if LuaManager.getInstance().isBind == false then
        LuaManager.getInstance().setWaitBind();
        return;
    end

    Lua_WindowUtil.openWin("LoadingScreenWindow", WinParam.ACTION_CLOSE);
    Lua_WindowUtil.openWin("LoginBgWindow", WinParam.ACTION_CLOSE);
    Lua_WindowUtil.openWin("Lua_ActivityIndicatorWindow", WinParam.ACTION_CLOSE);
    Lua_WindowUtil.openWin("Lua_CreateRoleWindow", WinParam.ACTION_CLOSE);
    Lua_WindowUtil.openWin("Lua_ServerListWindow", WinParam.ACTION_CLOSE);
    Lua_WindowUtil.openWin("Lua_ServerSelectWindow", WinParam.ACTION_CLOSE);

    ConfigManager.getInstance():loadOtherConfig();
    if GlobalVar.gameWorld == nil then
        GlobalVar.initGameWord();
    end
    self:onResetReturnLogin();
end

-------------------------------------- SDK账号登入 --------------------------------------

function Lua_LoginProxy:paltformLoginBack(obj)
    Lua_WindowUtil.openWin("Lua_ServerSelectWindow", WinParam.ACTION_OPEN);
end


-------------------------------------- 公告处理 --------------------------------------

function Lua_LoginProxy:onGetAnnouncement()
    print("wonGetAnnouncement", GlobalVar.announcementContents);
    if LanUtil.IsNullOrEmpty(GlobalVar.announcementContents) then
        local formData = {};
        formData.func = "notice";
        formData.package = ServerConfig.market;
        local tokenstr = decodeTabToJson(formData);
        print("公告打印===" .. tokenstr);
        UploadManager.getInstance():uploadPhpPost(UrlManager.prefixRequestStr, tokenstr, self, self.loadAnnouncementComplete, nil, true);
    else
        self:showAnnouncementWin(GlobalVar.announcementContents);
    end
end

function Lua_LoginProxy:loadAnnouncementComplete(text)
    if LanUtil.IsNullOrEmpty(text) then
        return;
    end
    GlobalVar.announcementContents = text;
    self:showAnnouncementWin(text);
end

function Lua_LoginProxy:showAnnouncementWin(text)
    if text == nil then
        return;
    end

    local jsonObj = decodeJson(text);
    if jsonObj.category ~= nil and jsonObj.category ~= 1 then
        Lua_MsgUtil.callFunc("AnnouncementInfoUpdate", GlobalVar.announcementContents);
    elseif jsonObj.content ~= nil then
        Lua_WindowUtil.openWin("Lua_AnnouncementWindow", WinParam.ACTION_OPEN, jsonObj);
    end
end
