-- SDK接口
checkRequire("Lua_SDKMessageType");
Lua_SDKInterface = class("Lua_SDKInterface");
local SDKInterface = SDKInterface;

function Lua_SDKInterface:ctor()
	self.isCreateRole = false;
	self.login_token = nil;

	self:initEvents();
end

------------------------------------- 下发 -------------------------------------

function Lua_SDKInterface:initEvents()
	MsgUtil.addEventListener(EventsDefine.SDK_MESSAGE_UPDATE, self, self.onSDKMessage); -- sdk通知
end

-- sdk下发，json格式
-- {"func":"标识","param":"参数集合"}
function Lua_SDKInterface:onSDKMessage(msg)
	if msg == nil or msg == "" then
		return;
	end
	print("onSDKMessage,msg:",msg);
	local dic = decodeJson(msg);
    if dic == nil then
    	return;
    end
    local func = dic.func;
    local param;
    if dic.param ~= nil then
    	param = decodeJson(dic.param);
    end
    print("onSDKMessage,func:",func,",param:",param);
    if func == Lua_SDKMessageType.netState then -- 1网络状态
    	SDKInfo.NetState = param.netState;
        if param.netState == Lua_SDKMessageType.NO_NET and GlobalVar.reconnect == 0 and GlobalVar.isInGame == 1 then
            ConnectionManager.getInstace():errorAlert(LanUtil.getValue(10003), true);
        end
    elseif func == Lua_SDKMessageType.phoneinfo then -- 2设备信息
    	SDKInfo.MACAddress = param.mac;
    	SDKInfo.Imei = param.imei;
    	SDKInfo.PhoneModel = param.sys_model;
    	SDKInfo.SystemVersion = param.sys_version;
    	SDKInfo.AvailMemory = param.avail_memory;
    	SDKInfo.CustomDevice = param.custom_device;
    	SDKInfo.OpenGL = param.openGl;
    elseif func == Lua_SDKMessageType.login then -- 3登陆回传
    	self.login_token = dic.param;
    	Lua_MsgUtil.callFunc("LOGIN_BACK_SEVER_SELECTED");
    elseif func == Lua_SDKMessageType.changeuser then -- 4切换用户
    	self.login_token = dic.param;
        ConnectionManager.getInstace():sdkLoginOut();
    elseif func == Lua_SDKMessageType.logout then -- 5注销
    	self.login_token = nil;
    	ConnectionManager.getInstace():sdkLoginOut();
    elseif func == Lua_SDKMessageType.ScreenHeight then -- 6回传刘海高度
   		local height = param;
    	if height ~= nil and type(height) ~= "number" then
    		height = param.ScreenHeight;
    	end
    	if height ~= nil and type(height) == "number" and height ~= 0 then
    		ServerConfig.SdkLiuhaiHight = height;
    	end
    elseif func == Lua_SDKMessageType.Openalbum then -- 7上传头像地址
    	MsgUtil.callFunc("SELECT_FILE", param.imagepath);
    end
end

------------------------------------- 上传 -------------------------------------

-- 调用sdk接口, dic为table
function Lua_SDKInterface:callSDKInterfaceTab(methobName, dic)
	local paramJsonStr = nil;
	if dic ~= nil then 
		paramJsonStr = decodeTabToJson(dic) 
	end
	self:callSDKInterface(methobName, paramJsonStr)
end

function Lua_SDKInterface:callSDKInterface(methobName, paramJsonStr)
	if paramJsonStr == nil then
		paramJsonStr = "";
	end
	SDKInterface.CallSDKInterface(methobName, paramJsonStr);
end







------------------------------------- 充值接口 -------------------------------------

-- conf_id:1正常
-- money_type:货币类型 1 人民币 2美金 3台币 4韩币 5越南币 6新加坡币 7泰铢
function Lua_SDKInterface:PointOut(goldNum, money, conf_id, money_type)
	conf_id = conf_id == nil and 1 or conf_id;
	money_type = money_type == nil and 2 or money_type;
	
   	local formData = {
   		getOrderId = 1,
    	server = ServerConfig.sign,
    	package = tostring(ServerConfig.market),
    	role_id = DataCenter.roleData.roleId,
    	money = money,
    	money_type = money_type,
    	account = ServerConfig.userID,
    	conf_id = conf_id,
    	role_level = DataCenter.roleData.level,
    	mac = ServerConfig.mac,
    	gold = goldNum
    };

	if Lua_PlatformUtil.IsAndroid() then
		formData.imei = SDKInfo.Imei;
	elseif Lua_PlatformUtil.IsIPhonePlayer() then
		formData.idfa = SDKInfo.Idfa;
    end

   	-- 获取订单号
  	local tokenstr = decodeTabToJson(formData);
    if Lua_PlatformUtil.IsIPhonePlayer() then -- ios sdk自己获取单号
    	self:callSDKInterface(Lua_SDKMessageType.PointOut, tokenstr);
    else
    	local extParam = tokenstr;
    	UploadManager.getInstance():uploadPhpPost(UrlManager.prefixRequestCallbackStr, tokenstr, extParam, self, self.loadServerComplete, self.loadServerError, true);
    end
end

function Lua_SDKInterface:loadServerComplete(text, extParam)
	if strIsNullOrEmpty(text) or strIsNullOrEmpty(extParam) then
		print("请求订单错误--", text, "extParam--", extParam);
		return;
	end

	local dictionary = decodeJson(text);
	if dictionary == nil then
		print("请求订单号text Json解析失败", text, extParam);
		return;
	end

	local error = dictionary.error;
    if not strIsNullOrEmpty(error) then
        print("请求订单号失败：", error, text, extParam);
        return;
    end

    local extParamDic = decodeJson(extParam);
    if extParamDic == nil then
    	print("请求订单号extParam Json解析失败", text, extParam);
    	return;
    end

   	if Lua_PlatformUtil.IsAndroid() or Lua_PlatformUtil.IsIPhonePlayer() then
		if SDKPlatform.IsNoSdk then
			self:testEditorRecharge(dictionary.order_id, extParamDic.money);
			return;
		end

		local formData = {};
    	formData.money = extParamDic.money;
    	formData.server = extParamDic.server;
    	formData.vip = DataCenter.roleData.vip;
    	formData.fighting = DataCenter.roleData.force;
    	formData.gold = extParamDic.gold;
    	formData.account = extParamDic.account;
		dictionary.myParam = formData;
		self:callSDKInterface(Lua_SDKMessageType.PointOut, decodeTabToJson(dictionary));
	else
		local linkUrl = dictionary.links;
        if not strIsNullOrEmpty(linkUrl) then -- 跳转
            UnityEngine.Application.OpenURL(linkUrl);
            return;
        end
        self:testEditorRecharge(dictionary.order_id, extParamDic.money);
    end
end

function Lua_SDKInterface:testEditorRecharge(order_id, rechargeNum)
   	local url = UrlManager.FIX_HTTP .. ServerConfig.center_server .. "/single/charge/package/" .. ServerConfig.market .. "?extends=" .. order_id .. "|" .. ServerConfig.sign;
    LoadManager.getInstance():Load(Lua_LoadFileType.JSON, url, true);
    print("testEditorRecharge: ", url);
end

function Lua_SDKInterface:loadServerError(text, extParam)
    print("请求订单错误--", text, extParam);
end

------------------------------------- 上报玩家信息 -------------------------------------

function Lua_SDKInterface:UpdatePlayerInfo(create_time)
	local data = DataCenter.roleData;
    local dic = {};
    dic.roleId = data.roleId;
    dic.roleName = data.name;
    dic.roleLevel = data.level;
    dic.zoneId = ServerConfig.serverId;
    dic.zoneName = ServerConfig.serverName;
    dic.balance = DataCenter.moneyData:getMoney(Lua_MoneyData.GOLD);
    dic.vip = data.vipType;
    dic.partyName = data.league_name;
    dic.roleCTime = create_time;
    dic.fighting = data.force;
    local playerInfo = decodeTabToJson(dic);
    if self.isCreateRole then
    	self.isCreateRole = false;
    	self:callSDKInterface(Lua_SDKMessageType.CreateRole, playerInfo);
    end
    self:callSDKInterface(Lua_SDKMessageType.UpdatePlayerInfo, playerInfo);
end