-- 一生一世
Lua_AllOneIsLlifePanel = class("Lua_AllOneIsLlifePanel", Lua_DisplayObject)
function Lua_AllOneIsLlifePanel:ctor(p)
	self:superCall("ctor", p, "AllOneIsLlifePanel_skin");
end

function Lua_AllOneIsLlifePanel:buildShowItem()
	self:superCall("buildShowItem");

	self.leftDragList = Lua_DragList.new(self.content,1, Vector4(0, 0, 250, 375));
	self.leftDragList:setListCell(Lua_AllOneIsLlifeLeftItem, 103, 250, 1);
	self.leftDragList:setLocation(-384, -52, 0);

	self.rightDragList = Lua_DragList.new(self.content,1, Vector4(0, 0, 740, 285));
	self.rightDragList:setListCell(Lua_AllOneIsLlifeRightItem, 120, 750, 1);
	self.rightDragList:setLocation(113, -103, 0);

	self:addLuaEvent("UPDATE_ONEPANEL_DATA", self, self.updatePanelInfo);
end

function Lua_AllOneIsLlifePanel:updatePanelInfo()
	if DataCenter.OpenDressCarnivalData.first_type ~= self.first_type then
		return;
	end

	self.eTimeNum = DataCenter.OpenDressCarnivalData.stop_tick; -- 活动结束时间
	self.times = DataCenter.OpenDressCarnivalData.times; -- 服务器当前时间戳（客户端使用）

	local start_tick = DataCenter.OpenDressCarnivalData.start_tick; -- 活动开始时间
	local atimeStr1 =  TimeTransform.getInstance():transSeconds8(start_tick, "yyyy-MM-dd HH:mm");
	local atimeStr2 =  TimeTransform.getInstance():transSeconds8(self.eTimeNum, "yyyy-MM-dd HH:mm");
	local etimeStr =  TimeTransform.getInstance():transSeconds1((self.eTimeNum - self.times), true);
	self.open_time.text = LanUtil.formateStr(LanUtil.getValue(127300), tostring(atimeStr1.."--"..atimeStr2));
	self.end_time.text = LanUtil.formateStr(LanUtil.getValue(127301), tostring(etimeStr));

	local content = DataCenter.OpenDressCarnivalData.content; -- 活动描述
	self.tips.text = LanUtil.formateStr(LanUtil.getValue(127302), tostring(content));

	local left_current = DataCenter.OpenDressCarnivalData.left_current; -- 甜蜜度
	self.leftCurrent.text = LanUtil.formateStr(LanUtil.getValue(127303), tostring(left_current));

	Lua_CommonUtil.addTimer("allOneIsLlife_Timer", 1, self,self.onTimeStrTimer);

	local left_data =  DataCenter.OpenDressCarnivalData.getAllOneIsLlifeLeftData;
	local right_data =  DataCenter.OpenDressCarnivalData.getOpenCommonData;
	self.leftDragList:setLuaArrayData(left_data, false);
	self.rightDragList:setLuaArrayData(right_data, false);
end

function Lua_AllOneIsLlifePanel:onTimeStrTimer()
	self.eTimeNum = self.eTimeNum - 1;
	if self.eTimeNum - self.times > 0 then
		local etimeStr = TimeTransform.getInstance():transSeconds1(self.eTimeNum - self.times, true);
		self.end_time.text = LanUtil.formateStr(LanUtil.getValue(127301), etimeStr);
	else
		Lua_CommonUtil.removeTimer(self, self.onTimeStrTimer);
	end
end

function Lua_AllOneIsLlifePanel:dispose()
	if self.leftDragList ~= nil then
		self.leftDragList:dispose()
		self.leftDragList = nil;
	end
	if self.rightDragList ~= nil then
		self.rightDragList:dispose()
		self.rightDragList = nil;
	end
	Lua_CommonUtil.removeTimer(self, self.onTimeStrTimer);

	self:superCall("dispose");
end





--------------------------------------------------





Lua_AllOneIsLlifeLeftItem = class("Lua_AllOneIsLlifeLeftItem", Lua_ListCell);
function Lua_AllOneIsLlifeLeftItem:ctor(p)
	self:superCall("ctor", p, "AllOneIsLlifeLeftItem_skin");
end

function Lua_AllOneIsLlifeLeftItem:buildShowItem()
	self:superCall("buildShowItem");

	self.subBtn:addClickFuntion(self, self.onGetBtnClick);
end

function Lua_AllOneIsLlifeLeftItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	self.countNum.text = data.title_name;
	self.numberTxt.text = data.left_count_num.."/".. data.right_max_num;

	self.actConfigInfo = DataCenter.OpenDressCarnivalData:getOpenDressDate(tonumber(data.task_id));
	if self.actConfigInfo.icon ~= nil and self.actConfigInfo.is_special ~= 1 then
		self.icon:setAltas(self.actConfigInfo.atlas, self.actConfigInfo.icon);
		self.icon:SetDimensions(74, 74);
	else
		self.icon:setAltas("mailboxwindow_atlas", "ui_friend_icon_04");
		self.icon:resetSize();
	end
	self.subBtn.label = self.actConfigInfo.button_name;
end

function Lua_AllOneIsLlifeLeftItem:onGetBtnClick()
	local open_id = self.actConfigInfo.open_fun;
	if DataCenter.funcOpenData:isOpened(open_id) ~= true then
		local tips = getConfig({"func_open", open_id, "advance_message"});
		OperateAlert.show(tips);
		return;
	end

	local winName =  self.actConfigInfo.winName;
	local num =  self.actConfigInfo.num;
	if num ~= -1 then
		Lua_WindowUtil.openWin(winName, WinParam.ACTION_OPEN, num);
	else
		Lua_WindowUtil.openWin(winName, WinParam.ACTION_OPEN);
	end
	Lua_WindowUtil.openWin("Lua_OpenDressCarnivalWindow", WinParam.ACTION_CLOSE);
end

function Lua_AllOneIsLlifeLeftItem:dispose()
	self:superCall("dispose");
end





--------------------------------------------------





Lua_AllOneIsLlifeRightItem = class("Lua_AllOneIsLlifeRightItem", Lua_ListCell);
function Lua_AllOneIsLlifeRightItem:ctor(p)
	self:superCall("ctor", p, "AllOneIsLlifeRightItem_skin");
end

function Lua_AllOneIsLlifeRightItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rItem = Lua_RewardItem.new(self.content);
	self.rItem:setLayout(70, 70, 6);
	self.rItem:setDepth(3);
	self.rItem:setMaxShow(6);
	self.rItem:setClickWin(true);
	self.rItem:setMouseEnble(true);
	self.rItem:setItemScale(0.85, 0.85);
	self.rItem:setLocation(-316, -15);

	self.redDot = UICreate.createUIAtlasImage(self.content,"common_atlas_1", "ui_common_hongdian", 330, 21, 0, 0)
	self.redDot.name = "redDot";
	self.redDot:setDepth(6);
	self.redDot:setEnable(false);
	
	self.subBtn:addClickFuntion(self,self.onGetBtnClick);
end

function Lua_AllOneIsLlifeRightItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	self.countNum.text = data.title_name;

	local effList = data.spec_effect_item;
	local effDic = {};
	for i = 1, #effList do
		effDic[tonumber(effList[i])] = 1;
	end
	-- print(#effList, "Lua_AllOneIsLlifePanel");

	local obj;
	local tvo;
	local rewardInfoArr = Array();
	for i = 1, #data.reward_set do
		obj = data.reward_set[i];

		tvo = Lua_ToolVo.createToolVo(obj.id, obj.amount, obj.bind == 2 and 1 or obj.bind);
		tvo.packType = 999;
		tvo.star = obj.equipment.star;
		tvo.bShowItemBg = true;
		tvo.roundEffect = effDic[obj.id] == 1;
		rewardInfoArr:add(tvo);
	end
	self.rItem:setRewardByArray(rewardInfoArr);

	if data.isReward == 0 then -- 0未领取，1已领取，2表示条件不足
		self.getBg:setEnable(false);
	elseif data.isReward == 1 then
		self.getBg:setEnable(true);
		self.getBg:setAltas("common_atlas_1", "ui_common_b_");
	else
		self.getBg:setEnable(true);
		self.getBg:setAltas("common_atlas_3", "ui_common_b_yidahceng1");
	end
	self.subBtn:setEnable(data.isReward == 0);
	self.redDot:setEnable(data.isReward == 0);
end

function Lua_AllOneIsLlifeRightItem:checkOutBound(showRect)
	if self._data == nil then
		return;
	end

	local width = self.rItem.awords[1].item_bg.width * 0.85;
	local height = self.rItem.awords[1].item_bg.height * 0.85;
	local itemImg;
	local rect = Lua_Rectangle.new(self.itemX - width / 2, self.itemY - height / 2 - 15, width, height);
	for i = 1, #self._data.reward_set do
		itemImg = self.rItem:getToolImageById(self._data.reward_set[i].id)
		itemImg:showRoundEff(showRect:containeRect(rect) and itemImg.data.roundEffect);
	end
end

function Lua_AllOneIsLlifeRightItem:onGetBtnClick()
	local avo = DataCenter.OperationalActivitiesData:getActivitiesByType(1024, nil);
	if avo == nil then
		return;
	end
	DataCenter.OperationalActivitiesData:buyReward(avo.act_index, tonumber(self._data.reward_index), 1);
end

function Lua_AllOneIsLlifeRightItem:dispose()
	if self.rItem ~= nil then
		self.rItem:dispose();
		self.rItem = nil;
	end
	if self.redDot ~= nil then
		self.redDot:dispose();
		self.redDot = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end