-- 部位数据

Lua_ArmySoulHoleVo = class("Lua_ArmySoulHoleVo")
function Lua_ArmySoulHoleVo:ctor()
    self:superCall("ctor");
end

function Lua_ArmySoulHoleVo:formServer(obj)
	if obj == nil then
		return;
	end

	self.equip_id = obj.id;           -- 魂装id
    self.intensify_lvl = obj.level;   -- 强化等级
    self.part = obj.part;             -- 部位
    self.order = obj.order            -- 阶级
    self.bind = obj.bind;             -- 绑定状态
end

function Lua_ArmySoulHoleVo.Get:armyEquipVo()
	if self.equip_id ~= nil and self.equip_id ~= 0 then
		local vo = Lua_ToolVo.createToolVo(self.equip_id,1,self.bind);
		vo.army_part = self.part;
		vo.soul_order = self.order;
		if self.intensify_lvl >= self.max_intensify_lvl then
			vo.intensify_lvl = self.max_intensify_lvl;
		else
			vo.intensify_lvl = self.intensify_lvl;
		end
		vo.isShowIntensifyRed = self.isShowIntensifyRed;
		return vo;
	end
	
	return nil;
end

function Lua_ArmySoulHoleVo.Get:armyEquipConfig() -- 魂装配置
    local config = getConfig({"soul_clothe_info", self.equip_id});
    if config == nil then
        return nil;
    end
    return config;
end

function Lua_ArmySoulHoleVo.Get:getEquipProp() -- 装备属性
    if self.equip_id ~= nil and self.equip_id ~= 0 then
    	local list = {};
	    for k,v in ipairs(Lua_ThingDefine.params) do
	        local val1 = getConfig({"army_soul_prop", self.armyEquipConfig.base_prop[1], v});
	        local val3 = getConfig({"army_soul_prop", self.armyEquipConfig.intensify_prop[1], v});
	        if val1 ~= nil and val3 ~= nil then
	            local base;
	            local upGrade_prop = 0;
	            local intensify_prop = 0;

	            if self.armyEquipConfig.order_prop ~= nil then
	                local val2 = getConfig({"army_soul_prop", self.armyEquipConfig.order_prop[1], v});
	                if self.order > 0 then
	                    upGrade_prop = val2[self.order];  
	                end
	            end

	            if self.intensify_lvl > 0 then
	                intensify_prop = val3[self.intensify_lvl];
	            end

	           	local base_prop = val1[1];
	            base = base_prop + upGrade_prop + intensify_prop;
	            list[v] = base;
	        end
	    end

	    return list;
	end

    return nil;
end

function Lua_ArmySoulHoleVo.Get:getOrderProp() -- 升阶属性
    if self.equip_id ~= nil and self.equip_id ~= 0 then
    	local list = {};
    	local prop_id = getConfig({"soul_clothe_info", self.equip_id,"order_prop"});
    	if prop_id ~= nil  then
		    for k,v in ipairs(Lua_ThingDefine.params) do
		        local val = getConfig({"army_soul_prop", prop_id[1], v});
		        if val ~= nil then
		        	if self.order > 0 then
		        		list[v] = val[self.order];
		        	else
		        		list[v] = 0;
		        	end
		        end
		    end

		    return list;
		end
	end

    return nil;
end

---------------------------------------------------------------------------------------------------------------------------------------
-- 强化数据
function Lua_ArmySoulHoleVo.Get:army_lvl() -- 强化等级
	if self.intensify_lvl >= self.max_intensify_lvl then
		return "lv."..self.max_intensify_lvl;
	end
    return "lv."..self.intensify_lvl;
end

function Lua_ArmySoulHoleVo.Get:intensify_name() -- 强化名字
	if self.intensify_lvl >= self.max_intensify_lvl then
		return self.armyEquipVo.name.." lv."..self.max_intensify_lvl;
	end
    return self.armyEquipVo.name.." lv."..self.intensify_lvl;
end

function Lua_ArmySoulHoleVo.Get:max_intensify_lvl() -- 强化最大等级
    return self.armyEquipConfig.level_upper;
end

function Lua_ArmySoulHoleVo.Get:intensify_info() -- 强化消耗 数据
    local lvl;
    if self.isMaxLvl == true then
        lvl = self.intensify_lvl;
    else
        lvl = self.intensify_lvl+1;
    end
    return self.armyInfo:intensify_cost(lvl);
end

function Lua_ArmySoulHoleVo.Get:isMaxLvl() -- 是否达到最大强化等级
    if self.intensify_lvl >= self.max_intensify_lvl then
        return true;      
    end

     return false;
end

function Lua_ArmySoulHoleVo.Get:armyIntensifyProp() -- 军装强化
    local str = "";
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"army_soul_prop", self.armyEquipConfig.intensify_prop[1], v});
        if val ~= nil then
            if str == "" then
                str = "";
            else
                str = str.."\n";
            end
            local base = 0;
            if self.intensify_lvl > 0 then
            	if self.intensify_lvl >= self.max_intensify_lvl then
					self.intensify_lvl = self.max_intensify_lvl;
				end
                base = val[self.intensify_lvl];
            end
            if Lua_ThingDefine.isPercentParam(v) then
                base = base.."%";
            end

            local s = "[3f6180]"..Lua_ThingDefine.getParamName(v).."：".."[-]".."[3f6180]"..base.."[-]";
            str = str..s;
        end
    end
    return str;
end

function Lua_ArmySoulHoleVo.Get:armyNextIntensifyProp() -- 军装下级强化
    local str = "";
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"army_soul_prop", self.armyEquipConfig.intensify_prop[1], v});
        if val ~= nil then
            if str == "" then
                str = "";
            else
                str = str.."\n";
            end
            local add = val[self.intensify_lvl+1];
            if Lua_ThingDefine.isPercentParam(v) then
                add = add.."%";
            end
            str = str..add;
        end
    end
    return str;
end

---------------------------------------------------------------------------------------------------------------------------------------
-- 升阶

function Lua_ArmySoulHoleVo.Get:army_order() -- 阶位
    local dec;
    if self.order == 0 then
        dec = LanUtil.getValue(10000);
    else
        dec = Lua_CommonUtil.transChineseNumber(self.order);
    end

    return dec..LanUtil.getValue(140537);
end

function Lua_ArmySoulHoleVo.Get:isCanUngarde() -- 是否可以升阶
    local color_cond = self.armyInfo.armyConfig.color_cond;
    if self.armyEquipVo.color >= color_cond then
    	return self.part;
    end

    return nil;
end

function Lua_ArmySoulHoleVo.Get:is_max_order() -- 是否达到最大阶级
    if self.order >= self.max_order_lvl then
    	return true;
    end
    return false;
end

function Lua_ArmySoulHoleVo.Get:max_order_lvl() -- 最大阶级
    return #self.armyEquipConfig.advance_cost;
end

function Lua_ArmySoulHoleVo.Get:bag_order_num() -- 拥有 升阶材料
    return DataCenter.packData:getBagType(Lua_PackData.ARMY_PACK):getItemNum(tonumber(self.equip_id));
end

function Lua_ArmySoulHoleVo.Get:need_order_num() -- 需要 升阶材料
    return self.armyEquipConfig.advance_cost[self.order+1]
end

-- 升阶属性
function Lua_ArmySoulHoleVo.Get:armyOrderProp() -- 军装升阶属性
    local str = "";
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"army_soul_prop", self.armyEquipConfig.order_prop[1], v});
        if val ~= nil then
            if str == "" then
                str = "";
            else
                str = str.."\n";
            end
            local base = 0;
            if self.order > 0 then
            	base = val[self.order];
            end   
            if Lua_ThingDefine.isPercentParam(v) then
                base = base.."%";
            end
            local s = "[3f6180]"..Lua_ThingDefine.getParamName(v).."：".."[-]".."[192e41]"..base.."[-]";
            str = str..s;
        end
    end
    return str;
end

function Lua_ArmySoulHoleVo.Get:armyNextOrderProp() -- 军装升阶 下级属性
    local str = "";
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"army_soul_prop", self.armyEquipConfig.order_prop[1], v});
        if val ~= nil then
            if str == "" then
                str = "";
            else
                str = str.."\n";
            end

            local base = val[self.order + 1];
            if Lua_ThingDefine.isPercentParam(v) then
                base = base.."%";
            end

            str = str..base;
        end
    end
    return str;
end

---------------------------------------------------------------------------------------------------------------------------------------
-- 红点

-- 军装 红点
function Lua_ArmySoulHoleVo.Get:isShowOpenEquipRed()
	if self.isShowAdornRed == true or self.isShowIntensifyRed == true or self.isShowOrderRed == true or self.isShowReplaceRed == true then
		return true;
	end
	
    return false;
end


-- 军装穿戴 红点
function Lua_ArmySoulHoleVo.Get:isShowAdornRed()
	if self.equip_id ~= 0 then
		return false;
	end

    if self.armyInfo.activate == 1 and self.equip_id == 0 and self.isHaveCommonStamp == true  then
    	return true;
    end

    return false;
end

function Lua_ArmySoulHoleVo.Get:isHaveCommonStamp()--背包 是否拥有同部位魂印
    local bagData = DataCenter.packData:getBagType(Lua_PackData.ARMY_PACK); --军魂 背包
    local arr = bagData:getItemsBySubType({Lua_PackTypeDefine.ARMY_EQUIP_ITEM});

    for i=1,arr:getSize() do
        if arr[i].part == self.part and arr[i].soul_type == self.armyInfo.soul_type and DataCenter.roleData.level >= arr[i].useLvl then
            return true;
        end
    end

    return false;
end

function Lua_ArmySoulHoleVo.Get:isShowReplaceRed() -- 替换  红点处理
	if self.equip_id == 0 then
    	return false;
    end
    local bagData = DataCenter.packData:getBagType(Lua_PackData.ARMY_PACK); --军魂 背包
    local arr = bagData:getItemsBySubType({Lua_PackTypeDefine.ARMY_EQUIP_ITEM});
   
    for i=1,arr:getSize() do
        if arr[i].part == self.part and arr[i].soul_type == self.armyEquipVo.soul_type and arr[i].color > self.armyEquipVo.color  then
            return true;
        end
    end

    return false;
end

-- 强化红点
function Lua_ArmySoulHoleVo.Get:isShowIntensifyRed()
    
    if self.equip_id == 0 then
		return false;
	end

    if self.isMaxLvl == false and self.intensify_info.bagNum >= self.intensify_info.needNum then
        return true;
    end

    return false;
end

-- 升阶红点
function Lua_ArmySoulHoleVo.Get:isShowOrderRed()
	if self.equip_id == 0 then
		return false;
	end

	if self.isCanUngarde == nil then
		return false;
	end

	if self.is_max_order == true then
		return false;
	end

    if self.bag_order_num >= self.need_order_num then
    	return true;
    end

    return false;
end