-- 军魂信息

checkRequire("Lua_ArmySoulHoleVo") -- 部位数据 VO
checkRequire("Lua_ArmySkillVo")    -- 技能数据 VO
Lua_ArmySoulVo = class("Lua_ArmySoulVo")
function Lua_ArmySoulVo:ctor()
    self:superCall("ctor");
end

function Lua_ArmySoulVo:dispose()
end

function Lua_ArmySoulVo:formServer(obj)
	if obj == nil then
		return;
	end

	self.army_id = obj.id;              -- 军魂id
    self.lvl = obj.level;               -- 军魂等级
    self.activate = obj.activate;       -- 激活状态
    self.schedule = obj.schedule        -- 进度
    self.skill_list = obj.skill_list;   -- 军魂技能列表
    self.soulInfo = obj.soul_clothe_info;  -- 魂装数据
end

function Lua_ArmySoulVo.Get:armyEquipInfo() -- 魂装数据
    local list = {};
    for k, v in ipairs(self.soulInfo) do
        local vo = Lua_ArmySoulHoleVo.new();
        vo:formServer(v);
        vo.armyInfo = self;
        list[tonumber(vo.part)] = vo;
    end
    return list;
end

function Lua_ArmySoulVo.Get:armySkillInfo() -- 技能
    local arr = Array();
    for i,v in ipairs(self.skill_list) do
        local vo = Lua_ArmySkillVo.new();
        vo:formServer(v);
        vo.index = i;
        vo.armyInfo = self;
        arr:add(vo);
    end

    return arr;
end

function Lua_ArmySoulVo.Get:armyConfig() -- 军魂配置
    local config = getConfig({"army_soul_info", self.army_id});
    if config == nil then
        return nil;
    end
    return config;
end

function Lua_ArmySoulVo.Get:army_name() -- 名字
    return self.armyConfig.remark;
end

function Lua_ArmySoulVo.Get:soul_type() -- 魂装穿戴类型
    return self.armyConfig.adorn_soul_clothe;
end

function Lua_ArmySoulVo.Get:shapeConfig() -- 模型数据
    return getConfig({"playerHanger", self.armyConfig.illusion});
end

function Lua_ArmySoulVo.Get:modelpos() -- 模型位置
    return self.armyConfig.modelpos
end

function Lua_ArmySoulVo.Get:modelros() -- 模型角度
    return self.armyConfig.modelros
end

function Lua_ArmySoulVo.Get:modelsca() -- 模型大小
    return self.armyConfig.modelsca
end

function Lua_ArmySoulVo.Get:icon_bg() -- 背景
    return "wpk_0"..self.armyConfig.color+1;
end

function Lua_ArmySoulVo.Get:all_intensify_lvl() -- 强化总和
    local list = self.armyEquipInfo;
    local lvl = 0;
    for k,v in pairs(list) do
        lvl = lvl + v.intensify_lvl
    end
    return lvl;
end

function Lua_ArmySoulVo.Get:all_order() -- 等阶总和
    local list = self.armyEquipInfo;
    local order = 0;
    for k,v in pairs(list) do
        order = order + v.order
    end
    return order;
end

-------------------------------------------------------------------------------------------------------------------------------------
-- 激活处理

function Lua_ArmySoulVo.Get:item_name() -- 名字
    if  self.activate == 0 then
        return "[808080]"..self.armyConfig.remark.."[-]";
    else
        local color = Lua_ColorDefine.getItemColorStr(self.armyConfig.color);       
        return "["..color.."]"..self.armyConfig.remark.."[-]";
    end
end

function Lua_ArmySoulVo.Get:item_lvl() -- 等级
    local dec;
    if self.activate == 0 then
        dec = LanUtil.getValue(140512);
    else
        dec = LanUtil.formateStr(LanUtil.getValue(140516),tostring(self.lvl));
    end

    return dec;
end

function Lua_ArmySoulVo.Get:activate_lvl() -- 激活等级
    return self.armyConfig.acti_limit_cond;
end

function Lua_ArmySoulVo.Get:isCanActivate() -- 是否可以激活;
    if DataCenter.roleData.level >= self.activate_lvl then
        return true;
    end

    return false;
end

function Lua_ArmySoulVo.Get:max_upgrade_lvl() -- 军魂最大提升等级
    local arr = self.armyConfig.intensify_cost;
    return #arr;
end

function Lua_ArmySoulVo.Get:isMaxUpgradeLvl() -- 是否达到 军魂最大提升等级
    if self.lvl >= self.max_upgrade_lvl then
        return true;
    end

    return false;
end

function Lua_ArmySoulVo.Get:upgrade_num() -- 提升所需值
    local arr = self.armyConfig.intensify_cost;
    if self.isMaxUpgradeLvl == true then
        return arr[self.lvl][2];
    else
        return arr[self.lvl+1][2];
    end
end

function Lua_ArmySoulVo.Get:activation_cost() -- 激活所需道具
    local list = self.armyConfig.activation_cost;
    if list ~= nil then
        local tvo = Lua_ToolVo.createToolVo(tonumber(list[1]));
        tvo.packType = 999;
        tvo.bagNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(tonumber(list[1]));
        tvo.needNum = tonumber(list[2]);
        return tvo;
    end

    return nil;
end

function Lua_ArmySoulVo.Get:upgrade_cost() -- 提升所需道具
    local arr = self.armyConfig.intensify_cost;
    if arr ~= nil then
        local tvo = Lua_ToolVo.createToolVo(arr[self.lvl+1][3]);
        tvo.packType = 999;
        tvo.bagNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(tonumber(arr[self.lvl+1][3]));
        tvo.needNum = arr[self.lvl+1][4];
        return tvo;
    end

    return nil;
end

-- 强化处理
function Lua_ArmySoulVo:intensify_cost(lvl) -- 魂装强化所需道具
    local arr = self.armyConfig.part_intensify_cost;
    if arr ~= nil then
        local tvo = Lua_ToolVo.createToolVo(arr[lvl][1]);
        tvo.packType = 999;
        tvo.bagNum = DataCenter.armySoulData:getIntensifySoulNum(tvo.color);
        tvo.needNum = arr[lvl][2];
        return tvo;
    end

    return nil;
end

-- 升阶处理
function Lua_ArmySoulVo.Get:isOpenUpgrade() -- 是否打开升阶
    for k,v in pairs(self.armyEquipInfo) do
        if v.equip_id ~= 0 then
            if v.isCanUngarde ~= nil then
                return v.isCanUngarde;
            end
        end
    end
    return nil;
end

-------------------------------------------------------------------------------------------------------------------------------------
-- 属性封装

-- 基础属性封装
function Lua_ArmySoulVo.Get:armyBaseProp()
    local arr = Array();
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val1 = getConfig({"army_soul_prop", self.armyConfig.base_prop[1], v});
        local val2 = getConfig({"army_soul_prop", self.armyConfig.intensify_prop[1], v});
        if val1 ~= nil and val2 ~= nil then
            local base_prop = val1[1];
            local intensify_prop = 0;
            if self.activate == 1 and self.lvl > 0 then
                for i=1, self.lvl do
                    intensify_prop = intensify_prop + val2[1];
                end
            end
            base = base_prop + intensify_prop;
            if Lua_ThingDefine.isPercentParam(v) then
                base = base.."%";
            end
            local s;
            if self.activate == 0 then
                s = "[555c68]"..Lua_ThingDefine.getParamName(v).."："..base.."[-]";
            else            
                s = "[3f6180]"..Lua_ThingDefine.getParamName(v).."：".."[-]".."[192e41]"..base.."[-]";
            end

            local next_base = val2[1];
            if Lua_ThingDefine.isPercentParam(v) then
                next_base = next_base.."%";
            end
            arr:add({base = s, isActivate = self.activate, isMax = self.isMaxUpgradeLvl, next_base = next_base})
        end
    end

    return arr;
end

-- 装备属性封装
function Lua_ArmySoulVo.Get:armyEquipProp()
    local list = self.armyEquipInfo;
    local _list = {};
    for i,v in pairs(list) do
        local info = v.getEquipProp;
        if info ~= nil then
            for j,k in pairs(info) do
                if  _list[j] == nil then

                    _list[j] = k;
                else
                    _list[j] = _list[j]+k;
                end
            end
        end
    end

    local str = "";
    for k,v in pairs(_list) do
        if str == "" then
            str = "";
        else
            str = str.."\n";
        end
        local base = v;
        if Lua_ThingDefine.isPercentParam(k) then
            base = base.."%";
        end

        local s = "[3f6180]"..Lua_ThingDefine.getParamName(k).."：".."[-]".."[192e41]"..base.."[-]";
        str = str..s;
    end

    return str;
end

-- 装备升阶属性封装
function Lua_ArmySoulVo.Get:armyOrderProp() 
    local list = self.armyEquipInfo;
    local _list = {};
    for i,v in pairs(list) do
        local info = v.getOrderProp;
        if info ~= nil then
            for j,k in pairs(info) do
                if  _list[j] == nil then
                    _list[j] = k;
                else
                    _list[j] = _list[j]+k;
                end
            end
        end
    end

    local str = "";
    for k,v in pairs(_list) do
        if str == "" then
            str = "";
        else
            str = str.."\n";
        end
        local base = v;
        if Lua_ThingDefine.isPercentParam(k) then
            base = base.."%";
        end

        local s = "[3f6180]"..Lua_ThingDefine.getParamName(k).."：".."[-]".."[192e41]"..base.."[-]";
        str = str..s;
    end

    return str;
end

function Lua_ArmySoulVo.Get:armyBaseForce() --基础战力
    local list = {};
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val1 = getConfig({"army_soul_prop", self.armyConfig.base_prop[1], v});
        local val2 = getConfig({"army_soul_prop", self.armyConfig.intensify_prop[1], v});

        if val1 ~= nil and val2 ~= nil then
            local base_prop = val1[1];
            local intensify_prop = 0;
            if self.activate == 1 and self.lvl > 0 then
                for i=1, self.lvl do
                    intensify_prop = intensify_prop + val2[1];
                end
            end

            list[v] = base_prop + intensify_prop;
        end
    end

    return Lua_FightUtil.caculateConfigForce(list)+self.armySkillForce;
end

function Lua_ArmySoulVo.Get:armySkillForce() -- 技能战力
    local arr = self.armySkillInfo;
    local force = 0;
    for i=1, arr:getSize() do
        if arr[i].skill_class == 1 then
            force = force + arr[i].skill_force;
        end
    end

    return force;
end

---------------------------------------------------------------------------------------------------------------------------------------
-- 红点

-- 军魂
function Lua_ArmySoulVo.Get:isShowBtnRed()-- 激活 提升 红点   
    local vo;
    if self.activate == 0 then
        if self.isCanActivate == false then -- 激活等级不足
            return false;
        end
        vo = self.activation_cost;
    else
        if self.isMaxUpgradeLvl == true then
            return false;
        end
        
        vo = self.upgrade_cost;
    end

    if vo ~= nil then
        if vo.bagNum >= vo.needNum then
            return true;
        end
    end

    return false;
end

-- 军魂 激活红点
function Lua_ArmySoulVo.Get:isShowActivatRed()
    if self.activate == 0 then
        if self.isCanActivate == false then -- 激活等级不足
            return false;
        end

        local vo = self.activation_cost;
        if vo ~= nil then
            if vo.bagNum >= vo.needNum then
                return true;
            end
        end
    end

    return false;
end

-- 军魂 提升红点
function Lua_ArmySoulVo.Get:isShowUpgradRed()
    if self.activate == 1 then
        if self.isMaxUpgradeLvl == true then
            return false;
        end

        local vo = self.upgrade_cost;
        if vo ~= nil then
            if vo.bagNum >= vo.needNum then
                return true;
            end
        end
    end

    return false;
end

-- 军装穿戴 红点
function Lua_ArmySoulVo.Get:isEquipAdornRed()
    local list = self.armyEquipInfo;
    for k,v in pairs(list) do
        if v.isShowAdornRed == true then
            return true;
        end
    end

    return false;
end

-- 军装替换 红点
function Lua_ArmySoulVo.Get:isEquipReplaceRed()
    local list = self.armyEquipInfo;
    for k,v in pairs(list) do
        if v.isShowReplaceRed == true then
            return true;
        end
    end
    
    return false;
end

-- 军装强化 红点
function Lua_ArmySoulVo.Get:isEquipIntensifyRed()
    local list = self.armyEquipInfo;
    for k,v in pairs(list) do
        if v.isShowIntensifyRed == true then
            return true;
        end
    end

    return false;
end

-- 军装升阶 红点
function Lua_ArmySoulVo.Get:isEquipOrderRed()
    local list = self.armyEquipInfo;
    for k,v in pairs(list) do
        if v.isShowOrderRed == true then
            return v.part;
        end
    end

    return nil;
end

function Lua_ArmySoulVo.Get:isShowEquipItmeRed()
    local list = self.armyEquipInfo;
    for k,v in pairs(list) do
        if v.isShowOpenEquipRed == true then
            return true;
        end
    end

    return false;
end