Lua_AwakeRecastInfoVo = class("Lua_AwakeRecastInfoVo")
function Lua_AwakeRecastInfoVo:ctor(id)
	self.id = tonumber(id);
	self.config = getConfig({"recast", self.id});

	self.debris_recast = 1;
	self.is_break = 0;
	self.debris_message = 0;
	self.recast_level = 0;
	self.levelValue = 20;
	self.force = 0;
	self.isRedDot = false;
end

-- 初级需要消耗
function Lua_AwakeRecastInfoVo.Get:primaryCostDic()
	return self.config.primary_cost;
end

-- 高级需要消耗
function Lua_AwakeRecastInfoVo.Get:advancedCostDic()
	return self.config.advanced_cost;
end

-- 突破需要消耗
function Lua_AwakeRecastInfoVo.Get:breakCostDic()
	return self.config.break_cost;
end

-- 阶段重铸属性
function Lua_AwakeRecastInfoVo.Get:property_upper()
	return self.config.property_upper;
end

-- 碎片等级限制
function Lua_AwakeRecastInfoVo.Get:lvl_limite()
	return self.config.lvl_limite;
end

-- 碎片最大等级限制
function Lua_AwakeRecastInfoVo.Get:limit()
	return self.config.limit;
end

-- 碎片最大等级限制
function Lua_AwakeRecastInfoVo.Get:recast_name()
	return self.config.recast_name;
end




-- 获取初级消耗品数量
function Lua_AwakeRecastInfoVo.Get:getPrimaryCost()
	if self.primaryCostDic == nil then
		return 0;
	end
	return DataCenter.packData:getBagType(2):getItemNum(self.primaryCostDic[1][1]);
end

-- 获取高级消耗品数量
function Lua_AwakeRecastInfoVo.Get:getAdvancedCost()
	if self.advancedCostDic == nil then
		return 0;
	end

	self._getAdvancedCost = DataCenter.packData:getBagType(2):getItemNum(self.advancedCostDic[2][1]);
	return self._getAdvancedCost;
end

-- 获取突破消耗品数量
function Lua_AwakeRecastInfoVo.Get:getBreakCostCost()
	if self.breakCostDic == nil then
		return 0;
	end

	self._getBreakCostCost = DataCenter.packData:getBagType(2):getItemNum(self.breakCostDic[1][1]);
	return self._getBreakCostCost;
end

-- 需要消耗初级数量
function Lua_AwakeRecastInfoVo.Get:needPrimaryCost()
	self._primaryCostDic = self.primaryCostDic[1][2];
	return self._primaryCostDic
end

-- 需要消耗高级品数量
function Lua_AwakeRecastInfoVo.Get:needAdvancedCost()
	self._advancedCostDic = self.advancedCostDic[2][2];
	return self._advancedCostDic
end

-- 需要消耗突破品数量
function Lua_AwakeRecastInfoVo.Get:needBreakCostCost()
	if self.breakCostDic == nil then
	 	return 0;
	end
	return self.breakCostDic[1][2]
end

-- 碎片红点
function Lua_AwakeRecastInfoVo.Get:isRecastRedDot()
	if DataCenter.redDotData:getRedDotStateByEventId(13005) == false and
		DataCenter.redDotData:getRedDotStateByEventId(13006) == false then
		return false;
	end
	if self.isMaxLevel == true then
		return false;
	end
	if self.debris_message == 0 then
		return false;
	end

	if self.is_break == 0 then -- 重塑
		if self.getPrimaryCost >= self.needPrimaryCost then
			return true;
		end
	else -- 突破
		if self.getBreakCostCost >= self.needBreakCostCost then
			return true;
		end
	end
	return false;
end

-- 突破红点
function Lua_AwakeRecastInfoVo.Get:isBreakBtnRedDot()
	if self.isMaxLevel == true then
		return false;
	end
	if self.debris_message == 0 then
		return false;
	end
	if DataCenter.redDotData:getRedDotStateByEventId(13006) == false then
		return false;
	end
	if self.is_break == 1 then 
		if self.getBreakCostCost >= self.needBreakCostCost then
			return true;
		end
	end
	return false;
end

-- 重铸一次红点
function Lua_AwakeRecastInfoVo.Get:isOneBtnRedDot()
	if self.isMaxLevel == true then
		return false;
	end
	if self.debris_message == 0 then
		return false;
	end
	if DataCenter.redDotData:getRedDotStateByEventId(13005) == false then
		return false;
	end
	if self.is_break == 0 then 
		if self.getPrimaryCost >= self.needPrimaryCost then
			return true;
		end
	end
	return false
end

-- 重铸十次红点
function Lua_AwakeRecastInfoVo.Get:isTenBtnRedDot()
	if self.isMaxLevel == true then
		return false;
	end
	if self.debris_message == 0 then
		return false;
	end
	if DataCenter.redDotData:getRedDotStateByEventId(13005) == false then
		return false;
	end
	if self.is_break == 0 then 
		if self.getPrimaryCost >= self.needPrimaryCost * 10 then
			return true;
		end
	end
	return false
end

-- 是否达到最大等级
function Lua_AwakeRecastInfoVo.Get:isMaxLevel()
	local isObjValueMax = true;
	if self.recastPropertyListMsg == nil then
		return false;
	end

	for i,v in ipairs(self.recastPropertyListMsg.obj_list) do
		for k,j in pairs(self.property_upper) do
			if v.obj_id == j[1] then
				if j[2] > v.obj_value then
					isObjValueMax = false;
				end
			end
		end
	end

	if self.recast_level == self.levelValue and isObjValueMax == true then
		return true;
	end
	return false;
end

-- 战力
function Lua_AwakeRecastInfoVo.Get:recastForce()
	if self.recastPropertyListMsg == nil then
		return 0;
	end

	local force = {};
	for i,v in ipairs(self.recastPropertyListMsg.obj_list) do
		force[tonumber(v.obj_id)] = v.obj_value;	
	end
	return Lua_FightUtil.caculateForce(force);
end

function Lua_AwakeRecastInfoVo.Get:recastPropertyList()
	if self.recastPropertyListMsg.obj_list == nil then
		return;
	end

	self._PropertyList = {};
	for i,v in ipairs(self.recastPropertyListMsg.obj_list) do
		self._PropertyList[tonumber(v.obj_id)] = v.obj_value;   
	end
	return self._PropertyList;
end