-- 兽灵Vo
Lua_BeastSoulVo = class("Lua_BeastSoulVo");
function Lua_BeastSoulVo:ctor(id, config)
    self.id = id;	
    if config == nil then
    	config = getConfig({ "zodiac_spirit_intensify", id });
    end
    self.config = config;
    self:resetServerInfo();
end

function Lua_BeastSoulVo:resetServerInfo()
    self.beastSoulLvl = 0;
    self.starLvl = 0;
    self.isActivate = 0;
end

function Lua_BeastSoulVo:updateServerInfo(serverInfo)
    if serverInfo == nil or serverInfo.id ~= self.id then
        return;
    end
    
    self.beastSoulLvl = serverInfo.level; -- 兽灵等级
    self.starLvl = serverInfo.star; -- 兽灵星级
    self.isActivate = serverInfo.activate; -- 激活状态: 0未激活 1激活
    self.skill_list = serverInfo.skill_list; -- 技能列表
end

function Lua_BeastSoulVo.Get:name()
    return self.config.name;
end

function Lua_BeastSoulVo.Get:mainType()
    return self.config.mainType;
end

function Lua_BeastSoulVo.Get:mainName()
    return self.config.mainName;
end

-- 激活所需道具和数量
function Lua_BeastSoulVo.Get:activate_cost()
    return self.config.activate_cost;
end

-- 强化消耗道具和数量
function Lua_BeastSoulVo.Get:intensify_cost()
    return self.config.intensify_cost;
end

-- 强化等级上限
function Lua_BeastSoulVo.Get:intensify_lvl_limit()
    return self.config.intensify_lvl_limit;
end

-- 星级上限
function Lua_BeastSoulVo.Get:star_lvl_limit()
    return self.config.star_lvl_limit;
end

-- 升星消耗道具和数量
function Lua_BeastSoulVo.Get:upstar_cost()
    return self.config.upstar_cost;
end

-- 技能
function Lua_BeastSoulVo.Get:skill()
    return self.config.skill;
end

-- 基础属性
function Lua_BeastSoulVo.Get:base_prop()
    return self.config.base_prop;
end

-- 强化属性
function Lua_BeastSoulVo.Get:intensify_prop()
    return self.config.intensify_prop;
end

-- 升星属性
function Lua_BeastSoulVo.Get:star_prop()
    return self.config.star_prop;
end

-- 头像资源ID
function Lua_BeastSoulVo.Get:headId()
    return self.config.headId;
end

-- 激活剪影
function Lua_BeastSoulVo.Get:imageStr()
    local str = "";
    if self.config.image_name ~= nil then
        str = "/images/head/zodiac/" .. self.config.image_name;
    end
    return str;
end

-- 未激活剪影
function Lua_BeastSoulVo.Get:unImageStr()
    local str = "";
    if self.config.un_image_name ~= nil then
        str = "/images/head/zodiac/" .. self.config.un_image_name;
    end
    return str;
end











-- 兽灵激活所需消耗的道具Vo 数量
function Lua_BeastSoulVo.Get:activateCostVo()
    local vo = Lua_ToolVo.createToolVo(self.activate_cost[1], self.activate_cost[2]);
    vo.haveNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(self.activate_cost[1]);
    return vo;
end

-- 当前可强化最大等级限制
function Lua_BeastSoulVo.Get:currentMaxIntensifyLvl()
    if self.isActivate == 0 then
        return self.intensify_lvl_limit[1];
    else
        if self.starLvl <= 0 then
            return self.intensify_lvl_limit[2];
        else
            return self.intensify_lvl_limit[self.starLvl + 2];
        end
    end
end

-- 是否达到当前最大强化等级
function Lua_BeastSoulVo.Get:isMaxCurrentIntensify()
    if self.beastSoulLvl >= self.currentMaxIntensifyLvl then
        return true;
    end
    return false;
end

-- 是否达到最大强化等级
function Lua_BeastSoulVo.Get:isMaxIntensify()
    local len = #self.intensify_lvl_limit;
    if self.beastSoulLvl >= self.intensify_lvl_limit[len] then
        return true;
    end
    return false;
end

-- 下一级强化所需消耗的道具Vo 数量
function Lua_BeastSoulVo.Get:intensifyCostVo()
    if self.isMaxIntensify == false then
        local cost = self.intensify_cost[self.beastSoulLvl + 1];
        local vo = Lua_ToolVo.createToolVo(cost[1], cost[2]);
        vo.haveNum = DataCenter.beastSoulData:getICostCountById(cost[1]);
        return vo;
    end
    return nil;
end

-- 强化技能
function Lua_BeastSoulVo.Get:intensifySkill()
    local vo = DataCenter.beastSoulUtil:getSkillVoById(self.skill[2]);
    if vo ~= nil and self.skill_list ~= nil then
        vo:updateServerInfo(self.skill_list[2]);
    end
    return vo;
end

-- 是否达到最大升星
function Lua_BeastSoulVo.Get:isMaxUpStar()
    if self.starLvl >= self.star_lvl_limit then
        return true;
    end
    return false;
end

-- 升级下一星所需消耗的道具Vo 数量
function Lua_BeastSoulVo.Get:upStarCostVo()
    if self.isMaxUpStar == false then
        local cost = self.upstar_cost[self.starLvl + 1];
        local vo = Lua_ToolVo.createToolVo(cost[1], cost[2]);
        vo.haveNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(cost[1]);
        return vo;
    end
    return nil;
end

-- 升星技能
function Lua_BeastSoulVo.Get:upStarSkill()
    local vo = DataCenter.beastSoulUtil:getSkillVoById(self.skill[1]);
    if vo ~= nil and self.skill_list ~= nil then
        vo:updateServerInfo(self.skill_list[1]);
    end
    return vo;
end

---------- 属性封装 ----------
-- 基础属性
function Lua_BeastSoulVo.Get:baseAttrsArr()
    local arr = Array();
    local val = 0;
    local config = DataCenter.beastSoulUtil:getAttributeCfgById(self.base_prop[1]);
    if config ~= nil then
        for i,v in ipairs(Lua_ThingDefine.params) do
            if config[v] ~= nil then
                val = config[v][1];
                local list = {};
                list.name = Lua_ThingDefine.getParamName(v);
                if Lua_ThingDefine.isPercentParam(v) then
                    val = val .. "%";
                end
                list.value = val;
                arr:add(list);
            end
        end
    end
    return arr;
end 

-- 升星属性
function Lua_BeastSoulVo.Get:starAttrsArr()
    local arr = Array();
    local val = 0;
    if self.isActivate == 1 then
        local config = DataCenter.beastSoulUtil:getAttributeCfgById(self.star_prop[1]);
        if config ~= nil then
            for i,v in ipairs(Lua_ThingDefine.params) do
                if config[v] ~= nil then
                    val = config[v][self.starLvl];

                    local list = {};
                    list.name = Lua_ThingDefine.getParamName(v);
                    if Lua_ThingDefine.isPercentParam(v) then
                        val = val .. "%";
                    end
                    list.value = val;
                    arr:add(list);
                end
            end
        end
    end
    return arr;
end

-- 强化属性
function Lua_BeastSoulVo.Get:intensifyAttrsArr()
    local arr = Array();
    local config = DataCenter.beastSoulUtil:getAttributeCfgById(self.intensify_prop[1]);
    if config ~= nil then
        for i,v in ipairs(Lua_ThingDefine.params) do
            if config[v] ~= nil then
                local val = 0;
                local nextVal = 0;
                if self.beastSoulLvl ~= 0 then
                    val = config[v][self.beastSoulLvl];
                end
                if config[v][self.beastSoulLvl + 1] ~= nil then
                    nextVal = config[v][self.beastSoulLvl + 1];
                end

                local list = {};
                list.name = Lua_ThingDefine.getParamName(v);
                if Lua_ThingDefine.isPercentParam(v) then
                    val = val .. "%";
                    if nextVal ~= 0 then
                        nextVal = nextVal .. "%";
                    end
                end

                list.value = val;
                list.nextValue = nextVal;
                arr:add(list);
            end
        end
    end
    return arr;
end

---------- 红点显隐处理 ----------
function Lua_BeastSoulVo.Get:isShowUpStarRed()
    -- 激活
    local vo = nil;
    if self.isActivate == 0 then
        vo = self.activateCostVo;
        if vo.haveNum >= vo.count then
            return true;
        end
        return false;
    end

    -- 升星
    if self.isActivate == 1 then
        if self.isMaxUpStar then
            return false;
        end

        vo = self.upStarCostVo;
        if vo.haveNum >= vo.count then
            return true;
        end
        return false;
    end
end

function Lua_BeastSoulVo.Get:isShowIntensifyRed()
    if self.isMaxIntensify then
        return false;
    end

    if self.isMaxCurrentIntensify then
        return false;
    end

    local vo = self.intensifyCostVo;
    if vo.haveNum >= vo.count then
        return true;
    end
    return false;
end