checkRequire("Lua_BossDetailInfoVo");
checkRequire("Lua_BossCopyResultVo");
Lua_BossData = class("Lua_BossData");
Lua_BossData.TYPE_WILD = 1; -- 世界BOSS
Lua_BossData.TYPE_HUANGLING = 2; -- BOSS之家
Lua_BossData.TYPE_PERSONAL = 3; -- 个人BOSS
Lua_BossData.TYPE_TIMELIMIT = 4; -- 幽冥鬼窟
Lua_BossData.TYPE_DROP_ITEMS = 5; -- 掉落记录
Lua_BossData.TYPE_ISLE_BOSS = 8; -- 神兽岛
Lua_BossData.TYPE_ISLEBOSS_KUAFU = 11; -- 神兽岛（跨服）
Lua_BossData.TYPE_DROPITEMS_KUAFU = 12; -- 掉落记录（跨服）
Lua_BossData.TYPE_CHAOTIC_KUAFU = 13; -- 混沌战场
Lua_BossData.TYPE_PRIMITIVE_KUAFU = 14; -- 洪荒仙境
Lua_BossData.BOSS_NAME_2_INDEX = {};
Lua_BossData.BOSS_NAME_2_INDEX[LanUtil.getValue(121600)] = Lua_BossData.TYPE_WILD;
Lua_BossData.BOSS_NAME_2_INDEX[LanUtil.getValue(121601)] = Lua_BossData.TYPE_HUANGLING;
Lua_BossData.BOSS_NAME_2_INDEX[LanUtil.getValue(121602)] = Lua_BossData.TYPE_PERSONAL;
Lua_BossData.BOSS_NAME_2_INDEX[LanUtil.getValue(121603)] = Lua_BossData.TYPE_TIMELIMIT;
Lua_BossData.BOSS_NAME_2_INDEX[LanUtil.getValue(121604)] = Lua_BossData.TYPE_DROP_ITEMS;
Lua_BossData.BOSS_NAME_2_INDEX[LanUtil.getValue(121653)] = Lua_BossData.TYPE_ISLE_BOSS;
function Lua_BossData:ctor()
	self.bossDetailInfoDic = {};
	self.curSceneId = 0;
	self.curSpaceId = 0;
	self.moveToMonsterId = 0;
	self.curMonsterId = 0;
	self.curBossInfoListType = 1;
	self.bossCopyRsVo = Lua_BossCopyResultVo.new();
	self.needTrackBossId = nil;
	self.needTrackSceneId = nil;
	self.OnUpdataZQ=false;
	-- 限时BOSS副本数据
	self.angerPoint = 0;
	self.rageType=0;
	-- 愤怒值
	self.angerMax = 0;
	-- 愤怒值上限
	self.thunderStrikeLeftTime = 0;
	-- 天谴剩余时间倒计时（秒）
	self.bossCopyReliveSecDic = {};
end

function Lua_BossData:sFollowBossRelive(type, monsterId, isFollow)
	local cmd = getProtoMsg("Proto10401604");
	cmd.type = type;
	cmd.sort_id = monsterId;
	cmd.flag = isFollow;
	sendMsg(10401604, cmd);
end

function Lua_BossData:fromServer50401601(msg)
	if msg == nil then
		return;
	end

	self.curSceneId = msg.scene_id;
	self.curSpaceId = msg.space_id;
	self.curMonsterId = msg.monster_id;
end

function Lua_BossData:fromServer80403904(msg)
	if msg == nil then
		return;
	end
	self.bossCopyRsVo:fromServer(msg);
end

function Lua_BossData:fromServer80403906(msg)
	if msg == nil then
		return;
	end

	self.angerPoint = msg.anger_point;
	self.angerMax = msg.anger_max;
	self.thunderStrikeLeftTime = msg.left_time;
	self.rageType = msg.type;
	
	local detailData = self:getBossDetailByType(msg.type);
	if detailData ~= nil then
		detailData.totalChall = msg.total_count;
		if msg.type == Lua_BossData.TYPE_CHAOTIC_KUAFU then
			detailData.leftChall = msg.chall_count;
		else
			detailData.leftChall = msg.total_count - msg.chall_count;
		end
	end
end

function Lua_BossData:fromServer80403907(msg)
	-- if self.bannerTime == nil then
	-- 	self.bannerTime = {};
	-- end
	-- self.bannerTime.refresh_time=msg.refresh_time;
	-- self.bannerTime.end_time=msg.end_time;
	self.bannerTime = msg;
end

-- 1野外boss, 2皇陵, 3个人, 4限时, 5掉落记录, 8神兽岛
function Lua_BossData:getBossDetailByType(bossType)
	local tt = tostring(bossType);
	if self.bossDetailInfoDic[tt] == nil then
		self.bossDetailInfoDic[tt] = Lua_BossDetailInfoVo.new(bossType);
	end
	return self.bossDetailInfoDic[tt];
end

-- challCount：已经挑战了多少次，
-- totalCount：总共
-- isLive:boss：是否活着
-- monsterId：怪物id
-- layer：层数
-- sceneId：场景id
function Lua_BossData:sEnterBossScene(challCount, totalCount, isLive, monsterId, layer, sceneId, checkTimes)
	local curType = DataCenter.bossData.curOpenUIType;
	if curType ~= nil and tonumber(sceneId) == DataCenter.roleData.sceneId then
		if curType == Lua_BossData.TYPE_WILD then
		-- 野外boss要到配置里面拿坐标，服务端没有返回数据
			self:gotoWildBossHandle(sceneId, monsterId);
		else
			-- 其他类型的boss副本，取服务端发过来的坐标数据
			local bossDetail = self:getBossDetailByType(curType);
			local bossPos = nil;
			for k, v in ipairs(bossDetail.bossDetailSet) do
				if v.monster_id == monsterId then
					bossPos = v.pos;
					break;
				end
			end

			if bossPos ~= nil then
				local tMonsterId = tonumber(monsterId);
				local nextAction = WorldMapUtil.genArriveActionVo({type = 8, monsterId = Lua_CommonUtil.trnsLongNum(tMonsterId), dailytask = 0});
				WorldMapUtil.moveTo(sceneId, bossPos.pixel_x, bossPos.pixel_y, bossPos.pixel_z, 0, 0, nextAction, 0);
			end
		end
		Lua_WindowUtil.openWin("Lua_BossMainWindow", WinParam.ACTION_CLOSE);
		return;
	end

	if checkTimes == true then
		if totalCount - challCount <= 0 then
			OperateAlert.show(LanUtil.getValue(121615));
			return;
		end
	end

	local sceneCfg = Lua_SceneConfigData.getSceneConfig(tonumber(sceneId));
	if sceneCfg == nil or sceneCfg.config == nil then
		return;
	end

	if sceneCfg.config.tick_item ~= nil then
		local itemId = sceneCfg.config.tick_item;
		local costTicket = sceneCfg.config.tick_cost[challCount + 1];
		local leftTicket = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(itemId);
		local itemName = Lua_ToolVo.createToolVo(itemId, 1, 1).colorName;
		if costTicket ~= nil and leftTicket < costTicket then
			Lua_WindowUtil.openWin("Lua_BossCopyBuyTimesWindow", WinParam.ACTION_OPEN,
			{type = sceneCfg.config.boss_copy_type, itemName = itemName, leftTicket = leftTicket,
				costTicket = costTicket, scene_id = sceneId, space_id = layer, monster_id = monsterId});
			return;
		end
	end
	self.needTrackBossId = monsterId;
	self.needTrackSceneId = tonumber(sceneId);

	local cmd = getProtoMsg("Proto10401601");
	cmd.scene_id = tonumber(sceneId);
	cmd.space_id = layer;
	cmd.monster_id = monsterId;
	self.moveToMonsterId = monsterId;
	sendMsg(10401601, cmd);

	if Lua_WindowUtil.isWindowShowing("Lua_BossReliveTipsWindow") then
		Lua_WindowUtil.openWin("Lua_BossReliveTipsWindow", WinParam.ACTION_CLOSE);
	end
end

function Lua_BossData:gotoWildBossHandle(sceneId, monsterId)
	local allCfg = getConfig({"field_boss_info"});
	local cfg;
	for i, j in ipairs(allCfg) do
		if j.scene_id == sceneId then
			cfg = j;
			break;
		end
	end

	if cfg ~= nil and cfg.monster_set ~= nil then
		local idx = nil;
		for k, v in ipairs(cfg.monster_set) do
			if v == monsterId then
				idx = k;
				break;
			end
		end

		if idx ~= nil then
			local moveData = {};
			moveData.pos = cfg.target_pos[idx];
			moveData.sceneId = sceneId;
			moveData.tMonsterId = tonumber(monsterId);
			moveData.nextAction = WorldMapUtil.genArriveActionVo({type = 8, monsterId = Lua_CommonUtil.trnsLongNum(moveData.tMonsterId), dailytask = 0});
			-- if DataCenter.roleData.curLine ~= 1 then
			-- 	local cmd = ProtoPublic_pb.Proto10400120();
			-- 	cmd.lines = 1;
			-- 	sendMsg(10400120, cmd);
			-- 	Lua_CommonUtil.addTimer("delayMoveTo", 0.5, self, self.delayMoveTo, moveData, 1);
			-- else
				self:delayMoveTo(moveData);
			-- end
		end

		DataCenter.bossData.needTrackBossId = nil;
		DataCenter.bossData.needTrackSceneId = nil;
	end
end

function Lua_BossData:delayMoveTo(moveData)
	if moveData == nil then
		return;
	end
	WorldMapUtil.moveTo(moveData.sceneId, moveData.pos[1], moveData.pos[2], moveData.pos[3], 0, 0, moveData.nextAction, 0);
end