checkRequire("Lua_BossData");
checkRequire("Lua_CountDownAnimation");
Lua_BossProxy = class("Lua_BossProxy")
function Lua_BossProxy:ctor()
	DataCenter.bossData = Lua_BossData.new();
	self.showingThunderCountdown = false;

	LuaUtil.addLuaMsg(50401601, self, self.rEnterBossScene); -- 请求进入boss场景（返回）
	LuaUtil.addLuaMsg(50401602, self, self.rBossDataInfo); -- 请求BOSS面板信息（返回）
	LuaUtil.addLuaMsg(50101650, self, self.rKuaFuBossDataInfo); -- 请求BOSS跨服面板道具掉落信息（返回）
	LuaUtil.addLuaMsg(80403904, self, self.rBossCopyResult); -- 请求BOSS副本结算面板（通知）
	LuaUtil.addLuaMsg(50401603, self, self.rBossKillRecord); -- 请求BOSS击杀记录（返回）
	LuaUtil.addLuaMsg(50101651, self, self.rKuaFuBossKillRecord); -- 请求BOSS跨服击杀记录（返回）
	LuaUtil.addLuaMsg(80403905, self, self.rBossReliveTips); -- boss刷新前推送（通知）
	LuaUtil.addLuaMsg(50401604, self, self.rFollowBoss); -- 关注boss（返回）
	LuaUtil.addLuaMsg(80403903, self, self.rBossCopyInfo); -- boss战斗信息（通知）
	LuaUtil.addLuaMsg(80403906, self, self.rRageInfo); -- 副本信息（包括愤怒值、愤怒值上限、天谴倒计时）（通知）
	LuaUtil.addLuaMsg(80401608, self, self.onThunderStrike); -- 播放特效，天雷处罚（通知）
	-- LuaUtil.addLuaMsg(80400412, self, self.onExitSceneCountDown); -- 退出场景倒计时（通知）
	LuaUtil.addLuaMsg(80403907, self, self.UpdataChaoticTime); -- 混沌战场采集物时间信息（通知）

	Lua_MsgUtil.addEventListener("SCENE_LOADED", self, self.onSceneLoaded); -- 场景切换完毕（返回）
	Lua_MsgUtil.addEventListener("SCENE_CHANGE", self, self.onSceneChange);-- 场景切换（返回）
end

function Lua_BossProxy:UpdataChaoticTime(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto80403907");
		msg:ParseFromString(mp.data);
		DataCenter.bossData:fromServer80403907(msg);
		Lua_MsgUtil.callFunc("UPDATACHAOTICTIME",msg);
	end
end

function Lua_BossProxy:onExitSceneCountDown(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto80400412");
		msg:ParseFromString(mp.data);
		if msg.left_time > 0 then
			self:showCountDown(msg.left_time, msg.type == 1 and 2 or 3);
		end
	end
end

function Lua_BossProxy:onCountEnd()
	self:showCountDown(0, 3);
end

function Lua_BossProxy:showCountDown(val, showType)
	if val > 0 then
		if self.countDownAni == nil then
			self.countDownAni = Lua_CountDownAnimation.new(self.content, self, self.onCountEnd, showType);
			self.countDownAni:setLocation(0, MainWinDefine.V_height / 2 - 230, 0);
			self.countDownAni:setDepth(10);
		end
		self.countDownAni:playCountDown(val, 1);
	else
		if self.countDownAni ~= nil then
			self.countDownAni:dispose();
			self.countDownAni = nil;
		end
	end
end

function Lua_BossProxy:onThunderStrike(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto80401608");
		msg:ParseFromString(mp.data);
		
		local rolePlayer = ThingUtil.instance:getThingById(msg.role_id);
		if rolePlayer ~= nil then
			rolePlayer:onPlayThunderStrikeEffect();
		end

		-- 延迟两秒，等天雷特效播放完后才弹面板
		Lua_CommonUtil.delayCall(2, self, self.showThunder, msg);
		self.showingThunderCountdown = false;
	end
end

function Lua_BossProxy:showThunder(msg)
	Lua_WindowUtil.openWin("Lua_ThunderStrikeWindow", WinParam.ACTION_OPEN, msg.exit_left_time - 2);
end

function Lua_BossProxy:onSceneChange()
	if Lua_WindowUtil.isWindowShowing("Lua_CountDownWindow") and self.showingThunderCountdown then
		Lua_WindowUtil.openWin("Lua_CountDownWindow", WinParam.ACTION_CLOSE, nil);
		self.showingThunderCountdown = false;
	end
end

function Lua_BossProxy:onSceneLoaded()
	if Lua_WindowUtil.isWindowShowing("Lua_BossCopyInfoWindow") then
		Lua_WindowUtil.openWin("Lua_BossCopyInfoWindow", WinParam.ACTION_CLOSE);
	end

	if Lua_WindowUtil.isWindowShowing("Lua_LimitTimeBossRageWindow") then
		Lua_WindowUtil.openWin("Lua_LimitTimeBossRageWindow", WinParam.ACTION_CLOSE);
	end

	if Lua_WindowUtil.isWindowShowing("Lua_ThunderStrikeWindow") then
		Lua_WindowUtil.openWin("Lua_ThunderStrikeWindow", WinParam.ACTION_CLOSE);
	end

	if Lua_WindowUtil.isWindowShowing("Lua_PersonalBossCopyInfoWindow") then
		Lua_WindowUtil.openWin("Lua_PersonalBossCopyInfoWindow", WinParam.ACTION_CLOSE);
	end

	if Lua_WindowUtil.isWindowShowing("Lua_IsleBossCopyInfoWindow") then
		Lua_WindowUtil.openWin("Lua_IsleBossCopyInfoWindow", WinParam.ACTION_CLOSE);
	end

	if Lua_WindowUtil.isWindowShowing("Lua_ChaoticLeftInfoWindow") then
		Lua_WindowUtil.openWin("Lua_ChaoticLeftInfoWindow", WinParam.ACTION_CLOSE);
	end

	-- 传送到野外boss地图后，检测寻路
	if DataCenter.bossData.needTrackBossId ~= nil and DataCenter.roleData.sceneId == DataCenter.bossData.needTrackSceneId then
		DataCenter.bossData:gotoWildBossHandle(DataCenter.bossData.needTrackSceneId, DataCenter.bossData.needTrackBossId);
	end

	-- if Lua_WindowUtil.isWindowShowing("Lua_CountDownWindow") and self.showingThunderCountdown then
	-- 	Lua_WindowUtil.openWin("Lua_CountDownWindow", WinParam.ACTION_CLOSE, nil);
	-- 	self.showingThunderCountdown = false;
	-- end
end

function Lua_BossProxy:rRageInfo(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto80403906");
		msg:ParseFromString(mp.data);
		DataCenter.bossData:fromServer80403906(msg);
		if msg.type == Lua_BossData.TYPE_TIMELIMIT -- 限时boss
			or msg.type == 9
			or msg.type == Lua_BossData.TYPE_CHAOTIC_KUAFU -- 混沌战场
			or msg.type == Lua_BossData.TYPE_PRIMITIVE_KUAFU then -- 洪荒仙境
			
			if Lua_WindowUtil.isWindowShowing("Lua_LimitTimeBossRageWindow") then
				Lua_MsgUtil.callFunc("LIMITTIME_BOSS_RAGE_UPDATE");
			else
				Lua_WindowUtil.openWin("Lua_LimitTimeBossRageWindow", WinParam.ACTION_OPEN);
			end
		elseif Lua_WindowUtil.isWindowShowing("Lua_LimitTimeBossRageWindow") then
			Lua_MsgUtil.callFunc("LIMITTIME_BOSS_RAGE_UPDATE");
		end

		if msg.type == Lua_BossData.TYPE_TIMELIMIT then
			if msg.left_time > 0 then
				if Lua_WindowUtil.isWindowShowing("Lua_CountDownWindow") == false then
					local winParamData = {};
					winParamData.leftTime = msg.left_time;
					-- winParamData.cbOwner = self;
					-- winParamData.cbFun = self.onCountDownFinish;
					-- winParamData.cbFunParam = "finish countdown";
					Lua_WindowUtil.openWin("Lua_ThurderCountWindow", WinParam.ACTION_OPEN, winParamData);
					self.showingThunderCountdown = true;
				end
			else
				if Lua_WindowUtil.isWindowShowing("Lua_ThurderCountWindow") then
					Lua_WindowUtil.openWin("Lua_ThurderCountWindow", WinParam.ACTION_CLOSE);
				end
			end
		end
	end
end

-- function Lua_BossProxy:onCountDownFinish(val)
-- 	print(val);
-- end

function Lua_BossProxy:rBossCopyInfo(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto80403903");
		msg:ParseFromString(mp.data);

		if Lua_WindowUtil.isWindowShowing("Lua_BossCopyInfoWindow") == false and msg.type ~= Lua_BossData.TYPE_PERSONAL and
			msg.type ~= Lua_BossData.TYPE_ISLE_BOSS and msg.type ~= Lua_BossData.TYPE_ISLEBOSS_KUAFU and msg.type ~= Lua_BossData.TYPE_CHAOTIC_KUAFU then
			Lua_WindowUtil.openWin("Lua_BossCopyInfoWindow", WinParam.ACTION_OPEN, msg);
		elseif Lua_WindowUtil.isWindowShowing("Lua_PersonalBossCopyInfoWindow") == false and msg.type == Lua_BossData.TYPE_PERSONAL then
			Lua_WindowUtil.openWin("Lua_PersonalBossCopyInfoWindow", WinParam.ACTION_OPEN, msg);
		elseif Lua_WindowUtil.isWindowShowing("Lua_IsleBossCopyInfoWindow") == false and msg.type == Lua_BossData.TYPE_ISLE_BOSS then
			Lua_WindowUtil.openWin("Lua_IsleBossCopyInfoWindow", WinParam.ACTION_OPEN, msg);
		elseif Lua_WindowUtil.isWindowShowing("Lua_IsleBossCopyInfoWindow") == false and msg.type == Lua_BossData.TYPE_ISLEBOSS_KUAFU then
			Lua_WindowUtil.openWin("Lua_IsleBossCopyInfoWindow", WinParam.ACTION_OPEN, msg);
		elseif Lua_WindowUtil.isWindowShowing("Lua_ChaoticLeftInfoWindow") == false and msg.type == Lua_BossData.TYPE_CHAOTIC_KUAFU then
			Lua_WindowUtil.openWin("Lua_ChaoticLeftInfoWindow", WinParam.ACTION_OPEN, msg);
		else
			Lua_MsgUtil.callFunc("BOSS_COPY_SCENE_INFO_UPDATE", msg);
		end
	end
end

function Lua_BossProxy:rFollowBoss(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto50401604");
		msg:ParseFromString(mp.data);
		
		local bossDetail = DataCenter.bossData:getBossDetailByType(msg.type);
		for k, v in ipairs(bossDetail.bossDetailSet) do
			if v.monster_id == msg.sort_id then
				v.is_follow = msg.flag;
				break;
			end
		end
		Lua_MsgUtil.callFunc("BOSS_DATA_INFO_UPDATE", msg.type);

		if msg.flag == 1 and DataCenter.neverTip:getNeverValue(Lua_NeverTipData.BOSS_RELIVE) == false then
			Lua_WindowUtil.openWin("Lua_TipsWindow", nil, {owner = self, neverTip = Lua_NeverTipData.BOSS_RELIVE,
				des = LanUtil.getValue(121621), type = 1});
			-- Lua_MsgUtil.callFunc("SHILED_BOSS_UI_AVATAR", true);
		end
	end
end

function Lua_BossProxy:rBossReliveTips(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto80403905");
		msg:ParseFromString(mp.data);
		Lua_WindowUtil.openWin("Lua_BossReliveTipsWindow", WinParam.ACTION_OPEN, msg);
	end
end

function Lua_BossProxy:rBossKillRecord(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto50401603");
		msg:ParseFromString(mp.data);
		Lua_MsgUtil.callFunc("BOSS_KILLED_RECORD_UPDATE", msg);
	end
end

function Lua_BossProxy:rKuaFuBossKillRecord(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto50101651");
		msg:ParseFromString(mp.data);
		Lua_MsgUtil.callFunc("BOSS_KILLED_RECORD_UPDATE", msg);
	end
end

function Lua_BossProxy:rEnterBossScene(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto50401601");
		msg:ParseFromString(mp.data);
		DataCenter.bossData:fromServer50401601(msg);
		if GlobalVar.hooking == true then
			DataCenter.hook:stop(true);
		end
		Lua_MsgUtil.callFunc("BOSS_ENTER_BOSS_SCENE");

		if Lua_WindowUtil.isWindowShowing("Lua_BossReliveTipsWindow") == true then
			Lua_WindowUtil.openWin("Lua_BossReliveTipsWindow", WinParam.ACTION_CLOSE);
		end
	end
end

function Lua_BossProxy:rBossDataInfo(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto50401602");
		msg:ParseFromString(mp.data);

		local detailInfo = DataCenter.bossData:getBossDetailByType(msg.type);
		detailInfo:fromServer(msg);
		Lua_MsgUtil.callFunc("BOSS_DATA_INFO_UPDATE", msg.type);
	end
end

function Lua_BossProxy:rKuaFuBossDataInfo(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto50101650");
		msg:ParseFromString(mp.data);

		local detailInfo = DataCenter.bossData:getBossDetailByType(msg.type)
		detailInfo:fromServer(msg);
		Lua_MsgUtil.callFunc("BOSS_DATA_INFO_UPDATE", msg.type);
	end
end

function Lua_BossProxy:rBossCopyResult(mp)
	if mp.errno == 0 then
		local msg = getProtoMsg("Proto80403904");
		msg:ParseFromString(mp.data);
		DataCenter.bossData:fromServer80403904(msg);
		Lua_WindowUtil.openWin("Lua_BossCopyResultPanel");
	end
end