-- 披风信息

Lua_CloakVo = class("Lua_CloakVo")
function Lua_CloakVo:ctor()
    self:superCall("ctor");
end

function Lua_CloakVo:formServer(obj)
	if obj == nil then
		return;
	end

	self.cloak_id = obj.id;               -- 披风id
    self.intensify_lvl = obj.level;       -- 强化等级
    self.star = obj.star;                 -- 星级
    self.isSwitch = obj.illusion_switch;  -- 幻化开关
    self.activate = obj.activate;         -- 激活状态

    self.adjoin_info = obj.adjoin_mana_info;   -- 附灵数据
    self.activate_num = obj.adjoin_mana_amount; -- 已激活条数
end

function Lua_CloakVo.Get:cloakConfig() -- 披风配置
    local config = getConfig({"cloak_info", self.cloak_id});
    if config == nil then
        return nil;
    end
    return config;
end

function Lua_CloakVo.Get:cloakName() -- 名字
    return self.cloakConfig.remark;
end

function Lua_CloakVo.Get:cloak_lvl() -- 等级
    local dec;
    if self.intensify_lvl == 0 then
        dec = LanUtil.getValue(10000);
    else
        dec = Lua_CommonUtil.transChineseNumber(self.intensify_lvl);
    end
    if getLanType() == 1 then
        local rs = "";
        local len = string.len(dec);
        for i=1,len do
            rs = rs..string.sub(dec, i, i).."\n";
        end
        return rs..LanUtil.getValue(110607);
    else
        return dec..LanUtil.getValue(110607);
    end
end

function Lua_CloakVo.Get:max_intensify_lvl() -- 最大强化等级
    return self.cloakConfig.star_limit_intensify[self.star+1];
end

function Lua_CloakVo.Get:name() -- 名字
    if self.intensify_lvl >0 then
        return self.cloakConfig.remark.."+"..self.intensify_lvl;
    else
        return self.cloakConfig.remark;
    end
end

function Lua_CloakVo.Get:decName() -- 名字
    if self.activate == 0 then
        return LanUtil.getValue(140001);
    else
        return LanUtil.formateStr(LanUtil.getValue(140010),tostring(self.cloakForce));
    end
end

function Lua_CloakVo.Get:shapeConfig() -- 模型数据
    return getConfig({"playerHanger", self.cloakConfig.illusion});
end

function Lua_CloakVo.Get:modelpos() -- 模型位置
    return self.cloakConfig.modelpos
end

function Lua_CloakVo.Get:modelros() -- 模型角度
    return self.cloakConfig.modelros
end

function Lua_CloakVo.Get:modelsca() -- 模型大小
    return self.cloakConfig.modelsca
end

function Lua_CloakVo.Get:pos() -- 锁位置
    return self.cloakConfig.pos
end

function Lua_CloakVo.Get:sacle() -- 锁大小
    return self.cloakConfig.sacle
end

function Lua_CloakVo.Get:isMaxStar() -- 是否升满星
    if self.star >= DataCenter.cloakData.cloak_star then
        return true;
    end

    return false;
end

function Lua_CloakVo.Get:isBreakIntensify() -- 是否强化突破  
    if self.intensify_lvl >= self.max_intensify_lvl then
        return true;
    end

    return false;
end

function Lua_CloakVo.Get:isMaxIntensifyLvl() -- 是否显示强化Tips
    local max_lvl = self.cloakConfig.star_limit_intensify[DataCenter.cloakData.cloak_star+1];
    if self.intensify_lvl >= max_lvl then
        return true;
    end

    return false;
end


function Lua_CloakVo.Get:activation_cost() -- 激活所需道具
    local arr = self.cloakConfig.activation_cost;
    if arr ~= nil then
        local _arr = Array();
        for i=1,#arr do
            local tvo = Lua_ToolVo.createToolVo(arr[i][1]);
            tvo.packType = 999;
            tvo.bagNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(arr[i][1]);
            tvo.needNum = arr[i][2];
            _arr:add(tvo);
        end

        return _arr;
    end

    return nil;
end

function Lua_CloakVo.Get:intensify_cost() -- 强化所需道具
    local arr = self.cloakConfig.intensify_cost;
    if arr ~= nil then
        local _arr = Array();
        for i=1,#arr do
            if i == self.intensify_lvl + 1 then
                local tvo = Lua_ToolVo.createToolVo(arr[i][1]);
                tvo.packType = 999;
                tvo.bagNum = DataCenter.cloakData:getIntensifySoulNum(tvo.color);
                tvo.needNum = arr[i][2];
                _arr:add(tvo);
            end
        end

        return _arr;
    end

    return nil;
end

function Lua_CloakVo.Get:upgrade_cost() -- 升星所需道具
    local star;
    if self.isMaxStar == true then
        star = self.star;
    else
        star = self.star + 1;
    end
    local arr = self.cloakConfig.upgrade_star_cost;
    if arr ~= nil then
        local _arr = Array();
        for i=1,#arr do
            if i == star then
                local tvo = Lua_ToolVo.createToolVo(arr[i][1]);
                tvo.packType = 999;
                tvo.bagNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(arr[i][1]);
                tvo.needNum = arr[i][2];
                _arr:add(tvo);
            end
        end

        return _arr;
    end

    return nil;
end

function Lua_CloakVo.Get:adjoin_cost() -- 附灵所需道具
    local arr = self.cloakConfig.adjoin_mana_cost;
    if arr ~= nil then
        local _arr = Array();
        for i=1,#arr do
            local tvo = Lua_ToolVo.createToolVo(arr[i][1]);
            tvo.packType = 999;
            tvo.bagNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(arr[i][1]);
            tvo.needNum = arr[i][2];
            _arr:add(tvo);
        end

        return _arr;
    end

    return nil;
end

-------------------------------------------------------------------------------------------------------------------------------------
-- 属性封装

-- 基础属性封装
function Lua_CloakVo.Get:cloakBaseProp()
    local str = "";
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val1 = getConfig({"cloak_prop", self.cloakConfig.base_prop[1], v});
        local val2 = getConfig({"cloak_prop", self.cloakConfig.intensify_prop[1], v});
        local val3 = getConfig({"cloak_prop", self.cloakConfig.star_prop[1], v});
        if val1 ~= nil and val2 ~= nil and val3 ~= nil  then
            if str == "" then
                str = "";
            else
                str = str.."\n";
            end

            local base_prop = val1[1];
            local intensify_prop = 0;
            local star_prop = 0;
            if self.activate == 1 then
                if self.intensify_lvl ~= 0 then
                    for i=1, self.intensify_lvl do
                        intensify_prop = intensify_prop + val2[1];
                    end
                end
                if self.star ~= 0 then
                    for i=1, self.star do
                        star_prop = star_prop + val3[1];
                    end
                end
            end
            base = base_prop + intensify_prop + star_prop;
            if Lua_ThingDefine.isPercentParam(v) then
                base = base.."%";
            end
            local s;
            if self.activate == 0 then
                s = "[555c68]"..Lua_ThingDefine.getParamName(v).."："..base.."[-]";
            else            
                s = "[3f6180]"..Lua_ThingDefine.getParamName(v).."：".."[-]".."[192e41]"..base.."[-]";
            end
            str = str..s;
        end
    end
    return str;
end

-- 升星属性封装
function Lua_CloakVo.Get:cloakStarProp()
    local str = "";
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"cloak_prop", self.cloakConfig.star_prop[1], v});
        if val ~= nil  then
            if str == "" then
                str = "";
            else
                str = str.."\n";
            end

            local base = 0;
            if self.star >0 then
                for i=1, self.star do
                    base = base + val[1];
                end
            end
            if Lua_ThingDefine.isPercentParam(v) then
                base = base.."%";
            end

            local s = "[3f6180]"..Lua_ThingDefine.getParamName(v).."：".."[-]".."[192e41]"..base.."[-]";
            str = str..s;
        end
    end

    return str;
end

-- 下级升星属性封装
function Lua_CloakVo.Get:cloakNextStarProp()
    local str = "";
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"cloak_prop", self.cloakConfig.star_prop[1], v});
        if val ~= nil  then
            if str == "" then
                str = "";
            else
                str = str.."\n";
            end

            local base = val[1];
            if self.star >0 then
                for i=1, self.star do
                    base = base + val[1];
                end
            end
            if Lua_ThingDefine.isPercentParam(v) then
                base = base.."%";
            end

            local s = base;
            str = str..s;
        end
    end
    
    return str;
end

-- 强化属性封装
function Lua_CloakVo.Get:cloakIntensifyProp()
    local str = "";
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"cloak_prop", self.cloakConfig.intensify_prop[1], v});
        if val ~= nil then
            if str == "" then
                str = "";
            else
                str = str.."\n";
            end

            local base = 0;
            if self.intensify_lvl > 0 then
                for i=1, self.intensify_lvl do
                    base = base + val[1];
                end
            end

            if Lua_ThingDefine.isPercentParam(v) then
                base = base.."%";
            end

            local s = "[3f6180]"..Lua_ThingDefine.getParamName(v).."：".."[-]".."[192e41]"..base.."[-]";
            str = str..s;
        end
    end

    return str;
end

-- 下级强化属性封装
function Lua_CloakVo.Get:cloakNextIntensifyProp()
    local str = "";
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"cloak_prop", self.cloakConfig.intensify_prop[1], v});
        if val ~= nil  then
            if str == "" then
                str = "";
            else
                str = str.."\n";
            end

            local base = val[1];
            if self.intensify_lvl > 0 then
                for i=1, self.intensify_lvl do
                    base = base + val[1];
                end
            end
            if Lua_ThingDefine.isPercentParam(v) then
                base = base.."%";
            end

            local s = base;
            str = str..s;
        end
    end
    
    return str;
end

-------------------------------------------------------------------------------------------------------------------------------------
-- 附灵处理

function Lua_CloakVo.Get:getAdjoinInfo() -- 获得附灵属性
    local arr = Array();
    for i,v in ipairs(self.adjoin_info) do
        if v.prop.obj_value ~= 0 then
            arr:add({att = v.prop.obj_id, value = v.prop.obj_value});
        end
    end

    return arr;
end

function Lua_CloakVo:getColorStr(value) -- 获得附灵色值
    local arr = getConfig({"cloak_base", "adjoin_color", "arr"});
    for i=1, #arr do
        if tonumber(value) >= tonumber(arr[i][1]) and tonumber(value) <= tonumber(arr[i][2]) then
            return tonumber(arr[i][3]);
        end
    end
end

function Lua_CloakVo.Get:isHaveBaseProp() -- 是否拥有 披风基础属性 加成
    for i,v in ipairs(self.adjoin_info) do
        if v.prop.obj_id == DataCenter.cloakData.prop_id then
            return v.prop.obj_value;
        end
    end

    return nil;
end

function Lua_CloakVo.Get:isShowAdjoinTips() -- 是否显示 附灵 突破Tips
    local list = self.cloakConfig.star_limit_adjoin_mana[self.star+1];
    
    for i,v in ipairs(list) do
        local idx = self.cloakConfig.adjoin_mana_prop[i];
        local value = getConfig({"cloak_adjoin_mana_prop", idx, "prop_base"});

        if self.getAdjoinInfo[i] == nil then
            return false;
        else
            if (self.getAdjoinInfo[i].value/value[2]) * 100 < v then
                return false;
            end
        end
    end
    return true;
end


-- 附灵属性名字
function Lua_CloakVo.Get:cloakAdjoinName()
    local str = "";

    local list =self.cloakConfig.adjoin_mana_prop;
    for i,v in ipairs(list) do
        if str == "" then
            str = "";
        else
            str = str.."\n";
        end

        local att;

        local s;
        if self.getAdjoinInfo[i] ~= nil then
            att =  getConfig( { "attr_common", self.getAdjoinInfo[i].att,"common"});
            local value = getConfig({"cloak_adjoin_mana_prop", v, "prop_base"});
            local num = string.format("%.2f", (self.getAdjoinInfo[i].value/value[2])*100);
            local color = Lua_ColorDefine.getItemColorStr(self:getColorStr(num));
            s = "["..color.."]"..Lua_ThingDefine.getParamName(att).."：".."[-]";
        else
            local prop = getConfig({"cloak_adjoin_mana_prop", v, "prop_base"});
            att = prop[1];
            s = "[555c68]"..Lua_ThingDefine.getParamName(att).."：".."[-]";
        end
        str = str..s;
    end

    return str;
end


-- 附灵属性封装
function Lua_CloakVo.Get:cloakAdjoinProp()
    local str = "";

    local list =self.cloakConfig.adjoin_mana_prop;
    for i,v in ipairs(list) do
        if str == "" then
            str = "";
        else
            str = str.."\n";
        end

        local att;
        local base;
        local s;
        if self.getAdjoinInfo[i] ~= nil then
            att = getConfig( { "attr_common", self.getAdjoinInfo[i].att, "show_percent"});
            base = string.format("%.2f", self.getAdjoinInfo[i].value);
            local value = getConfig({"cloak_adjoin_mana_prop", v, "prop_base"});
            local num = string.format("%.2f", (base/value[2])*100);
            if att == 1 then
                base = base.."%";
            end
            local percent;
            local color = Lua_ColorDefine.getItemColorStr(self:getColorStr(num));
            if self.isShowAdjoinTips == true and self.isMaxStar == true then
                percent = "["..color.."]".."("..LanUtil.getValue(140016)..")".."[-]";
            else
                percent = "["..color.."]".."("..num.."%"..")".."[-]";
            end
             
            s = "["..color.."]"..base.."[-]"..percent;
        else
            local prop = getConfig({"cloak_adjoin_mana_prop", v, "prop_base"});
            att = prop[1];
            base = prop[2];
            if Lua_ThingDefine.isPercentParam(att) then
                base = base.."%";
            end
            s = LanUtil.formateStr(LanUtil.getValue(141021), tostring(base));
        end
        str = str..s;
    end

    return str;
end

function Lua_CloakVo.Get:cloakBaseForce() --基础战力
    local list = {};
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val1 = getConfig({"cloak_prop", self.cloakConfig.base_prop[1], v});
        local val2 = getConfig({"cloak_prop", self.cloakConfig.intensify_prop[1], v});
        local val3 = getConfig({"cloak_prop", self.cloakConfig.star_prop[1], v});

        if val1 ~= nil and val2 ~= nil and val3 ~= nil   then
            local base_prop = val1[1];
            local intensify_prop = 0;
            local star_prop = 0;
            if self.activate == 1 then
                if self.intensify_lvl ~= 0 then
                    for i=1, self.intensify_lvl do
                        intensify_prop = intensify_prop + val2[1];
                    end
                end
                if self.star ~= 0 then
                    for i=1, self.star do
                        star_prop = star_prop + val3[1];
                    end
                end
            end

            list[v] = base_prop + intensify_prop + star_prop;
        end
    end

    if self.isHaveBaseProp ~= nil then
        return (Lua_FightUtil.caculateConfigForce(list) *self.isHaveBaseProp)/100
    else
        return 0;
    end
end

function Lua_CloakVo.Get:cloakAdjoinForce() -- 附灵战力
    if self.adjoin_info ~= nil then
        local force = {};
        for i,v in ipairs(self.adjoin_info) do
            if v.prop.obj_value ~= 0 then
                force[tonumber(v.prop.obj_id)] = v.prop.obj_value;
            end
        end

        return math.floor(Lua_FightUtil.caculateForce(force)+self.cloakBaseForce);
    end

    return 0;
end

function Lua_CloakVo.Get:cloakForce() -- 战力
    local list = {};
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val1 = getConfig({"cloak_prop", self.cloakConfig.base_prop[1], v});
        local val2 = getConfig({"cloak_prop", self.cloakConfig.intensify_prop[1], v});
        local val3 = getConfig({"cloak_prop", self.cloakConfig.star_prop[1], v});

        if val1 ~= nil and val2 ~= nil and val3 ~= nil   then
            local base_prop = val1[1];
            local intensify_prop = 0;
            local star_prop = 0;
            if self.activate == 1 then
                if self.intensify_lvl ~= 0 then
                    for i=1, self.intensify_lvl do
                        intensify_prop = intensify_prop + val2[1];
                    end
                end
                if self.star ~= 0 then
                    for i=1, self.star do
                        star_prop = star_prop + val3[1];
                    end
                end
            end

            list[v] = base_prop + intensify_prop + star_prop;
        end
    end

    return math.floor(Lua_FightUtil.caculateConfigForce(list)+self.cloakAdjoinForce);
end
---------------------------------------------------------------------------------------------------------------------------------------
-- 红点

-- 升星红点
function Lua_CloakVo.Get:isShowUpgradeStarRed()
    if self.isMaxStar == true then
        return false;
    end
    local isShowRed = false;
    if self.activate == 1 then
        local arr = self.upgrade_cost;
        if arr ~= nil then
            for i=1,arr:getSize() do
                if arr[i].bagNum >= arr[i].needNum then
                    isShowRed = true;
                end
            end
        end
        return isShowRed;
    end
    
    return isShowRed;
end

-- 激活红点
function Lua_CloakVo.Get:isShowActivatRed()
    local isShowRed = false;
    if self.activate == 0 then
        local arr = self.activation_cost;
        if arr ~= nil then
            for i=1,arr:getSize() do
                if arr[i].bagNum >= arr[i].needNum then
                    isShowRed = true;
                end
            end
        end
        return isShowRed;
    end

    return isShowRed;
end

-- 强化红点
function Lua_CloakVo.Get:isShowIntensifyRed()
    if self.isMaxIntensifyLvl == true then
        return false;
    end
    if self.isBreakIntensify == true then
        return false;
    end
    
    local isShowRed = false;
    if self.activate == 1 then
        local arr = self.intensify_cost;
        if arr ~= nil then
            for i=1,arr:getSize() do
                if arr[i].bagNum >= arr[i].needNum then
                    isShowRed = true;
                end
            end
        end
        return isShowRed;
    end
    
    return isShowRed;
end

-- 附灵红点
function Lua_CloakVo.Get:isShowAdjoinRed()
    if self.isShowAdjoinTips == true then
        return false;
    end

    local isShowRed = false;
    if self.activate == 1 then
        local arr = self.adjoin_cost;
        if arr ~= nil then
            for i=1,arr:getSize() do
                if arr[i].bagNum >= arr[i].needNum then
                    isShowRed = true;
                end
            end
        end
        return isShowRed;
    end
    
    return isShowRed;
end

-- 强化材料是否满足
function Lua_CloakVo.Get:isHaveIntensifyItem()
    local isShowRed = false;
    if self.activate == 1 then
        local arr = self.intensify_cost;
        if arr ~= nil then
            for i=1,arr:getSize() do
                if arr[i].bagNum >= arr[i].needNum then
                    isShowRed = true;
                end
            end
        end
        return isShowRed;
    end
    
    return isShowRed;
end

-- 附灵材料是否满足
function Lua_CloakVo.Get:isHaveAdjoinItem()
    local isShowRed = false;
    if self.activate == 1 then
        local arr = self.adjoin_cost;
        if arr ~= nil then
            for i=1,arr:getSize() do
                if arr[i].bagNum >= arr[i].needNum then
                    isShowRed = true;
                end
            end
        end
        return isShowRed;
    end
    
    return isShowRed;
end