-- 跨服充值/消费排行 数据类型
Lua_CrossServerPurchasingData = class("Lua_CrossServerPurchasingData");
Lua_CrossServerPurchasingData.GOLD_TYPE  = 0  -- 跨服充值
Lua_CrossServerPurchasingData.GIFT_TYPE  = 1  -- 跨服消费

function Lua_CrossServerPurchasingData:ctor()
    self:dispose();
end

function Lua_CrossServerPurchasingData:dispose()
    self.rewardInfo = {};
    self.gold_buy_num = 0;
    self.gift_buy_num = 0;
    self.roll_list = nil;
    self.isInfiniteBuy = false;
    self.isInitMsg = false;
end

function Lua_CrossServerPurchasingData:fromServerInfo(msg)
    if msg == nil then
        return
    end
    self.isInitMsg = true;

    self.act_id = msg.acitivty_info.act_id;           -- 活动ID
    self.first_type = msg.acitivty_info.second_type;  -- 活动子类型
    self.need_gold = msg.acitivty_info.need_gold;     -- 上榜的最低元宝数
    self.act_content = tostring(msg.acitivty_info.content); -- 内容

    self.left_time = msg.reward_tick;           -- 剩余时间
    self.big_reward_list = msg.big_reward_list; -- 大奖列表
    self.reward_list = msg.reward_list;         -- 奖励显示列表
    self.record_list = msg.record_list;         -- 购买记录
    
    self.goldNum = msg.gold;       -- 元宝价格
    self.giftNum = msg.bind_gold;  -- 礼金价格
    self.free_buy_time = msg.free_buy_time;  -- 自由购买时间
    self.infinite_buy_time = self.free_buy_time*3600;  -- 不限购购买时间

    self.isInfiniteBuy = self.left_time - DataCenter.roleData.serverTime-1 <= self.infinite_buy_time;
    self.showTime = TimeTransform.getInstance():transSeconds8(self.left_time, "MM-dd HH:mm");      -- 大奖开启时间

    self.rewardInfo = {};
    for i,v in ipairs(msg.reward_list) do -- 活动标记
       self.rewardInfo[v.type] = 1;
    end
end

function Lua_CrossServerPurchasingData:getRewardInfo(itemVo,reward_number) -- 获得大奖信息
    local arr = Array();
    for i=1,reward_number do
        local list = {};
        if self.roll_list ~= nil then
            if self.roll_list[i] ~= nil then
                list.name = LanUtil.formateStr(LanUtil.getValue(141414),tostring(self.roll_list[i].server_name),tostring(self.roll_list[i].role_name));
            else
                list.name = LanUtil.getValue(141417);
            end
        else
            list.name = LanUtil.getValue(141417);
        end
        list.showTime = self.showTime;
        list.itemVo = itemVo;
        arr:add(list)
    end
    return arr;
end

function Lua_CrossServerPurchasingData:getActiviteItemInfo(_type) -- 获取活动数据
    if self.big_reward_list == nil then
        return Array();
    end

    local arr = Array();
    local big_reward_list = self.big_reward_list
    for k, v in ipairs(big_reward_list) do
        local _list = {};
        
        if v.type == _type then
            _list.index = v.index; -- 大奖索引
            _list.state = v.state; -- 0未开奖，1已开奖
            local tvo = Lua_ToolVo.createToolVo(v.reward.id,v.reward.amount,v.reward.bind);
            tvo.star = v.reward.equipment.star;
            _list.itemVo = tvo;

            _list.reward_number = v.reward_number; -- 大奖名额
            _list.cur_buy_times = v.cur_buy_times; -- 当前购买次数
            _list.max_buy_times = v.max_buy_times; -- 最大购买次数
        
            _list.cur_schedule = v.cur_schedule; -- 当前全服购买次数
            _list.act_schedule = v.act_schedule; -- 大奖名额激活进度

            arr:add(_list);
        end
    end

    return arr;
end

function Lua_CrossServerPurchasingData:getActiviteRewardInf(_type) -- 奖励显示列表
    if self.reward_list == nil then
        return Array();
    end

    local arr = Array();
    local reward_list = self.reward_list;
    for k, v in ipairs(reward_list) do
        if v.type == _type then
            for i,j in ipairs(v.item_list) do
                local itemVo = Lua_ToolVo.createToolVo(j.id,j.amount,j.bind);
                itemVo.star = j.equipment.star;
                arr:add(itemVo);
            end
        end
    end
    
    return arr;
end

function Lua_CrossServerPurchasingData:getActiviteRecordInfo(_type) -- 购买记录
    if self.record_list == nil then
        return Array();
    end

    local arr = Array();
    local record_list = self.record_list;
    for k, v in ipairs(record_list) do
        if v.type == _type then
            for i,j in ipairs(v.record_list) do
                arr:add({ server_name = j.server_name,role_id = j.role_id, role_name = j.role_name, value = j.value});
            end
        end
    end

    return arr;
end

function Lua_CrossServerPurchasingData.Get:getOpenActiviteType() -- 开启专场类型
    if self.isOpenGoldActivite == true and self.isOpenGiftActivite == true then
        return 0;
    else
        if self.isOpenGoldActivite == true then
            return 1;
        elseif self.isOpenGiftActivite == true then
            return 2;
        end
    end
    return false;
end


function Lua_CrossServerPurchasingData.Get:isOpenGoldActivite() -- 是否开启元宝专场
    local list = self.rewardInfo;
    if list[Lua_CrossServerPurchasingData.GOLD_TYPE] == 1 then
        return true;
    end
    return false;
end


function Lua_CrossServerPurchasingData.Get:isOpenGiftActivite() -- 是否开启礼金专场
    local list = self.rewardInfo;
    if list[Lua_CrossServerPurchasingData.GIFT_TYPE] == 1 then
        return true;
    end
    return false;
end

function Lua_CrossServerPurchasingData.Get:isOpenReward() -- 是否开启大奖
    for k, v in ipairs(self.big_reward_list) do
        if v.state == 1 then --0未开奖，1已开奖
            return true;
        end
    end
    return false;
end


function Lua_CrossServerPurchasingData.Get:getGoldPrice() -- 元宝消费
    if self.goldNum == nil then
        return;
    end

    if self.gold_buy_num == 0 then
        return self.goldNum;
    elseif self.gold_buy_num == 1 then
        return self.goldNum * 10;
    end
end

function Lua_CrossServerPurchasingData.Get:getGiftPrice() -- 礼金消费
    if self.giftNum == nil then
        return;
    end

    if self.gift_buy_num == 0 then
        return self.giftNum;
    elseif self.gift_buy_num == 1 then
        return self.giftNum * 10;
    end
end
