-- 跨服充值/消费排行 数据类型
Lua_CrossServerRechargeData = class("Lua_CrossServerRechargeData");
Lua_CrossServerRechargeData.ACT_RECHARGE  = 1051  -- 跨服充值
Lua_CrossServerRechargeData.ACT_CONSUME  = 1052  -- 跨服消费
function Lua_CrossServerRechargeData:ctor()
	self:dispose();
end

function Lua_CrossServerRechargeData:dispose()
	self.activity_type = 0;
	self.recharge_index = 1;
	self.consume_index = 1;
	self.rechargeRed = false;
	self.consumeRed = false;
end

function Lua_CrossServerRechargeData:fromServer50105601(msg)
	if msg == nil then
		return;
	end
	self.rankInfo = msg.rankers;             -- 排名信息
	self.rank_reward = msg.rank_reward;      -- 排名奖励
	self.acc_reward = msg.acc_reward;        -- 累计奖励
	self.server_flag = msg.server_flag       -- 跨服服务器标识
	if msg.rank == 0 then -- 排名
		self.rank_dic = LanUtil.formateStr(LanUtil.getValue(141007), LanUtil.getValue(141010));
	else
		self.rank_dic = LanUtil.formateStr(LanUtil.getValue(141007), tostring(msg.rank));
	end

	self.role_id = msg.role_id;       -- 玩家ID
	self.total_gold = msg.total_gold; -- 累计金额
	self.content = msg.activity_info.content;   -- 内容
	self.end_tick = msg.activity_info.end_tick; -- 结束时间
	self.start_tick = msg.activity_info.start_tick;-- 开始时间
	self.left_time = self.end_tick - self.start_tick;
	self.first_type = msg.first_type;      -- 活动类型
	self.travel_act = msg.travel_act;      -- 是否为跨服
end

function Lua_CrossServerRechargeData.Get:openActiviteType() -- 开启那个活动判断
	if self.first_type == Lua_CrossServerRechargeData.ACT_RECHARGE then
		return 1;
	elseif self.first_type == Lua_CrossServerRechargeData.ACT_CONSUME then
		return 0;
	end
	return nil;
end

function Lua_CrossServerRechargeData.Get:isHaveFirst() -- 是否有第一名
	for i,v in ipairs(self.rankInfo) do
		if v.value >= self.rank_reward[1].cond[1] then
			return true;
		end
	end
	return false;
end

function Lua_CrossServerRechargeData.Get:getFirstRechargeNum() -- 至少充值/消费
	if self.openActiviteType == 1 then
		return LanUtil.formateStr(LanUtil.getValue(141004), tostring(self.rank_reward[1].cond[1]));
	elseif self.openActiviteType == 0 then
		return LanUtil.formateStr(LanUtil.getValue(141017), tostring(self.rank_reward[1].cond[1]));
	end
end

function Lua_CrossServerRechargeData.Get:getFirstName() -- 第一名 名字
	if self.isHaveFirst == true then
		return self.getRankInfo[1].name;
	else
		return LanUtil.getValue(141011);
	end
end

function Lua_CrossServerRechargeData.Get:getFirstAward() -- 第一名 奖励显示
	return self.getRankRewaedInfo[1].itemArr;
end

function Lua_CrossServerRechargeData.Get:getRankInfo()
	local _list;
	local arr = Array();
	local curRankIndex = 1;
	for i = 1, 100 do
		_list = {};
		if self.rankInfo[curRankIndex] ~= nil then
			if self.rankInfo[curRankIndex].rank == i then
				local v = self.rankInfo[curRankIndex];
				_list.role_id = v.role_id;
				_list.server_flag = v.server_flag;
				_list.rank = v.rank;
				_list.name = v.server_name.."\n"..v.name;
				_list.money = v.value;
				curRankIndex = curRankIndex + 1;
			else
				_list.role_id = 0;
				_list.server_flag = "0";
				_list.rank = i;
				_list.name = LanUtil.getValue(120014);
				_list.money = "";
			end
			arr:add(_list);
		else
			break;
		end
	end
	return arr;
end

function Lua_CrossServerRechargeData.Get:getRankRewaedInfo()
	local itemArr;
	local arr = Array();
	for i,v in ipairs(self.rank_reward) do
		itemArr = Array();
		for k,j in ipairs(v.reward_items) do
			itemArr:add({id = j.id, count = j.amount, bind = j.bind, star = j.equipment.star,
				roundEffect = j.show_effect == 1 and true or false})
		end

		arr:add({num = v.cond[1], rank = v.cond[2] == v.cond[3] and v.cond[2] or v.cond[2].."~"..v.cond[3],
			itemArr = itemArr})
	end
	return arr;
end

function Lua_CrossServerRechargeData:getAccRewaedInfo(index)
	if index <= 1 then
		index = 1;
	end

	if index > #self.acc_reward then
		index = #self.acc_reward;
	end

	local info = self.acc_reward[index];
	local tvo;
	local itemArr = Array();
	for k,j in ipairs(info.reward_items) do
		tvo = Lua_ToolVo.createToolVo(j.id, j.amount, j.bind)
		tvo.star = j.equipment.star;
		tvo.roundEffect = j.show_effect == 1 and true or false;
		itemArr:add(tvo)
	end
	return {index = info.index, curIndex = index, content = info.content, state = info.state, itemArr = itemArr};
end

-- 最大奖励页
function Lua_CrossServerRechargeData.Get:max_select_index()
	return #self.acc_reward;
end

-- 是否选择最大页
function Lua_CrossServerRechargeData.Get:is_max_select_index()
	if self.openActiviteType == 1 then
		if self.recharge_index >= self.max_select_index then
			return true;
		end
	elseif self.openActiviteType == 0 then
		if self.consume_index >= self.max_select_index then
			return true;
		end
	end
	return false;
end

-- 获得奖励索引
function Lua_CrossServerRechargeData.Get:getAwardIndex()
	local info = self.acc_reward;
	for i,v in ipairs(info) do
		if v.state == 1 then
			return i;
		end
	end
	return 1;
end

-- 是否可以领取红点
-- function Lua_CrossServerRechargeData.Get:isShowDrawRed()
-- 	local info = self.acc_reward;
-- 	for i,v in ipairs(info) do
-- 		if v.state == 1 then
-- 			return true;
-- 		end
-- 	end
-- 	return false;
-- end

-- 可领取奖励最小索引
function Lua_CrossServerRechargeData.Get:getMinDrawInddex()
	local info = self.acc_reward;
	for i,v in ipairs(info) do
		if v.state == 1 then
			return i;
		end
	end
	return 1;
end

-- 红点处理
function Lua_CrossServerRechargeData:fromServerActiveInfo(msg)
	if msg == nil then
		return;
	end
	self.act_states = msg.act_states;
end

-- 跨服充值消费红点检测
function Lua_CrossServerRechargeData:checkServerRedDotSate()
	self:isShowRechargeIconRed(self:isShowRechargeRed());
	self:isShowConsumeIconRed(self:isShowConsumeRed());
end

-- 充值
function Lua_CrossServerRechargeData:isShowRechargeRed()
	if self.act_states == nil then
		return false;
	end

	for i,v in ipairs(self.act_states) do
		if v.first_type == Lua_CrossServerRechargeData.ACT_RECHARGE and v.has_reward == 1 then
			self.rechargeRed = true;
		elseif v.first_type == Lua_CrossServerRechargeData.ACT_RECHARGE and v.has_reward == 0 then
			self.rechargeRed = false;
		end
	end
	return self.rechargeRed;
end

-- 消费
function Lua_CrossServerRechargeData:isShowConsumeRed()
	if self.act_states == nil then
		return false;
	end

	for i,v in ipairs(self.act_states) do
		if v.first_type == Lua_CrossServerRechargeData.ACT_CONSUME and v.has_reward == 1 then
			self.consumeRed = true;
		elseif v.first_type == Lua_CrossServerRechargeData.ACT_CONSUME and v.has_reward == 0 then
			self.consumeRed = false;
		end
	end
	return self.consumeRed;
end

-- 充值
function Lua_CrossServerRechargeData:isShowRechargeIconRed(bool)
	DataCenter.redDotData:updateRedDotVoState(22048, bool); -- 客户端主动添加红点事件
	Lua_MsgUtil.callFunc("UPDATE_REDDOT_EVENT", {evenId = 22048, val = bool and 1 or 0, bShow = bool});
	Lua_MsgUtil.callFunc("NOTICE_BESTRONG_STATE", bool); -- 变强事件
end

-- 消费
function Lua_CrossServerRechargeData:isShowConsumeIconRed(bool)
	DataCenter.redDotData:updateRedDotVoState(22049, bool); -- 客户端主动添加红点事件
	Lua_MsgUtil.callFunc("UPDATE_REDDOT_EVENT", {evenId = 22049, val = bool and 1 or 0, bShow = bool});
	Lua_MsgUtil.callFunc("NOTICE_BESTRONG_STATE", bool); -- 变强事件
end