Lua_PlayerDeadWindow = class("Lua_PlayerDeadWindow", Lua_Window);
function Lua_PlayerDeadWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_PlayerDeadWindow";
	self.skinName = "PlayerDeadWindow_skin";
	self.showClose = false;
end

function Lua_PlayerDeadWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.canCountDown = true;

	self.itemId = Lua_CommonUtil.getCommonConfig("relive_item", 1);
	self.toolImg = Lua_ToolImage.new(self.content);
	self.toolImg:setDepth(5);
	self.toolImg:setLocation(0, 0, 0);
	self.toolImg.data = Lua_ToolVo.new(self.itemId, 1, 0);

	if DataCenter.killData ~= nil then
	    self.killName = DataCenter.killData.fighter_name;
	else
	    self.killName = LanUtil.getValue(110616);
	end
	DataCenter.killData = nil;

	self.lastSendTime = getTime();

	self.startTime = getTime();
	Lua_CommonUtil.addTimer("reliveCount", 0.5, self, self.onCountDown);
	self:onCountDown();

	self.infoTxt.clickScale = false;
	self.infoTxt:addUrlClickFuntion(self, self.onUrlClick);

	self.strongLabel.clickScale = false;
	self.strongLabel:addClickFuntion(self, self.onBeStrongClick);
	self.yuandiBtn:addClickFuntion(self, self.onYuandiClick);
	self.anquanBtn:addClickFuntion(self, self.onAnquanClick);
end

function Lua_PlayerDeadWindow:showWin(param)
	self.data = param;
	self.config = param.config;
end

function Lua_PlayerDeadWindow:onCountDown()
	if DataCenter.roleData.hp > 0 then
		self:hide();
		return;
	end

	if self.canCountDown == false then
		return;
	end

	local leftTime = 0;
	local buffId = Lua_CommonUtil.getCommonConfig("relive_limit_buff", 1);
	local buffData = DataCenter.roleData:getBuffById(buffId, true);
	if buffData ~= nil then
		leftTime = buffData.leftTime;
	else
		self.anquanBtn:setBtnEnable(true);
		if self.config ~= nil and self.config.wait ~= nil then
			leftTime = self.config.wait -(getTime() - self.startTime);
		else
			leftTime = Lua_CommonUtil.getCommonConfig("relive_time", 1) -(getTime() - self.startTime);
		end
	end

	local sceneData = Lua_SceneConfigData.getSceneConfig(DataCenter.roleData.sceneId);
	if sceneData.no_auto_relive == 0 and DataCenter.hangUpSettingsData.relive_type == 1 then
		self:autoRelive();
	end

	if sceneData.is_yuandi_relive == 1 then
		self.yuandiBtn:setBtnEnable(false);
	else
		self.yuandiBtn:setBtnEnable(true);
	end

	self.anquanBtn.label = "安全復活";
	if leftTime <= 0 then
		self:onAnquanClick();
	else
		leftTime = math.floor(leftTime);
		local str = LanUtil.formateStr(LanUtil.getValue(110615), self.killName, tostring(leftTime));
		if buffData ~= nil then
			str = str.."\n"..LanUtil.formateStr(LanUtil.getValue(110656), tostring(buffData.value1));
			if buffData.value1 > getConfig({"tiny", "die_punish_critical"}) then
				str = str.."\n"..LanUtil.getValue(110657);
				local pt = getConfig({"tiny", "advance_relive_time", buffData.value1});
				if pt == nil then
					pt = 10;
				end

				local lt = leftTime - pt;
				if lt > 0 then
					self.anquanBtn.label = "安全復活[00E125]("..lt.."S)[-]";
					self.anquanBtn:setBtnEnable(false);
				else
					self.anquanBtn.label = "安全復活";
					self.anquanBtn:setBtnEnable(true);
				end
			end
		end
		self.infoTxt.text = str;
	end
end

function Lua_PlayerDeadWindow:autoRelive()
	if getTime() - self.lastSendTime < 1 then
		return;
	end
	self.lastSendTime = getTime();
	
	local itemId = Lua_CommonUtil.getCommonConfig("relive_item", 1);
	local tvo = Lua_ToolVo.new(itemId);
	if DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.GOLD_AND_BINDGOLD, tvo.goldPrice, false, false) == false then
		return;
	end
	OperateAlert.show(LanUtil.getValue(110648));
	self:reliveYuandi();
end

function Lua_PlayerDeadWindow:onUrlClick(url)
	if url ~= nil then
		Lua_WindowUtil.openWin("Lua_RuleTipWindow", WinParam.ACTION_AUTO, LanUtil.getValue(110658));
	end
end

function Lua_PlayerDeadWindow:onBeStrongClick(go)
	if DataCenter.funcOpenData:isOpened(10006) == false then
		local s = getConfig({"func_open", 10006, "advance_message"});
		if s ~= nil then
			OperateAlert.show(s);
		end
		return;
	end
	Lua_WindowUtil.openWin("Lua_ForgingWindow", WinParam.ACTION_AUTO, nil);
end

function Lua_PlayerDeadWindow:onYuandiClick(go)
	local itemId = Lua_CommonUtil.getCommonConfig("relive_item", 1);
	local num = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(itemId);
	if num > 0 then
		self:reliveYuandi();
	else
		if DataCenter.neverTip:getNeverValue(Lua_NeverTipData.RELIVE) == true then
			self:reliveYuandi();
		else
			local tvo = Lua_ToolVo.new(itemId);
			local tipData = {};
			tipData.des = LanUtil.formateStr(LanUtil.getValue(110619), tostring(tvo.goldPrice));
			tipData.owner = self;
			tipData.subFun = self.onSubCallback;
			tipData.countDown = 10;
			tipData.neverTip = Lua_NeverTipData.RELIVE;
			tipData.type = 1;
			Lua_WindowUtil.openWin("Lua_TipsWindow", nil, tipData);
		end
	end
end

function Lua_PlayerDeadWindow:reliveYuandi()
	local cmd = ProtoPublic_pb.Proto10400203();
	cmd.relive = 2;
	local itemId = Lua_CommonUtil.getCommonConfig("relive_item", 1);
	cmd.item_id = itemId;
	sendMsg(10400203, cmd);
end

function Lua_PlayerDeadWindow:onSubCallback(tipData)
	local itemId = Lua_CommonUtil.getCommonConfig("relive_item", 1);
	local tvo = Lua_ToolVo.new(itemId);
	if DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.GOLD_AND_BINDGOLD, tvo.goldPrice, true, false) == false then
		return;
	end
	self:reliveYuandi();
end

function Lua_PlayerDeadWindow:onAnquanClick(go)
	-- local buffId = Lua_CommonUtil.getCommonConfig("relive_limit_buff", 1);
	-- local buffData = DataCenter.roleData:getBuffById(buffId, true);
	-- if buffData ~= nil and buffData.leftTime > 0 then
	-- 	OperateAlert.show(LanUtil.getValue(110653));
	-- 	return;
	-- end

	local cmd = ProtoPublic_pb.Proto10400203();
	cmd.relive = 1;
	sendMsg(10400203, cmd);
end

function Lua_PlayerDeadWindow:dispose()
	Lua_CommonUtil.removeTimer(self, self.onCountDown);
	self:superCall("dispose");
end