-- 幻星数据

Lua_EidolonVo = class("Lua_EidolonVo")
function Lua_EidolonVo:ctor(id)
    self:superCall("ctor");
    self.id = id;
    self.config = getConfig( { "fantasy_soul", id });-- 幻星配置
end

function Lua_EidolonVo:formServer(obj)
	if obj == nil then
		return;
	end

	self.id = obj.id;               -- 幻灵id
    self.color = obj.color;         -- color
    self.star_lvl = obj.star_lvl;   -- 星级
    self.intensify_lvl = obj.intensify_lvl;      -- 强化等级
    self.activation_state = obj.activation_state;-- 激活状态
end

function Lua_EidolonVo.Get:isMaxIntensify() -- 是否达到最大强化等级
	if self.intensify_lvl == self.max_intensify_lvl then
		return true;
	end

	return false;
end

function Lua_EidolonVo.Get:max_intensify_lvl() -- 最大强化等级
	local arr = self.config.intensify_cost;
	if arr ~= nil then
		return #arr;
	end

	return 0;
end

function Lua_EidolonVo.Get:name() -- 名字
	return self.config.name;
end

function Lua_EidolonVo.Get:item_name() -- 名字
	return "Lv."..self.intensify_lvl..self.name;
end

function Lua_EidolonVo.Get:left_lvl() -- 等级
	return "Lv."..self.intensify_lvl;
end

function Lua_EidolonVo.Get:sort() -- 排序
	return self.config.sort;
end

function Lua_EidolonVo.Get:item_type() -- 类型
	return self.config.type;
end

function Lua_EidolonVo.Get:decompose() -- 分解
    return self.config.decompose_num[2];
end

function Lua_EidolonVo.Get:decompose_id() -- 分解材料ID
    return self.config.decompose_num[1];
end

function Lua_EidolonVo.Get:atlas_name() -- 头像名
	return "/images/head/eidolon/"..self.config.atlas_name..".png";
end

function Lua_EidolonVo.Get:illusion() -- 模型数据
    return self.config.illusion
end

function Lua_EidolonVo.Get:modelpos() -- 模型位置
    return self.config.modelpos;
end

function Lua_EidolonVo.Get:modelros() -- 模型角度
    return self.config.modelros;
end

function Lua_EidolonVo.Get:modelsca() -- 模型大小
    return self.config.modelsca;
end

function Lua_EidolonVo.Get:depict() -- 获得描述
    return self.config.depict;
end

function Lua_EidolonVo.Get:activation_item() -- 激活所需道具
    local list = self.config.activation_cost;
    if list ~= nil then
        local tvo = Lua_ToolVo.createToolVo(tonumber(list[1]));
        tvo.packType = 999;
        tvo.bagNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(tonumber(list[1]));
        tvo.needNum = tonumber(list[2]);
        return tvo;
    end

    return nil;
end

function Lua_EidolonVo.Get:intensify_item() -- 强化消耗
	local arr = self.config.intensify_cost;
    if arr ~= nil then
        local tvo = Lua_ToolVo.createToolVo(tonumber(arr[self.intensify_lvl+1][1]));
        tvo.packType = 999;
        tvo.bagNum = DataCenter.eidolonData.fantasy_soul_stone;
        tvo.needNum = tonumber(arr[self.intensify_lvl+1][2]);
        return tvo;
    end

    return nil;
end

function Lua_EidolonVo.Get:eidolonStarConfig() -- 升星数据
    return getConfig({"fantasy_soul_star", self.id})
end

function Lua_EidolonVo.Get:isMaxUpgardStar() -- 是否最大等级
    if self.star_lvl == DataCenter.eidolonUtil.maxStarNum then
    	return true;
    end

    return false;
end

function Lua_EidolonVo.Get:isUpgardStar() -- 是否可以升星
    if self.eidolonStarConfig ~= nil then
    	return true;
    end
    return false;
end

function Lua_EidolonVo.Get:upgard_star_Item() -- 升星消耗
	local arr = self.eidolonStarConfig.star_upgrade;
    if arr ~= nil then
        local tvo = Lua_ToolVo.createToolVo(tonumber(arr[self.star_lvl+1][1]));
        tvo.packType = 999;
        tvo.bagNum = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(tonumber(arr[self.star_lvl+1][1]));
        tvo.needNum = tonumber(arr[self.star_lvl+1][2]);
        return tvo;
    end

    return nil;
end

-- 属性封装
function Lua_EidolonVo.Get:eidolonBaseProp() -- 幻灵封装
    local arr = Array();
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"fantasy_soul", self.id, v});
        if val ~= nil then
            if self.activation_state == 0 then
                local attr_num = "0";
                local attr_add = val[self.intensify_lvl+1];
                if Lua_ThingDefine.isPercentParam(v) then
                    attr_num = attr_num.."%";
                    attr_add = attr_add.."%";
                end

                arr:add({attr_name = Lua_ThingDefine.getParamName(v); attr_num = attr_num; attr_add = attr_add});
            else
                local attr_num;
                local attr_add;
                if self.isMaxIntensify == true then --达到最大等级
                    if val[self.intensify_lvl+1] == nil then
                        attr_num = val[1];
                    else
                        attr_num = val[self.intensify_lvl+1];
                    end
                    attr_add = nil;
                    if Lua_ThingDefine.isPercentParam(v) then
                        attr_num = attr_num.."%";
                    end
                else
                    if val[self.intensify_lvl+2] == val[1] then
                        attr_num = val[1];
                        attr_add = nil;
                        if Lua_ThingDefine.isPercentParam(v) then
                            attr_num = attr_num.."%";
                        end
                    else
                        attr_num = val[self.intensify_lvl+1];
                        attr_add = val[self.intensify_lvl+2] - attr_num;
                        if Lua_ThingDefine.isPercentParam(v) then
                            attr_num = attr_num.."%";
                            attr_add = attr_add.."%";
                        end
                    end
                end
                 
                arr:add({attr_name = Lua_ThingDefine.getParamName(v); attr_num = attr_num; attr_add = attr_add})
            end
        end
    end

    return arr;
end

function Lua_EidolonVo.Get:eidolonStarBaseProp() -- 幻灵升星封装
    local str = "";
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"fantasy_soul_star", self.id, v});
        if val ~= nil then
            if str == "" then
                str = "";
            else
                str = str.."\n";
            end

            local base;
            if self.star_lvl == 0 then
	            base = "0";
	        else
	        	base = val[self.star_lvl];
	        end
	        if Lua_ThingDefine.isPercentParam(v) then
                base = base.."%";
            end
	        local s = "[3f6180]"..Lua_ThingDefine.getParamName(v)..":".."[-]".."[192e41]"..base.."[-]";
            str = str..s;
        end
    end

    return str;
end

function Lua_EidolonVo.Get:eidolonStarNextProp() -- 幻灵升星下级属性
    local str = "";
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"fantasy_soul_star", self.id, v});
        if val ~= nil then
            if str == "" then
                str = "";
            else
                str = str.."\n";
            end

            local base;
        	base = val[self.star_lvl+1];
        	if Lua_ThingDefine.isPercentParam(v) then
                base = base.."%";
            end
	        local s = "[3f6180]"..Lua_ThingDefine.getParamName(v)..":".."[-]".."[192e41]"..base.."[-]";
            str = str..s;
        end
    end

    return str;
end


function Lua_EidolonVo.Get:eidolonBaseForce() -- 幻灵战力
	if self.activation_state == 0 then
		return 0;
	end

    local list = {};
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val = getConfig({"fantasy_soul", self.id, v});
        if val ~= nil then
            list[v] = val[self.intensify_lvl + 1];
        end
    end

    return Lua_FightUtil.caculateConfigForce(list) + self.eidolonStarForce;
end

function Lua_EidolonVo.Get:eidolonStarForce() -- 幻灵升级战力
    if self.isUpgardStar == false or self.star_lvl == 0 then
        return 0;
    end

    local list = {};
    for k,v in ipairs(Lua_ThingDefine.params) do
        local val =  getConfig({"fantasy_soul_star", self.id, v});
        if val ~= nil then
            list[v] = val[self.star_lvl];
        end
    end
    
    return Lua_FightUtil.caculateConfigForce(list);
end

---------------------------------------------------------------------------------------------------------------------------------------

-- 检测item 红点
function Lua_EidolonVo.Get:checkEidolonItemRed()
	if self.isShowActivationRed == true or self.isShowUpgardRed == true or self.isShowStarUpgardRed == true then
		return true;
	end
    
	return false;
end

-- 激活红点
function Lua_EidolonVo.Get:isShowActivationRed()
	if self.activation_state == 0 then
		if self.activation_item.bagNum >= self.activation_item.needNum then
			return true;
		end
	end

	return false;
end

-- 升级红点
function Lua_EidolonVo.Get:isShowUpgardRed()
	if self.activation_state == 1 and self.isMaxIntensify == false and self.intensify_item.bagNum >= self.intensify_item.needNum then
		return true;
	end

	return false;
end

-- 升星红点
function Lua_EidolonVo.Get:isShowStarUpgardRed()
	if self.activation_state == 1 and self.isUpgardStar == true and self.isMaxUpgardStar == false
		and self.upgard_star_Item.bagNum >= self.upgard_star_Item.needNum then
		return true;
	end

	return false;
end