checkRequire("Lua_FairyData");
checkRequire("Lua_FairyVo");
Lua_FairyProxy = class("Lua_FairyProxy");
function Lua_FairyProxy:ctor()
	DataCenter.fairyData = Lua_FairyData.new();

	LuaUtil.addLuaMsg(51409001, self, self.rGetPanelInfo);
	LuaUtil.addLuaMsg(51409002, self, self.rEquipFairy);
	LuaUtil.addLuaMsg(81409001, self, self.rGetFairyInfo);
	LuaUtil.addLuaMsg(51409003, self, self.rRenewalFairy);
	LuaUtil.addLuaMsg(81409002, self, self.rLoginFairyExpireInfo);
	
	Lua_MsgUtil.addEventListener("SCENE_LOADED", self, self.onSceneChange); -- 场景切换
	Lua_MsgUtil.addEventListener("updateChatMiniFairyIcon", self, self.updateChatMiniFairyIcon);
end

function Lua_FairyProxy:rGetPanelInfo(mp)
	if mp.errno == 0 then
		local msg = ProtoPublic_pb.Proto51409001();
		msg:ParseFromString(mp.data);
		DataCenter.fairyData:fromServer51409001(msg);
		Lua_MsgUtil.callFunc("FAIRY_PANEL_UPDATE");
		Lua_MsgUtil.callFunc("FAIRY_EQUIP_UPDATE");
		Lua_MsgUtil.callFunc("FAIRY_ICON_UPDATE");
		self:updateChatMiniFairyIcon();
		self:checkFairyCountDown();
	end
end

function Lua_FairyProxy:rEquipFairy(mp)
	self:sFairyInfo();
end

function Lua_FairyProxy:rGetFairyInfo(mp)
	if mp.errno == 0 then
		local msg = ProtoPublic_pb.Proto81409001();
		msg:ParseFromString(mp.data);
		DataCenter.fairyData:fromServer81409001(msg);
		local isExpire = DataCenter.fairyData.isExpire;
		local curFairyIndex = DataCenter.fairyData.curFairyIndex;

		if isExpire == 1 then -- 到期
			local fairyVo = DataCenter.fairyData.fairyList[curFairyIndex];
			if fairyVo ~= nil then
				self:sPutOffFairy({id = fairyVo.itemId});
			end
		elseif isExpire == 0 then -- 未到期
			-- print("未到期");
		end
	end
end

function Lua_FairyProxy:rRenewalFairy(mp)
	if mp.errno == 0 then
		local msg = ProtoPublic_pb.Proto51409003();
		msg:ParseFromString(mp.data);
		DataCenter.fairyData:fromServer51409003(msg);
	end
end

function Lua_FairyProxy:rLoginFairyExpireInfo(mp)
	if mp.errno == 0 then
		local msg = ProtoPublic_pb.Proto81409002();
		msg:ParseFromString(mp.data);
		self:loginFairyExpireHandle(msg.fairy_type)
	end
end

function Lua_FairyProxy:onSceneChange(mp)
	local fairyList = DataCenter.fairyData.fairyList;
	local sceneIdList;
	local arr = Array();
	for i = 1, fairyList:getSize() do
		sceneIdList = fairyList[i].sceneIdArr;
		if sceneIdList ~= nil then
			for j = 1, #sceneIdList do
				if DataCenter.roleData.sceneId == sceneIdList[j] then
					arr:add(fairyList[i]);
				end
			end
		end
	end

	if arr ~= nil and arr:getSize() > 0 then
		local isEquip = false;
		for i = 1, arr:getSize() do
			if DataCenter.fairyData.curFairyIndex == arr[i].index then
				isEquip = true;
				break;
			end
		end

		if isEquip then
			return;
		end
		self:showFairyTipsWin({fairyVo = arr});
	end
end

function Lua_FairyProxy:updateChatMiniFairyIcon()
	local equipedfairyItem = DataCenter.fairyData.equipedfairyItem;
	if equipedfairyItem ~= nil and equipedfairyItem.fairyVo.referenceIndex ~= nil and equipedfairyItem.fairyVo.bExpire == false then
		local msg = {};
		msg.type = Lua_MenuTipData.PROBATION_FAIRY;
		msg.altas = "icon_atlas_5";
		msg.spriteName = "activity_small_tips_jl";
		msg.state = 1;
		msg.fairyInfo = {fairyVo = DataCenter.fairyData.fairyList[equipedfairyItem.fairyVo.index], winType = 1};
		Lua_MsgUtil.callFunc("MENU_TIP_UPDATE", msg);

		Lua_CommonUtil.addTimer("PROBATION_FAIRY_COUNTDOWN_DETECTION", 1, self, self.probationCountDownDetection, msg);
	else
		Lua_MsgUtil.callFunc("MENU_TIP_UPDATE", {type = Lua_MenuTipData.PROBATION_FAIRY, state = 0});
	end
end





function Lua_FairyProxy:sFairyInfo()
	sendMsg(11409001);
end

-- 装备精灵
function Lua_FairyProxy:sPutOnFairy(param)
	local fairyVo = Lua_FairyVo.new(param.fairyType);
	local cmd = ProtoPublic_pb.Proto11409002();
	cmd.pack_index = param.index; -- 背包索引 购买时不需要这个字段
	cmd.fairy_item = fairyVo.itemId; -- 购买的精灵道具id
	cmd.active_type = 0; -- 装备方式 0背包使用 1购买
	cmd.put_on = 0; -- 0装备 1卸下
	sendMsg(11409002, cmd); -- 购买金钱类型 1元宝 2礼金 3元宝+礼金
end

function Lua_FairyProxy:sPutOffFairy(param)
	local cmd = ProtoPublic_pb.Proto11409002();
	cmd.pack_index = -1;
	cmd.fairy_item = param.id;
	cmd.active_type = 0;
	cmd.put_on = 1;
	sendMsg(11409002, cmd);
end

function Lua_FairyProxy:sBuyFairy(param)
	local cmd = ProtoPublic_pb.Proto11409002();
	cmd.pack_index = -1;
	cmd.fairy_item = param.itemId;
	cmd.active_type = 1;
	cmd.put_on = 0;
	if param.money_type ~= nil then
		cmd.money_type = param.money_type;
	end
	sendMsg(11409002, cmd);
end

function Lua_FairyProxy:sRenewalFairy(param)
	local cmd = ProtoPublic_pb.Proto11409003();
	if param.packType == Lua_PackData.BAG_PACK then
		cmd.renew_type = 0;
		cmd.pack_index = param.index;
	elseif param.packType == Lua_PackData.EQU_PACK then
		cmd.renew_type = 1;
		cmd.pack_index = -1;
	end

	if param.money_type ~= nil then
		cmd.money_type = param.money_type;
	end
	sendMsg(11409003,cmd);
end





function Lua_FairyProxy:checkFairyCountDown()
	local equipedfairyItem = DataCenter.fairyData.equipedfairyItem;
	if equipedfairyItem ~= nil and equipedfairyItem.fairyVo.referenceIndex == nil then
		Lua_CommonUtil.addTimer("FAIRY_COUNTDOWN_DETECTION", 1, self, self.countDownDetection);
	end
end

function Lua_FairyProxy:countDownDetection()
	local equipedfairyItem = DataCenter.fairyData.equipedfairyItem;
	if equipedfairyItem == nil or equipedfairyItem.fairyVo.referenceIndex ~= nil then
		Lua_CommonUtil.removeTimer(self, self.countDownDetection);
		return;
	end

	local leftTime = equipedfairyItem.fairyVo.expireTimes - DataCenter.roleData.serverTime
	if leftTime <= 0 then
		Lua_CommonUtil.removeTimer(self, self.countDownDetection);
		-- Lua_WindowUtil.openWin("Lua_ProbationFairyPurchaseWindow", WinParam.ACTION_OPEN, msg.fairyInfo);
		-- Lua_WindowUtil.openWin("Lua_FairyExpireWindow", WinParam.ACTION_OPEN, msg.fairyInfo);
		self:sPutOffFairy(equipedfairyItem);
	end
end

function Lua_FairyProxy:loginFairyExpireHandle(fairyType)
	Lua_WindowUtil.openWin("Lua_FairySceneTipWindow", WinParam.ACTION_OPEN, {fairyVo = DataCenter.fairyData.fairyList[fairyType], winType = 2});
end

function Lua_FairyProxy:showFairyTipsWin(param)
	local fairyVoList = param.fairyVo;
	local itemList;
	local tempTime;
	local curFairyItem;
	local temp = 1;
	local isOwned = false;
	for i = 1, fairyVoList:getSize() do
		itemList = DataCenter.packData:getBagType(2):getItemsById(fairyVoList[i].itemId);
		if itemList ~= nil and itemList:getSize() > 0 then
			for j = 1, itemList:getSize() do
				tempTime = itemList[j].timeOut - DataCenter.roleData.serverTime;
				if itemList[j].timeOut == 0 or tempTime > 0 then
					curFairyItem = itemList[j];
					temp = i;
					isOwned = true;
				end
			end
		end
	end

	if isOwned then
		Lua_WindowUtil.openWin("Lua_FairySceneTipWindow", WinParam.ACTION_OPEN, {curFairyItem = curFairyItem, fairyVo = fairyVoList[temp]});
	else
		Lua_WindowUtil.openWin("Lua_TipsWindow", nil, {owner = self, des = fairyVoList[1].tipsDes1, itemId = fairyVoList[1].itemId,
			type = 2, subFun = self.goToStore, txtSpacingX = 1, txtSpacingY = 12, txtPivot = UIWidget.Pivot.Left,
			txtPos = Vector2(-220, 61), txtSize = Vector2(447, 158), isShowCloseBtn = false});
	end
end

function Lua_FairyProxy:goToStore(param)
	Lua_WindowUtil.openWin("Lua_ShopWindow", nil, {openIdx = 2, itemID = param.itemId, isShowEffectInFirst = true});
end

function Lua_FairyProxy:probationCountDownDetection(msg)
	local equipedfairyItem = DataCenter.fairyData.equipedfairyItem;
	if equipedfairyItem == nil or equipedfairyItem.fairyVo.referenceIndex == nil then
		Lua_CommonUtil.removeTimer(self, self.probationCountDownDetection);
		return;
	end

	local leftTime = equipedfairyItem.fairyVo.expireTimes - DataCenter.roleData.serverTime
	if leftTime <= 0 then
		Lua_CommonUtil.removeTimer(self, self.probationCountDownDetection);
		-- Lua_WindowUtil.openWin("Lua_ProbationFairyPurchaseWindow",WinParam.ACTION_OPEN, msg.fairyInfo);
		Lua_WindowUtil.openWin("Lua_FairyExpireWindow", WinParam.ACTION_OPEN, msg.fairyInfo);
	end
end