checkRequire("Lua_GamePlayData")
Lua_GamePlayProxy = class("Lua_GamePlayProxy");

function Lua_GamePlayProxy:ctor()
    DataCenter.gamePlayData = Lua_GamePlayData.new();
    LuaUtil.addLuaMsg(50101201, self, self.rArenaPanelInfo);	-- 请求比武场界面信息(返回)
    LuaUtil.addLuaMsg(50101202, self, self.rArenaChallenge);	-- 比武场挑战请求(返回)
    LuaUtil.addLuaMsg(50101203, self, self.rArenaRecordsInfo);	-- 请求比武场战斗记录界面(返回)
    -- LuaUtil.addLuaMsg(50101204, self, self.rChangeChallengeList);	-- 请求比武场更换挑战列表(返回)
    LuaUtil.addLuaMsg(50101205, self, self.rBuyChallengeTimes);	-- 请求比武场购买挑战次数(返回)
    LuaUtil.addLuaMsg(50101206, self, self.rGetRankRewards); -- 领取比武场排行榜结算奖励(返回)
    -- LuaUtil.addLuaMsg(50402114, self, self.rSkipChallenge); -- 比武场直接跳过动画(返回)

    LuaUtil.addLuaMsg(80401201, self, self.rArenaFightingInfo);	-- 比武场战斗信息
    LuaUtil.addLuaMsg(80401202, self, self.rArenaFightingEndInfo);	-- 比武场战斗胜利界面
    LuaUtil.addLuaMsg(80401203, self, self.rArenaFightingTimeInfo);  -- 比武场时间信息
end

-----------------------------------------------------
-- 上行协议

-- 请求比武场界面信息
function Lua_GamePlayProxy:sArenaPanelInfo()
    sendMsg(10101201);
end

-- 比武场挑战请求
function Lua_GamePlayProxy:sArenaChallenge(targetRoleId, rank, isCombine)
    local cmd = ProtoPublic_pb.Proto10101202();
    cmd.target_role_id = targetRoleId;
    cmd.target_cur_rank = rank;
    cmd.use_all_times = isCombine;
    sendMsg(10101202, cmd);
end

-- 请求比武场战斗记录界面
function Lua_GamePlayProxy:sArenaRecordsInfo(id)
    sendMsg(10101203);
end

-- 请求比武场更换挑战列表
function Lua_GamePlayProxy:sChangeChallengeList()
    sendMsg(10101204);
end

-- 请求比武场购买挑战次数
function Lua_GamePlayProxy:sBuyChallengeTimes(times)
    local cmd = ProtoPublic_pb.Proto10101205();
    cmd.buy_count = times;
    sendMsg(10101205, cmd);
end

-- 领取排行奖励
function Lua_GamePlayProxy:sGetRankRewards()
	sendMsg(10101206);
end

-- 请求退出当前系统
function Lua_GamePlayProxy:sExitCurScene()
    sendMsg(10400902);
end

-- 比武场直接跳过动画
function Lua_GamePlayProxy:sSkipChallenge()
    sendMsg(10402114);
end


-----------------------------------------------------
-- 下行协议

-- 请求比武场界面信息(返回)
function Lua_GamePlayProxy:rArenaPanelInfo(mp)
    if mp.errno == 0 then
        local msg = ProtoPublic_pb.Proto50101201();
        msg:ParseFromString(mp.data);
        DataCenter.gamePlayData:fromServerArenaInfo(msg);
        Lua_MsgUtil.callFunc("rArenaPanelInfo");
    end
end

-- 比武场挑战请求(返回)
function Lua_GamePlayProxy:rArenaChallenge(mp)
    if mp.errno == 0 then
        local msg = ProtoPublic_pb.Proto50101202();
        msg:ParseFromString(mp.data);
        if msg.ret == 0 then -- 进入挑战关闭界面
        	Lua_WindowUtil.openWin("Lua_GamePlayWindow", WinParam.ACTION_CLOSE, nil);
        end
    end
end

-- 请求比武场战斗记录界面(返回)
function Lua_GamePlayProxy:rArenaRecordsInfo(mp)
    if mp.errno == 0 then
        local msg = ProtoPublic_pb.Proto50101203();
        msg:ParseFromString(mp.data);
        Lua_MsgUtil.callFunc("rArenaRecordsInfo", msg.record);
    end
end

-- 请求比武场更换挑战列表(返回)
function Lua_GamePlayProxy:rChangeChallengeList(mp)
    if mp.errno == 0 then
        local msg = ProtoPublic_pb.Proto50101204();
        msg:ParseFromString(mp.data);
        DataCenter.gamePlayData.oldClickChangeListTime = getTime();
        Lua_MsgUtil.callFunc("rChangeChallengeList");
    end
end

-- 请求比武场购买挑战次数(返回)
function Lua_GamePlayProxy:rBuyChallengeTimes(mp)
    if mp.errno == 0 then
        local msg = ProtoPublic_pb.Proto50101205();
        msg:ParseFromString(mp.data);
        DataCenter.gamePlayData.curChallengeTimes = msg.cur_left_times;
        DataCenter.gamePlayData.curBeBuyTimes = msg.cur_buy_times;
        DataCenter.gamePlayData.curCanBuyTimes = msg.cur_can_buy_times;
        Lua_MsgUtil.callFunc("BuyTimesInfoUpdate", msg.cur_can_buy_times);
        OperateAlert.show(LanUtil.getValue(120909));
    end
end

-- 领取比武场排行榜结算奖励(返回)
function Lua_GamePlayProxy:rGetRankRewards(mp)
	if mp.errno == 0 then
        local msg = ProtoPublic_pb.Proto50101204();
        msg:ParseFromString(mp.data);
        DataCenter.gamePlayData.rankRewardState = 1; -- 已领取
        Lua_MsgUtil.callFunc("rGetArenaRankRewards");
    elseif mp.errno == 1302 then -- 背包空间不足
        if Lua_WindowUtil.isWindowShowing("Lua_TipsWindow") == false and Lua_WindowUtil.isWindowShowing("Lua_PackWindow") == false then
            DataCenter.packData:showFullBagTip(Lua_PackData.BAG_PACK);
            return;
        end
    end
end

-- 比武场直接跳过动画(返回)
function Lua_GamePlayProxy:rSkipChallenge(mp)
    if mp.errno == 0 then
        local msg = ProtoPublic_pb.Proto50402114();
        msg:ParseFromString(mp.data);

    end
end

-- 比武场战斗信息(返回)
function Lua_GamePlayProxy:rArenaFightingInfo(mp)
    if mp.errno == 0 then
        local msg = ProtoPublic_pb.Proto80401201();
        msg:ParseFromString(mp.data);
        DataCenter.gamePlayData:fromServerArenaFightingInfo(msg);
        Lua_MsgUtil.callFunc("rArenaFightingInfo");
    end
end

-- 比武场战斗胜利界面
function Lua_GamePlayProxy:rArenaFightingEndInfo(mp)
	if mp.errno == 0 then
        local msg = ProtoPublic_pb.Proto80401202();
        msg:ParseFromString(mp.data);
        -- msg.before_rank;
        -- msg.after_rank;	
        -- msg.glory_point;	-- 荣耀点数
        -- msg.exp;	-- 获得经验值
        -- msg.auto_return_time;	-- 自动返回时间
        -- msg.ret;	-- 0 挑战成功 其他失败
        if GlobalVar.hooking == true then
            DataCenter.hook:stop(true);
        end
        DataCenter.gamePlayData:resetFightInfo(); -- 重置战斗信息
        Lua_WindowUtil.openWin("Lua_BiwuFightingWindow", WinParam.ACTION_CLOSE, nil);
        Lua_WindowUtil.openWin("Lua_BiWuFightEndWindow", WinParam.ACTION_OPEN, msg);
    end
end

-- 比武场时间信息
function Lua_GamePlayProxy:rArenaFightingTimeInfo(mp)
    if mp.errno == 0 then
        local msg = ProtoPublic_pb.Proto80401203();
        msg:ParseFromString(mp.data);
        -- msg.left_time; -- 剩余时间
        -- msg.ready_left_time;  -- 战斗前倒计时
        DataCenter.gamePlayData:fromServerArenaFightingTimeInfo(msg);
        Lua_MsgUtil.callFunc("rArenaFightingTimeInfo");
    end
end