Lua_GodWingTransVo = class("Lua_GodWingTransVo")
function Lua_GodWingTransVo:ctor(id, config)
	self.id = id;
	self.config = config == nil and getConfig({"wing_illusion", id}) or config;

	self.level = 0;
	self.is_unlock = 0;
end

function Lua_GodWingTransVo:formServer(data)
	self.level = data.ill_lvl; -- 幻化等级
	self.is_unlock = data.is_unlock; -- 是否解锁 1是0否
end

function Lua_GodWingTransVo.Get:name()
	if self.level == 0 then
		return self.config.name;
	end
	return self.config.name.."+"..self.level;
end

function Lua_GodWingTransVo.Get:illusion_id()
	return self.config.illusion_id;
end

-- 是否幻化
function Lua_GodWingTransVo.Get:isIllusion()
	if DataCenter.godWingTransData.cur_ill_id == self.id then
		return true;
	end
	return false;
end

-- 解锁所需要道具
function Lua_GodWingTransVo.Get:isUnlock()
	local packData = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK);
	local packTotalItemNum = packData:getItemNum(self.totalItemId);
	local packDebrisItemNum = packData:getItemNum(self.debrisItemId);
	if self.level > 0 then
		return false;
	end

	if packTotalItemNum >= self.totalItemNum or packDebrisItemNum >= self.debrisItemNum then
		return true;
	end
	return false;
end

function Lua_GodWingTransVo.Get:isRedDot()
	if self.level == 50 then
		return false;
	end

	local debrisItemNum =  DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(self.debrisItemId);
	if self.level == 0 then
		if self.isUnlock == true then
			return true;
		end
	end

	if debrisItemNum >= self.debrisItemNum then
		return true;
	end
	return false;
end

-- 整个物品id
function Lua_GodWingTransVo.Get:totalItemId()
	if self.config.illusion_item == nil then
		return 0;
	end
	return self.config.illusion_item[1][1];
end

-- 整个物品数量
function Lua_GodWingTransVo.Get:totalItemNum()
	if self.config.illusion_item == nil then
		return 0;
	end
	return self.config.illusion_item[1][2];
end

-- 碎片物品id
function Lua_GodWingTransVo.Get:debrisItemId()
	if self.config.illusion_item == nil then
		return 0;
	end
	return self.config.illusion_item[2][1];
end

-- 碎片物品数量
function Lua_GodWingTransVo.Get:debrisItemNum()
	if self.cost_number == 0 then
		return self.config.cost_number[49][2];
	end

	if self.config.illusion_item == nil then
		return 0;
	end

	if self.is_unlock == 0 then
		return self.config.illusion_item[2][2];
	else
		return self.cost_number[2];
	end
end

function Lua_GodWingTransVo.Get:cost_number()
	if self.config.cost_number[self.level] == nil and self.level ~= 0 then
		return 0;
	end
	return self.config.cost_number[self.level];
end

-- 背包物品数量
function Lua_GodWingTransVo.Get:packItemNum()
	local packData = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK);
	if self.cost_number == 0 then
		return packData:getItemNum(self.config.cost_number[49][1]);
	end

	if self.is_unlock == 0 then
		local totalItemNum = packData:getItemNum(self.totalItemId);
		local debrisItemNum = packData:getItemNum(self.debrisItemId);
		if totalItemNum >= self.totalItemNum  then
			return self.debrisItemNum * totalItemNum;
		end
		return debrisItemNum;
	else
		return packData:getItemNum(self.cost_number[1]);
	end
end

function Lua_GodWingTransVo.Get:getPropertyData()
	local level = self.level ~= 0 and self.level or 1;
	if self.level == 50 then 
		level = 50;
	end

	local data;
	local configInfo = getConfig({"wing_illusion", self.id});
	local arr  = Array();
	for k,v in ipairs(Lua_ThingDefine.params) do
		if configInfo[v] ~= nil then
			data = {};
			data.show_percent = Lua_ThingDefine.isPercentParam(v) and 1 or 0; 
			data.name = Lua_ThingDefine.getParamName(v)
			data.val = configInfo[v][level]
			data.level = self.level;
			data.nextVal = configInfo[v][level + 1] ~= nil and configInfo[v][level + 1] - configInfo[v][level] or 0;

			arr:add(data);
		end
	end
	return arr;
end





function Lua_GodWingTransVo.Get:modelInfo()
	if self._modelInfo == nil then
		self._modelInfo = getConfig({"playerHanger", self.id})
	end
	return self._modelInfo;  
end

function Lua_GodWingTransVo.Get:floder()
	return self.modelInfo.floder == nil and nil or self.modelInfo.floder;
end

function Lua_GodWingTransVo.Get:fileName()
	return self.modelInfo.fileName == nil and nil or self.modelInfo.fileName;
end

function Lua_GodWingTransVo.Get:modelName()
	return self.modelInfo.modelName == nil and nil or self.modelInfo.modelName;
end

function Lua_GodWingTransVo.Get:modelPosDic()
	if self._modelPosDic == nil then
		if self.modelInfo.servant_pos == nil then
			self._modelPosDic = {-45, 0, 0};
		else
			self._modelPosDic = self.modelInfo.servant_pos;
		end
	end
	return self._modelPosDic;
end

function Lua_GodWingTransVo.Get:modelRosDic()
	if self._modelRosDic == nil then
		if self.modelInfo.servant_rot == nil then
			self._modelRosDic = {0, 0, 0};
		else
			self._modelRosDic = self.modelInfo.servant_rot;
		end
	end
	return self._modelRosDic;
end

function Lua_GodWingTransVo.Get:modelScaDic()
	if self._modelScaDic == nil then
		if self.modelInfo.servant_sca == nil then
			self._modelScaDic = {100, 100, 100};
		else
			self._modelScaDic = self.modelInfo.servant_sca;
		end
	end
	return self._modelScaDic;
end