checkRequire("Lua_ThingDefine");
Lua_ParamChangeWindow = class("Lua_ParamChangeWindow", Lua_FullSizeWindow);
function Lua_ParamChangeWindow:ctor()
    self.windowName = "Lua_ParamChangeWindow";
    self.showList = Array();
    self:superCall("ctor", false, false, 6500, false, false, false);
end
function Lua_ParamChangeWindow:buildShowItem()
    self:superCall("buildShowItem");
end
function Lua_ParamChangeWindow:showWin(param)
	local newList = Array();
	if param["attack_upper"] ~= 0 or param["attack_lower"] ~= 0 then
		param["attack"] = 0;
	end

	local num;
	for i,v in ipairs(Lua_ThingDefine.changeParams) do
		if param[v] ~= nil and param[v] ~= 0 then
			num = string.format("%.2f", tostring(param[v])); 
			newList:add({param=v, value = tonumber(num)});
		end
	end
	if newList:getSize() > 0 then
		self:clearShowList();
		local offsetH = newList:getSize() * (20) + 20;
		for i=1,newList:getSize() do
			local item = Lua_ParamChangeItem.new(self.content);
			item:setData(newList[i].param, newList[i].value);
			local index = i - 1;
			item:setLocation(-MainWinDefine.V_width / 2 + 270, MainWinDefine.V_height / 2 - 400);
			item:setAlpha(0);
			item:setEnable(false);
			item:setDelayTime(0.4 * index);
			self.showList:add(item);
		end
		local index = self.showList:getSize();
		if self.showList[index] ~= nil then
			self.showList[index]:setCallBack(self, self.clearShowList);
		end
	end
end
function Lua_ParamChangeWindow:clearShowList()
	for i=1,self.showList:getSize() do
		self.showList[i]:dispose();
	end
	self.showList:clear();
end
function Lua_ParamChangeWindow:dispose()
	self:superCall("dispose");
	self:clearShowList();
end


















Lua_ParamChangeItem = class("Lua_ParamChangeItem",Lua_DisplayObject);
Lua_ParamChangeItem.SHOW_TIME = 0.1;
Lua_ParamChangeItem.SHOWING_TIME = 0.35;
Lua_ParamChangeItem.HIDE_TIME = 1.7;

function Lua_ParamChangeItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_ParamChangeItem:setData(paramName, changeNum)
	self.moveContent = UICreate.createGameObject(self.content, 0, 0,0);

	local preName = "";
	if changeNum > 0 then
		preName = "gold_";
	else
		preName = "red_";
	end
	changeNum = math.abs(changeNum);

	self.paramName = UICreate.createUIAtlasImage(self.moveContent,"number_atlas",preName..paramName,0,0,0,0);
	self.paramName.pivot = UIWidget.Pivot.Left;
	self.paramName:setLocation(0,0,0);

	if preName == "gold_" then
		self.changeSp = UICreate.createUIAtlasImage(self.moveContent,"number_atlas","gold_add",0,0,0,0);
		self.changeSp:setLocation(self.paramName.width + 15, 0, 0);
	else
		self.changeSp = UICreate.createUIAtlasImage(self.moveContent,"number_atlas","red_sub",0,0,0,0);
		self.changeSp:setLocation(self.paramName.width + 15, 0, 0);
	end

	local num1 = math.floor(changeNum);
	local num2 = changeNum - num1;
	
	self.fightNum = Lua_NumberImage.new(self.moveContent);
	self.fightNum.prefix = preName;
	self.fightNum.numWidth = 14;
	self.fightNum:setDepth(5);
	self.fightNum:setLocation(self.paramName.width + 33, 0, 0);

	if paramName == "damage" or paramName == "reduction" then
		local len = string.len(tostring(changeNum));
		self.perSp = UICreate.createUIAtlasImage(self.moveContent,"number_atlas",preName.."bai",0,0,0,0);
		self.perSp:setLocation(self.paramName.width + len * 14 + 37, 0, 0);
		self.fightNum.num = changeNum;
	else
		self.fightNum.num = math.floor(changeNum);
	end
	self.fightNum:setNumScale(0.7, 0.7);
end

function Lua_ParamChangeItem:setAlpha(val)
	self.paramName.alpha = val;
	self.changeSp.alpha = val;
	if self.perSp ~= nil then
		self.perSp.alpha = val;
	end
	if self.fightNum ~= nil then
		self.fightNum:setAlpha(val);
	end
end
function Lua_ParamChangeItem:setDelayTime(val)
	self.delayTime = val;
	self.startTime = getTime();
	self:addTimer("Lua_ParamChangeItem",0.01,self,self.onEnterFrame);		
end
function Lua_ParamChangeItem:onEnterFrame()
	local dt = getTime() - self.startTime;
	if dt < self.delayTime then
		self:setEnable(false);
	else
		self:setEnable(true);
		dt = dt - self.delayTime;
		if dt < Lua_ParamChangeItem.SHOW_TIME then
			local v = dt / Lua_ParamChangeItem.SHOW_TIME;
			self:setAlpha(v);
			self:updatePos(0, -20+20*v,0);
		elseif dt < Lua_ParamChangeItem.SHOWING_TIME then
			self:setAlpha(1);
			self:updatePos(0, 0, 0);
		elseif dt < Lua_ParamChangeItem.HIDE_TIME then
			local pt = Lua_ParamChangeItem.HIDE_TIME - dt;
			local v = pt / (Lua_ParamChangeItem.HIDE_TIME - Lua_ParamChangeItem.SHOWING_TIME);
			self:setAlpha(v);
			self:updatePos(0, 110*(1-v), 0);
		else
			if self.owner ~= nil and self.callBack ~= nil then
				self.callBack(self.owner);
				self.owner = nil;
				self.callBack = nil;
			end
		end
	end
end
function Lua_ParamChangeItem:setCallBack(owner, callBack)
	self.owner = owner;
	self.callBack = callBack;
end
function Lua_ParamChangeItem:updatePos(x,y,z)
	-- self.moveContent.transform.localPosition = Vector3(x,y,z);
	LuaUtil.setObjPos(self.moveContent, x,y,z);
end
function Lua_ParamChangeItem:dispose()
	self.owner = nil;
	self.callBack = nil;
	self:setAlpha(1);
	self:superCall("dispose");
end