Lua_Joystick = class("Lua_Joystick", Lua_DisplayObject);
function Lua_Joystick:buildShowItem()
	self.content.name = "Lua_Joystick";
    self.gui = UICreate.createUIAtlasImage(self.content, "iconantlas2", "joystick_touch", 0, 0, 0, 0);
    self.gui.depth = 3;
    self.bg = UICreate.createUIAtlasImage(self.content, "iconantlas2", "joystick_still", 0, 0, 0, 0);
    self.bg.depth = 2;
   --[[ self.joySkill = UICreate.createUIAtlasImage(self.content, "iconantlas2", "joystick_dead", 0, 0, 0, 0);
    self.joySkill.depth = 1;--]]
    self.b = UICreate.createUIAtlasImage(self.content, "iconantlas2", "black_bg", 0, 0, 0, 0);
    self.b.depth = 0;
    self.b:SetDimensions(185, 185);
    self.b.alpha = 0.01;
    self.b:addClickFuntion(self, self.onMouseDown);
    self.b:addMouseUpFuntion(self, self.onMouseUp);

    self.halfTouchArea = 95;
    self.radius = 100;
    self.mousePosition = Vector3(0,0,0);
    self._shouldLatchFinger = false;
    self.isLocation = false;
    self:resetJoystick();
end
function Lua_Joystick:resetJoystick()
	if self.gui ~= null then
        self.position = Vector2(0,0);
        self.gui:setLocation(0, 0, 0);
        self.bg:setLocation(0, 0, 0);
        self.bg:setEnable(false);
        self.gui:setEnable(false);
--        self.joySkill:setEnable(true);
	end
    self.isLocation = false;
end
function Lua_Joystick:onMouseDown(go)
	if self.shouldLatchFinger == true then
        return;
    end
    for i=1,UnityEngine.Input.touchCount do
    	if UnityEngine.Input.GetTouch(i - 1).phase == TouchPhase.Began then
            self.fingerId = UnityEngine.Input.GetTouch(i - 1).fingerId;
        end
    end
    self.shouldLatchFinger = true;
    MsgUtil.callFunc("JOYSTICK_CLICK");
end
function Lua_Joystick:onMouseUp(go)
	for i=1,UnityEngine.Input.touchCount do
    	if UnityEngine.Input.GetTouch(i - 1).phase == TouchPhase.Began then
            self.fingerId = UnityEngine.Input.GetTouch(i - 1).fingerId;
        end
    end
    self:resetJoystick();
	self.shouldLatchFinger = false;
end
function Lua_Joystick.Get:shouldLatchFinger(val)
	return self._shouldLatchFinger;
end
function Lua_Joystick.Set:shouldLatchFinger(val)
	self._shouldLatchFinger = val;
	if self._shouldLatchFinger == true then
        Lua_CommonUtil.addTimer("Joystick", 0.01, self, self.onUpdate);
    else
        Lua_CommonUtil.removeTimer(self, self.onUpdate);
        MsgUtil.callFunc(EventsDefine.JOYSTICK_STOP_MOVE);
    end
end
function Lua_Joystick:getPoint(p)
	if self.bgTrans == nil then
        self.bgTrans = self.bg.mainContent.transform;
    end
    local bgX = self.bgTrans.localPosition.x;
    local bgY = self.bgTrans.localPosition.y;

    local l = math.sqrt(math.pow(bgX - p.x, 2) + math.pow(bgY - p.y, 2));
    local angle = math.atan2(p.y - bgY, p.x - bgX) * 180 / math.pi;

    if l <= self.radius then
        return p;
    end

    local pointVec2 = Vector2(0,0);
    pointVec2.x = bgX + (math.cos(angle * math.pi / 180) * self.halfTouchArea);
    pointVec2.y = bgY + (math.sin(angle * math.pi / 180) * self.halfTouchArea);

    return pointVec2;
end
function Lua_Joystick:onUpdate()
	if self._shouldLatchFinger == false then
		return;
	end
	if self.bgTrans == nil then
        self.bgTrans = self.bg.mainContent.transform;
    end
    if self.guiTrans == nil then
        self.guiTrans = self.gui.mainContent.transform;
    end


    if UnityEngine.Input.touchCount == 0 or UnityEngine.Input.touchCount == 1 then
        self.mousePosition.x = UnityEngine.Input.mousePosition.x;
        self.mousePosition.y = UnityEngine.Input.mousePosition.y;
	else
		for i=1,UnityEngine.Input.touchCount do
			if UnityEngine.Input.GetTouch(i - 1).fingerId == self.fingerId then
                self.mousePosition = UnityEngine.Input.GetTouch(i - 1).position;
                break;
            end
		end
    end
	local screenpos = UICamera.mainCamera:ScreenToWorldPoint(self.mousePosition);
	self.mousePosition = self.content.transform:InverseTransformPoint(screenpos);

    if self.isLocation == false then
        self.guiTrans.localPosition = self.mousePosition;
        self.bgTrans.localPosition = self.guiTrans.localPosition;
        self.bg:setEnable(true);
        self.gui:setEnable(true);
--        self.joySkill:setEnable(false);
        self.isLocation = true;
    else
        self.guiTrans.localPosition = self:getPoint(self.mousePosition);
    end

    self.mousePosition.x = self.guiTrans.localPosition.x / self.halfTouchArea;
    self.mousePosition.y = self.guiTrans.localPosition.y / self.halfTouchArea;

	local position = (self.guiTrans.localPosition - self.bgTrans.localPosition) / self.halfTouchArea;
    if math.abs(position.x) < 0 then
        position.x = 0;
    end
    if math.abs(position.y) < 0 then
        position.y = 0;
	end
    if position.x ~= 0 and position.y ~= 0 then
        local v = UnityEngine.Camera.main.transform.localRotation.eulerAngles;
        local s = math.sin(v.y * math.pi / 180);
        local c = math.cos(v.y * math.pi / 180);
        local nx = position.x * c + position.y * s;
        local ny = -position.x * s + position.y * c;
        position.x = nx;
        position.y = ny;
        MsgUtil.callFunc("JOYSTICK_MOVE", position);
    end
end