Lua_MenuIconBaseItem = class("Lua_MenuIconBaseItem", Lua_DisplayObject);
function Lua_MenuIconBaseItem:ctor(p, clickOwner, clickFun, iconData, spAtlas, spName)
	self.clickOwner = clickOwner;
	self.clickFun = clickFun;
	self.iconData = iconData;
	self.spAtlas = spAtlas;
	self.spName = spName;
	self:superCall("ctor", p, "MenuIconBase_skin");	
	
	self:onEffectListUpdate();
end

function Lua_MenuIconBaseItem.Get:sortIndex()
	if self.iconData ~= nil then
		return self.iconData.sort_index;
	end
	return 0;
end

function Lua_MenuIconBaseItem.Get:iconId()
	if self.iconData ~= nil then
		return self.iconData.id;
	end
	return 0;
end

function Lua_MenuIconBaseItem.Get:floatTargetPath()
	if self.iconData ~= nil then
		return self.iconData.floatTargetPath;
	end
	return nil;
end

function Lua_MenuIconBaseItem.Get:iconFloat()
	if self.iconData ~= nil then
		return self.iconData.iconFloat;
	end
	return nil;
end

function Lua_MenuIconBaseItem:buildShowItem()
	self:superCall("buildShowItem");

	if self.iconData ~= nil then
		self.iconSp:setAltas(self.iconData.iconAtlas, self.iconData.icon);
	else
		self.iconSp:setAltas(self.spAtlas, self.spName);
	end
	self.iconSp:addClickFuntion(self, self.onIconClick);
	self:setIconSpSize(86, 86);
	
	if self.iconData ~= nil then
		self.redDotIcon = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_hongdian", 25, 25, 0, 0);
		self.redDotIcon.name = "redDotIcon";
		self.redDotIcon:setDepth(self.depth + 3);
		self:refreshRedDot();
	end
	self:updateEff();

	self:addLuaEvent("LOCK_EFFECT_LIST", self, self.onEffectListUpdate);
end

function Lua_MenuIconBaseItem:refreshRedDot()
	if self.redDotIcon ~= nil and self.iconData ~= nil then
		
		local redState = self.iconData.redDotShowState;
		if self.bShowRedDot ~= redState then
			self.redDotIcon:setEnable(redState);
			if self.bShowRedDot == true and self.iconData.show_effect ~= nil and self.iconData.show_effect == 2 then
				DataCenter.menuIconData:setHasClick(self.iconData.id);
				self:updateEff();
			end
			self.bShowRedDot = redState;
		end
	end
end

function Lua_MenuIconBaseItem:onIconClick(go)
	if self.lockEffect ~= nil then
		DataCenter.roleData:updateLockState(self.iconData.id, 0);
	end
	self:showHideLockEffect(false);

	if self.clickOwner ~= nil and self.clickFun ~= nil then
		self.clickFun(self.clickOwner);
	elseif self.iconData ~= nil then
		if self.iconData.type == 1 and self.iconData.param then
			Lua_WindowUtil.openWin(self.iconData.param, nil, self.iconData.isNested);
		elseif self.iconData.type == 2 and self.iconData.param  then
			Lua_MsgUtil.callFunc(self.iconData.param);
		end
	end

	-- 登录显示，点击前有红点则继续保留
	if self.iconData ~= nil and self.iconData.show_effect ~= nil then
		if self.iconData.show_effect == 2 then
			local redState = self.iconData.redDotShowState;
			if redState == false then
				DataCenter.menuIconData:setHasClick(self.iconData.id);
			end
		elseif self.iconData.show_effect == 3 then
			DataCenter.menuIconData:setHasClick(self.iconData.id);
		end
	end
	self:updateEff();
end

function Lua_MenuIconBaseItem:setIcon(atlas, spName)
	if self.iconSp ~= nil then
		self.iconSp:setAltas(atlas, spName);
		self.iconSp:resetSize();
	end
end

function Lua_MenuIconBaseItem:setIconBg(atlas, spName)
	if self.bg ~= nil then
		self.bg:setAltas(atlas, spName);
		self.bg:resetSize();
	end
end

function Lua_MenuIconBaseItem:setIconSpSize(w, h)
	if self.iconSp ~= nil then
		self.iconSp:SetDimensions(w, h);
	end
end

function Lua_MenuIconBaseItem:setIconPos(x, y)
	if self.iconSp ~= nil then
		self.iconSp:setLocation(x, y, 0);
	end
end

-- 更新特效显示
function Lua_MenuIconBaseItem:updateEff()
	if self.iconData ~= nil and self.iconData.show_effect ~= nil then
		if self.iconData.show_effect == 1 then -- 跟随图标存在
			self:createEff();
		else
			if DataCenter.menuIconData:getHasClick(self.iconData.id) == false then
				self:createEff();
			else
				self:cleanEff();
			end
		end
	else
		self:cleanEff();
	end
end

function Lua_MenuIconBaseItem:createEff()
	if self.iconData == nil then
		self:cleanEff();
		return;
	end

	if self.effect == nil then
		local url = self.iconData.effect_url == nil and "activity_circle" or self.iconData.effect_url;
		self.effect = UICreate.createUIEffect(self.content, "/effects/scsEffects/"..url, url, 0, 0);
		self.effect:SetRenderQueue(self.bg, 2, UIEffect.NormalSort);
	end
end

function Lua_MenuIconBaseItem:cleanEff()
	if self.effect ~= nil then
		self.effect:dispose();
		self.effect = nil;
	end
end

function Lua_MenuIconBaseItem:onEffectListUpdate(o)
	if self.iconData == nil then
		return;
	end

	local val = DataCenter.roleData:getLockEffectState(self.iconData.id);
	if val == 1 then
		self:showHideLockEffect(true);
	elseif val == 0 then
		self:showHideLockEffect(false);
	end
end

function Lua_MenuIconBaseItem:showHideLockEffect(val)
	-- print("showHideLockEffect",val);
	if val == true then
		DataCenter.roleData:updateLockState(self.iconData.id, 1);
		if self.lockEffect == nil and DataCenter.roleData:getLockEffectState(self.iconData.id) ~= 0 then
			self.lockEffect = UICreate.createUIEffect(self.content, "/effects/scsEffects/gui_suoding", "gui_suoding", 0, 0);
			self.lockEffect:SetRenderQueue(self.iconSp, 5, 2);
		end
	else
		if self.lockEffect ~= nil then
			self.lockEffect:dispose();
			self.lockEffect = nil;
		end
	end
end

function Lua_MenuIconBaseItem:checkShowLockEffect(force)
	-- print("checkShowLockEffect",force);
	local tlist = self.iconData.show_lock_lv;
	if tlist == nil then
		self:showHideLockEffect(false);
		return;
	end

	local roleLv = DataCenter.roleData.level;
	for k,v in ipairs(tlist) do
		if force == true or tonumber(v) == roleLv then
			self:showHideLockEffect(true);
			return ;
		end
	end
	-- self:showHideLockEffect(false);
end

function Lua_MenuIconBaseItem:dispose()
	self:cleanEff();
	self:showHideLockEffect(false);
	self:superCall("dispose");
end