-- 市场配置数据
Lua_MarketUtil = class("Lua_MarketUtil");
function Lua_MarketUtil:ctor()
end

-- 所有主类数
function Lua_MarketUtil.Get:showTypeCount()
	return getConfig({"market_const", "all", "value"});
end

-- 市场上架背包分类
function Lua_MarketUtil.Get:getPackClassInfo()
	if self.packClass == nil then
		self.packClass = Array();

		local list = getConfig({"market_const", "pack_list", "value1"});
		for i = 1, #list do
			self.packClass:add({index = i, name = list[i][1], packType = list[i][2]});
		end
	end
	return self.packClass;
end

-- 根据索引选择对用背包类型
function Lua_MarketUtil.Get:getPackType()
	if self.packList == nil then
		self.packList = {};

		local list = getConfig({"market_const", "pack_list", "value1"});
		for i = 1, #list do
			self.packList[i] = list[i][2];
		end
	end
	return self.packList[DataCenter.marketData.selectIndex];
end

-- 主类列表
function Lua_MarketUtil.Get:showTypeArr()
	if self._showTypeArr == nil then 
		self._showTypeArr = Array();

		local vo;
		for i = 1, self.showTypeCount do 
			vo = self:getShowTypeInfoByIdx(i, false);
			if vo ~= nil then
				self._showTypeArr:add({name = vo.remark});
			end
		end
	end
	return self._showTypeArr;
end

function Lua_MarketUtil:getShowTypeInfoByIdx(idx, needTip)
	needTip = needTip == nil and true or needTip;
	if idx < 1 or idx > self.showTypeCount then
		if needTip == true then
			OperateAlert.show(LanUtil.formateStr(LanUtil.getValue(121710), tostring(idx)));
		end
		return;
	end
	return getConfig({"market_const", "part"..idx});
end

-- 子类列表
function Lua_MarketUtil:getShowSubTypeArr(idx)
	if self._showSubTypeDic == nil then
		self._showSubTypeDic = {};
	end

	if self._showSubTypeDic[idx] == nil then
		local arr = Array();
		local info = self:getShowTypeInfoByIdx(idx, true);
		if info ~= nil then
			local typeArr = info.value1;
			local typeNameArr = info.value2;
			local itemIdArr = info.value3;
			if typeArr ~= nil and typeNameArr ~= nil and itemIdArr ~= nil then
				arr:add({name = LanUtil.getValue(121711), subType = 0, mainType = idx, itemId = itemIdArr[#itemIdArr]}); -- 全部
				for i = 1, #typeArr do
					if typeNameArr[i] ~= nil then
						arr:add({name = typeNameArr[i], subType = typeArr[i], mainType = idx, itemId = itemIdArr[i]});
					else
						arr:add({name = "", subType = typeArr[i], mainType = idx, itemId = itemIdArr[i]});
					end
				end
			end
		end
		self._showSubTypeDic[idx] = arr;
	end
	return self._showSubTypeDic[idx];
end

-- 每次出售最高数量
function Lua_MarketUtil.Get:maxSellAmount()
	if self._maxSellAmount == nil then
		self._maxSellAmount = getConfig({"market_const", "max_sell_amount", "value"});
		if self._maxSellAmount == nil then
			self._maxSellAmount = 0;
		end
	end
	return self._maxSellAmount;
end

-- 最高出售单价
function Lua_MarketUtil.Get:maxSellEachPrice()
	if self._maxSellEachPrice == nil then
		self._maxSellEachPrice = getConfig({"market_const", "max_sell_price", "value"});
		if self._maxSellEachPrice == nil then
			self._maxSellEachPrice = 0;
		end
	end
	return self._maxSellEachPrice;
end

function Lua_MarketUtil:getSellGoodsMarketInfo(itemId)
	return getConfig({"market", tonumber(itemId)});
end

-- 传闻消耗
function Lua_MarketUtil:getShoutCost()
	local num = getConfig({"market_const", "shout_cost", "gold"}); -- 元宝
	if num ~= nil and num > 0 then
		return {id = Lua_MoneyData.GOLD, val = num};
	end

	num = getConfig({"market_const", "shout_cost", "bint_gold"}); -- 绑元
	if num ~= nil and num > 0 then
		return {id = Lua_MoneyData.BIND_GOLD, val = num};
	end

	num = getConfig({"market_const", "shout_cost", "copper"}); -- 铜钱
	if num ~= nil and num > 0 then
		return {id = Lua_MoneyData.COPPER, val = num};
	end
	return nil;
end

-- 星级
function Lua_MarketUtil:getStarNum(idx)
	return getConfig({"market_const", "star_select_arr", "value1"})[idx];
end

-- 星级显示
function Lua_MarketUtil.Get:starShowArr()
	if self._starShowArr == nil then
		self._starShowArr = Array();
		local list = getConfig({"market_const", "star_select_arr", "value2"});
		for i = 1, #list do
			self._starShowArr:add(list[i]);
		end
	end
	return self._starShowArr;
end

-- 阶数
function Lua_MarketUtil:getJieNum(idx)
	return getConfig({"market_const", "jie_select_arr", "value1"})[idx];
end

-- 阶数显示
function Lua_MarketUtil.Get:jieShowArr()
	if self._jieShowArr == nil then
		self._jieShowArr = Array();
		local list = getConfig({"market_const", "jie_select_arr", "value2"});
		for i = 1, #list do
			self._jieShowArr:add(list[i]);
		end
	end
	return self._jieShowArr;
end

-- 密码
function Lua_MarketUtil:getPWNum(idx)
	return getConfig({"market_const", "pw_select_arr", "value1"})[idx];
end

-- 密码显示
function Lua_MarketUtil.Get:PWShowArr()
	if self._PWShowArr == nil then
		self._PWShowArr = Array();

		local list = getConfig({"market_const", "pw_select_arr", "value2"});
		for i = 1, #list do
			self._PWShowArr:add(list[i]);
		end
	end
	return self._PWShowArr;
end

-- 我的货架数量
function Lua_MarketUtil.Get:myMarketShelvesNum()
	return getConfig({"vip_level", DataCenter.roleData.vipType, "market_grid"});
end

-- 货架格子数对应需要的vip等级
function Lua_MarketUtil:getMarketShelvesIdxInfo(gridIdx)
	if self._shelvesInfo == nil then
		self._shelvesInfo = {};

		local config = checkRequire("vip_level");
		self._maxShelvesNum = 0;
		for k, v in ipairs(config) do
			local num = v.market_grid;
			if self._shelvesInfo[num] == nil then
				self._shelvesInfo[num] = tonumber(k);
			elseif self._shelvesInfo[num] > tonumber(k) then
				self._shelvesInfo[num] = tonumber(k);
			end

			if self._maxShelvesNum < num then
				self._maxShelvesNum = num;
			end
		end
	end
	return self._shelvesInfo[tonumber(gridIdx)];
end

-- 货架格子数最大数
function Lua_MarketUtil.Get:maxShelvesNum()
	if self._maxShelvesNum == nil then
		self._shelvesInfo = {};

		local config = checkRequire("vip_level");
		self._maxShelvesNum = 0;
		for k, v in ipairs(config) do
			local num = v.market_grid;
			if self._shelvesInfo[num] == nil then
				self._shelvesInfo[num] = tonumber(k);
			elseif self._shelvesInfo[num] > tonumber(k) then
				self._shelvesInfo[num] = tonumber(k);
			end

			if self._maxShelvesNum < num then
				self._maxShelvesNum = num;
			end
		end
	end
	return self._maxShelvesNum;
end


function Lua_MarketUtil:isEquipMainType(mainType)
	mainType = tonumber(mainType);
	if self.equipMainTypeInfo == nil then
		self.equipMainTypeInfo = {};
		local list = getConfig({"market_const", "equip_mainType", "value1"})
		for i = 1, #list do
			self.equipMainTypeInfo[tonumber(list[i])] = true;
		end
	end

	if self.equipMainTypeInfo[mainType] == nil then
		return false;
	end
	return self.equipMainTypeInfo[mainType];
end