Lua_PeakAuctionData = class("Lua_PeakAuctionData");
function Lua_PeakAuctionData:ctor()
    self:superCall("ctor");
    self.peakAuctionLogin = false;
    self.money_type = 0;
    self.selectId = nil;
end

function Lua_PeakAuctionData:dispose()
	self.peakAuctionLogin = false;
	self.money_type = 0;
	self.selectId = nil;
end

function Lua_PeakAuctionData:from50105632(msg)
	if msg ~= nil then
		self.bidding_periods = msg.bidding_periods; -- 竞拍期数
		self.items_info = msg.items_info; -- 竞拍物品信息
		self.conditional_information = msg.conditional_information; -- 条件信息
		self.auction_history = msg.auction_history; -- 赢家历史信息
		self.end_tick = msg.act_info.end_tick; -- 活动结束时间
		self.content = msg.act_info.content; -- 活动内容
		self.role_id = msg.role_id; -- 玩家id
	end
end

function Lua_PeakAuctionData:from80105602(msg)
	if msg ~= nil then
		local arr = Array();
		for i,v in ipairs(msg.all_outbid_info) do -- 所有被超价格物品信息
			local list = {};
			local vo = Lua_ToolVo.createToolVo(v.id);
			vo:fromServer(v);
			list.vo = vo;
			list.item_id = v.id;
			list.update_time = msg.update_time[i];
			arr:add(list);
		end
		arr:sort("update_time", true);

		local _msg = {};
		_msg.type = Lua_MenuTipData.ACT_PEAK_AUCTION;
		_msg.altas = "PeakAuction";
		_msg.spriteName = "icon_hammer";
		_msg.openAct = true;
		_msg.state = 1;
		_msg.data = arr;
		Lua_MsgUtil.callFunc("MENU_TIP_UPDATE", _msg);
	end
end

function Lua_PeakAuctionData.Get:getPeakAuctionData() -- 竞拍物品数据
	local arr = Array();
	for i,v in ipairs(self.items_info) do
		local list = {};
		list.end_time = v.end_time; -- 竞拍结束时间戳
		list.current_price = v.current_price; -- 当前价格
		list.clap_reserve = v.clap_reserve; -- 起拍底价
		list.money_type = v.money_type; -- 铜钱、绑元、元宝
		self.money_type = v.money_type;
		list.my_bid = v.my_bid; -- 我的出价

		local vo = Lua_ToolVo.createToolVo(v.item_info.id, v.item_info.amount, v.item_info.bind); -- 物品信息
		vo.star = v.item_info.equipment.star;
		list.vo = vo;
		list.item_effect = v.item_info.show_effect; -- 道具特效

		if v.my_bid > 0 and v.current_price > v.my_bid then -- 出价已被超过的道具
			list.sortNum = i;
		elseif v.my_bid <= 0 then --暂未出价的道具
			list.sortNum = i + 1;
		elseif v.my_bid > 0 and v.current_price <= v.my_bid then -- 已出价但未被超过的道具
			list.sortNum = i + 2;
		end

		list.raise_limit = v.raise_limit; -- 最低加价百分比/加价值
		list.raise_rule = v.raise_rule; -- 0按值加价1按百分比加价
		list.index_id = v.index_id; -- 竞拍唯一id
		arr:add(list);
	end
	arr:sort("sortNum", false);
	return arr;
end

function Lua_PeakAuctionData.Get:getAuctionWinnerData() -- 竞拍赢家数据
	local arr = Array();
	for i,v in ipairs(self.auction_history) do
		local list = {};

		list.bidding_periods = v.bidding_periods; -- 竞拍期数

		if v.bidding_item.id ~= 0 then
			local vo = Lua_ToolVo.createToolVo(v.bidding_item.id);
			vo:fromServer(v.bidding_item);
			list.vo = vo;
		else
			list.vo = nil;
		end
		
		list.item_id = v.bidding_item.id;
		list.transaction_price = v.transaction_price; -- 成交价格
		list.role_id = v.role_id; -- 竞拍赢家id
		list.server_flag = v.server_flag; -- 竞拍赢家所在服务器
		list.role_name = v.role_name; -- 竞拍赢家名
		list.end_time = v.end_time;

		arr:add(list);
	end
	return arr;
end