Lua_SceneConfigData = class("Lua_SceneConfigData");
function Lua_SceneConfigData.getSceneConfig(sceneId)
    if Lua_SceneConfigData.configs == nil then
        Lua_SceneConfigData.configs = { };
    end
    if Lua_SceneConfigData.configs[sceneId] == nil then
        Lua_SceneConfigData[sceneId] = Lua_SceneConfigData.new(sceneId);
    end
    return Lua_SceneConfigData[sceneId];
end
function Lua_SceneConfigData:ctor(sceneId)
    self:superCall("ctor");
    self.sceneId = sceneId;
    self.config = getConfig( { "scene", sceneId });
end
function Lua_SceneConfigData.Get:name()
    if self.config == nil then
        return "";
    end
    return self.config.name;
end

function Lua_SceneConfigData:findNearestMonster(monsterId, curPos)
    local dis = 999999999999;
    local rs = nil;
    local monsterList = self.config.monster;
    if monsterList == nil then
        return nil;
    end
    for i, v in ipairs(monsterList) do
        -- 都不在安全区域，才进行判断
        -- 2018.3.27 安全区域内也可以攻击怪物相关bug单：BUG #7595 安全区相关问题
        -- 	if roleIsInSafeArea == false  and self:isInSafeArea(Vector3(v.posX,v.posY,v.posZ)) == false then 		
        if v.id == monsterId then
            return v;
        end
        local dx = curPos.x - v.posX;
        local dy = curPos.y - v.posY;
        local dz = curPos.z - v.posZ;
        local cDis = dx * dx + dy * dy + dz * dz;
        if dis > cDis then
            dis = cDis;
            rs = v;
        end
        -- 	end
    end
    return rs;
end
function Lua_SceneConfigData:findNpcById(npcId)
    local npcList = self.config.npc;
    if npcList ~= nil then
        for i, v in ipairs(npcList) do
            if v.id == npcId then
                return v;
            end
        end
    end
    return nil;
end
function Lua_SceneConfigData.Get:minLv()
    if self.config.level ~= nil then
        return self.config.level[1];
    end
    return 0;
end
function Lua_SceneConfigData.Get:maxLv()
    if self.config.level ~= nil then
        return self.config.level[2];
    end
    return 999;
end
function Lua_SceneConfigData.Get:no_auto_task()
    if self.config.no_auto_task == nil then
        return 0;
    end
    return self.config.no_auto_task;
end
function Lua_SceneConfigData.Get:safe_area()
    return self.config.safe_area;
end
function Lua_SceneConfigData.Get:team_chat_kuafu()
    if self.config.team_chat_kuafu == nil then
        return 0;
    end
    return self.config.team_chat_kuafu;
end
function Lua_SceneConfigData.Get:no_auto_task_area()
    return self.config.no_auto_task_area;
end
function Lua_SceneConfigData.Get:never_jump()
    if self.config.never_jump == nil then
        return 0;
    end
    return self.config.never_jump;
end
function Lua_SceneConfigData.Get:enter_tip()
    return self.config.enter_tip;
end
-- 判断坐标是否在安全区域
function Lua_SceneConfigData:isInSafeArea(curPos)
    if self.safe_area == nil then
        return 0;
    end
    for k, v in ipairs(self.safe_area) do
        if v.center ~= nil and Vector3.Distance(Vector3(v.center[1], 0, v.center[3]), curPos) < v.r then
            if v.safe_type == nil then
                return 1;
            else
                if v.safe_type == 0 then
                    return 1;
                else
                    return 2;
                end
            end
        end
    end
    return 0;
end
-- 判斷坐標是否在禁止自動任務區域
function Lua_SceneConfigData:isInNoAutoTaskArea(curPos)
    if self.no_auto_task_area == nil then
        return false;
    end
    for k, v in ipairs(self.no_auto_task_area) do
        if v.center ~= nil and Vector3.Distance(Vector3(v.center[1], 0, v.center[3]), curPos) < v.r then
            return true;
        end
    end
    return false;
end
-- 判断坐标是否在Boss区域
function Lua_SceneConfigData:isInBossArea(curPos)
    if self.config == nil then
        return false;
    end
    if self.config.boss_area == nil then
        return false;
    end
    for k, v in ipairs(self.config.boss_area) do
        if v.center ~= nil and Vector3.Distance(Vector3(v.center[1], 0, v.center[3]), curPos) < v.r then
            return true;
        end
    end
    return false;
end
function Lua_SceneConfigData.Get:enterAutoHook()
    if self.config.enter_auto_hook ~= 1 then
        return false;
    end
    return true;
end

function Lua_SceneConfigData.Get:noAutoCollect()
    -- 挂机不自动采集
    if self.config.no_auto_collect == 1 then
        return true;
    end
    return false;
end
function Lua_SceneConfigData.Get:single_map()
    if self.config.single_map == nil then
        return 0;
    end
    return self.config.single_map;
end
function Lua_SceneConfigData.Get:hook_range()
    if self.config.single_map == 1 then
        return 999999999;
    end
    if self.config.hook_range == nil then
        return 0;
    end
    return self.config.hook_range;
end
function Lua_SceneConfigData.Get:copy_type()
    if self.config.copy_type == nil then
        return 0;
    end
    return self.config.copy_type;
end

function Lua_SceneConfigData.Get:no_auto_relive()
    if self.config.no_auto_relive == nil then
        return 0;
    end
    return self.config.no_auto_relive;
end

function Lua_SceneConfigData.Get:is_yuandi_relive()
    if self.config.is_yuandi_relive == nil then
        return 0;
    end
    return self.config.is_yuandi_relive;
end

function Lua_SceneConfigData.Get:show_monster_list()
    if self.config == nil or self.config.show_monster_list == nil then
        return 0;
    end
    return self.config.show_monster_list;
end

function Lua_SceneConfigData.Get:show_server_name()
    if self.config.show_server_name == nil then
        return 0;
    end
    return self.config.show_server_name;
end

function Lua_SceneConfigData.Get:kuafu_map()
    if self.config.show_server_name == nil then
        return 0;
    end
    return self.config.show_server_name;
end

function Lua_SceneConfigData.Get:no_select_safe_area()
    if self.config.no_select_safe_area == nil then
        return 0;
    end
    return self.config.no_select_safe_area;
end

function Lua_SceneConfigData.Get:no_act_tip()
    if self.config.no_act_tip == nil then
        return 0;
    end
    return self.config.no_act_tip;
end

function Lua_SceneConfigData.Get:close_right_top()
    if self.config.close_right_top == nil then
        return 0;
    end
    return self.config.close_right_top;
end

function Lua_SceneConfigData.Get:guide_id()
    if self.config.guide_id == nil then
        return 0;
    end
    return self.config.guide_id;
end

function Lua_SceneConfigData.Get:close_chat()
    if self.config.close_chat == nil then
        return 0;
    end
    return self.config.close_chat;
end
function Lua_SceneConfigData.Get:not_show_transfer_time()
    -- 1时不显示变身剩余时间
    if self.config.not_show_transfer_time == nil then
        return 0;
    end
    return self.config.not_show_transfer_time;
end
function Lua_SceneConfigData.Get:relive_pos()
    if self._relive_pos == nil then
        self._relive_pos = { };
        if self.config == nil or self.config.relive == nil or self.config.relive.fixed_pos == nil then
            self._relive_pos.x = -1;
            self._relive_pos.y = -1;
            self._relive_pos.z = -1;
        else
            self._relive_pos.x = self.config.relive.fixed_pos[1];
            self._relive_pos.y = self.config.relive.fixed_pos[2];
            self._relive_pos.z = self.config.relive.fixed_pos[3];
        end
    end
    return self._relive_pos;
end

function Lua_SceneConfigData.Get:limit_recover_item()
    if self._limit_recover_item == nil then
        local list = getConfig( { "tiny", "recover_item_limit" });
        for i, v in ipairs(list) do
            if tonumber(v) == tonumber(self.sceneId) then
                self._limit_recover_item = 1;
                break;
            end
        end
        if self._limit_recover_item == nil then
            self._limit_recover_item = 0;
        end
    end
    return self._limit_recover_item;
end
function Lua_SceneConfigData.Get:isMirrorMap()
    return self.config.is_mirror_map == 1;
end
function Lua_SceneConfigData.Get:canTransfer()
    if self.canTrans == nil then
        local limitList = getConfig( { "awake", "limit_scene" });
        for i, v in ipairs(limitList) do
            if v == self.sceneId then
                self.canTrans = false;
                return self.canTrans;
            end
        end
        self.canTrans = true;
    end
    return self.canTrans;
end
function Lua_SceneConfigData.Get:isSwimScene()
    return self.config.swim_act == 1;
end