-- 秘藏Vo
Lua_SecretVo = class("Lua_SecretVo");
function Lua_SecretVo:ctor(id, config)
    self.id = id;	
    if config == nil then
    	config = getConfig({ "animal_hoard", id });
    end
    self.config = config;
    self:resetServerInfo();
end

function Lua_SecretVo:resetServerInfo()
    self.isActivate = 0; -- 激活状态
    self.isFreeDraw = 0; -- 0:没有免费次数 1:有免费次数
    self.copperDrawTimes = 0; -- 铜钱抽奖次数
    self.oneDrawTimes = 0; -- 绑元/元宝单抽次数
    self.tenDrawTimes = 0; -- 元宝十抽次数
end

function Lua_SecretVo:updateServerInfo(serverInfo)
    if serverInfo == nil or serverInfo.hoard_num ~= self.id then
        return;
    end

    self.isActivate = serverInfo.activate;
    self.isFreeDraw = serverInfo.free_draw;
    self.copperDrawTimes = serverInfo.copper_draw_times;
    self.oneDrawTimes = serverInfo.gold_one_draw_times;
    self.tenDrawTimes = serverInfo.gold_ten_draw_times;
end

---------- 消耗类型 ----------

-- 是否消耗铜钱
function Lua_SecretVo.Get:isCopperDraw()
	if self.config.money_type[1] == 1 then
		return true;
	end
	return false;
end

-- 是否消耗绑元
function Lua_SecretVo.Get:isBindGoldDraw()
	if self.config.money_type[2] == 1 then
		return true;
	end
	return false;
end

-- 是否消耗元宝
function Lua_SecretVo.Get:isGoldDraw()
	if self.config.money_type[3] == 1 then
		return true;
	end
	return false;
end


----------- 花费金额 ----------

-- 铜钱 召唤
function Lua_SecretVo.Get:copperDrawCost()
	local price = self.config.copper_price;
	if price == nil then
		return nil;
	end

	local time = self.copperDrawTimes + 1;
	local len = #price;
	if self.copperDrawTimes >= len then
		time = len;
	end
	return price[time];
end

-- 绑元/元宝单抽 召唤
function Lua_SecretVo.Get:oneDrawCost()
	local price = self.config.one_gold_price;
	if price == nil then
		return nil;
	end

	local time = self.oneDrawTimes + 1;
	local len = #price;
	if self.oneDrawTimes >= len then
		time = len;
	end
	return price[time];
end

-- 元宝十抽 召唤
function Lua_SecretVo.Get:tenDrawCost()
	local price = self.config.ten_gold_price;
	if price == nil then
		return nil;
	end

	local time = self.tenDrawTimes + 1;
	local len = #price;
	if self.tenDrawTimes >= len then
		time = len;
	end
	return price[time];
end

---------- 花费折扣 -----------

-- 铜钱 召唤折扣
function Lua_SecretVo.Get:copperDiscount()
	local discount = self.config.copper_discount;
	if discount == nil then
		return nil;
	end

	local time = self.copperDrawTimes + 1;
	local len = #discount;
	if self.copperDrawTimes >= len then
		time = len;
	end
	return discount[time];
end

-- 绑元/元宝单抽 召唤
function Lua_SecretVo.Get:oneDiscount()
	local discount = self.config.one_discount;
	if discount == nil then
		return nil;
	end

	local time = self.oneDrawTimes + 1;
	local len = #discount;
	if self.oneDrawTimes >= len then
		time = len;
	end
	return discount[time];
end

-- 元宝十抽 召唤
function Lua_SecretVo.Get:tenDiscount()
	local discount = self.config.ten_discount;
	if discount == nil then
		return nil;
	end

	local time = self.tenDrawTimes + 1;
	local len = #discount;
	if self.tenDrawTimes >= len then
		time = len;
	end
	return discount[time];
end

-- 头像资源名
function Lua_SecretVo.Get:headStr()
	local str = "";
	if self.config.headStr ~= nil then
		str = "/images/head/zodiac/" .. self.config.headStr;
	end
	return str;
end