Lua_SkillVo = class("Lua_SkillVo");
function Lua_SkillVo:ctor(skillId)
	self:superCall("ctor");

	self.skill_owner = 1;
	self.config = getConfig({"player_skill", skillId});
	self.skillId = skillId;

	if self.config == nil then
		self.config = getConfig({"monster_skill", skillId});
		self.skill_owner = 2;
	end

	if self.config == nil then
		self.config = getConfig({"servant_skill", skillId});
		self.skill_owner = 3;
	end

	if self.config == nil then
		self.config = getConfig({"recast_skill", skillId});
		self.skill_owner = 3;
	end

	if self.config == nil then
		print("no skill config:"..skillId);
	end
	self.useTimes = 0;
	self.lastTime = -99999;
end

function Lua_SkillVo.getCarrerSkillInterval()
	if Lua_SkillVo.csInterval == nil then
		local s = Lua_CommonUtil.getCommonConfig("careerskill_interval", 1);
		Lua_SkillVo.csInterval = s * 0.001;
	end
	return Lua_SkillVo.csInterval;
end

function Lua_SkillVo:fromServer(val)
	self.skillLevel = val.skill_level;
	self.useSec = val.use_sec;
	self.usUSec = val.use_usec;
	self.useTimes = val.use_times;
end

function Lua_SkillVo:hasLearn()
	return self.skillLevel ~= 0;
end

function Lua_SkillVo:updateUseTime(offsetTime)
	self.lastTime = UnityEngine.Time.realtimeSinceStartup + 0.5;
end

function Lua_SkillVo:updateCdTime(cdLeftTime)
	self.lastTime = UnityEngine.Time.realtimeSinceStartup - cdLeftTime + 0.5;
end

function Lua_SkillVo:updateCdLeftTime(cdLeftTime)
	self.lastTime = UnityEngine.Time.realtimeSinceStartup - (self.cool - cdLeftTime) + 0.5;
end

function Lua_SkillVo.Get:curCoolTime()
	local dt = UnityEngine.Time.realtimeSinceStartup - self.lastTime;
	local lt = self.cool - dt;
	if lt <= 0 then
		lt = 0;
	end
	return lt;
end

function Lua_SkillVo.Get:isCool()
	local nt = UnityEngine.Time.realtimeSinceStartup;
	local dt2 = nt - self.lastTime;
	local lt = self.cool - dt2;
	if lt <= 0 then
		local dt = nt - DataCenter.skillData.lastCareerTime;
		if self.skillType == Lua_SkillDefine.SKILL_TYPE_CAREER then
			if dt < Lua_SkillVo.getCarrerSkillInterval() then
				return 1;
			end
		end
		return 0;
	else
		return 2;
	end
end

function Lua_SkillVo.Get:canUse()
	if self.skillType == Lua_SkillDefine.SKILL_TYPE_BASE then
		return true;
	end
	if DataCenter.roleData.mp < self.costMagic then
		return false;
	end
	if self:hasLearn() == false then
		return false;
	end
	if self.isCool ~= 0 then
		return false;
	end
	return true;
end

function Lua_SkillVo.Get:defaultSkill()
	local s = self.config.defaultSkill;
	if s == nil then
		return 0;
	end
	return s;
end

function Lua_SkillVo.Get:skillLv()
	if self.skillLevel == nil then
		return 0;
	else
		return self.skillLevel
	end
end

-- 蓝耗
function Lua_SkillVo.Get:costMagic()
	return self:getCostMagic(self.skillLevel);
end

-- 技能类型  1職業技能，2怒氣技能，3狀態技能，4被動技能，5基礎技能，6跳躍技能
function Lua_SkillVo.Get:skillType()
	return self.config.skill_type;
end

-- 技能类型名字
function Lua_SkillVo.Get:skillTypeName() -- 如有需要自己添加 2018/10/24
	if self.skillType == 1 then
		return LanUtil.getValue(110600);
	elseif self.skillType == 4 then
		return LanUtil.getValue(110601);
	end
end

-- 转生次数
function Lua_SkillVo.Get:changeJob()
	return self.config.change_job;
end

-- 技能名字
function Lua_SkillVo.Get:name()
	return self.config.name;
end

-- CD时间
function Lua_SkillVo.Get:cool()
	if self.config.cool == nil then
		return 0;
	end
	if self._cool == nil then
		self._cool = self.config.cool;
		if self.skillType == 9 then
			self._cool = self._cool + 2;
		end
	end
	return self._cool;
end

-- 图集
function Lua_SkillVo.Get:atlas()
	return self.config.atlas;
end

-- 图标
function Lua_SkillVo.Get:skillIcon()
	return self.config.skill_icon;
end

-- 奇缘激活
function Lua_SkillVo.Get:activate()
	return self.config.activate;
end

function Lua_SkillVo.Get:maxLevel()
	if self.config.savvy ~= nil then
		return #self.config.savvy + 1;
	end
	return 1;
end

function Lua_SkillVo:getCostMagic(lv)
	if self.skillLevel == 0 then
		return 0;
	end

	if self.config.magic == nil or self.config.magic[lv] == nil then
		return 0;
	else
		return self.config.magic[lv];
	end
end

function Lua_SkillVo.Get:auto_distance()
	if self.config.auto_distance == nil then
		return 0;
	end
	return self.config.auto_distance;
end

function Lua_SkillVo.Get:des()
	if self.config.reMark == nil then
		return nil;
	end
	return self.config.reMark;
end

-- 技能激活状态描述
function Lua_SkillVo.Get:stateDes()
	if self.config.stateDes == nil then
		return "";
	end
	return self.config.stateDes;
end

function Lua_SkillVo.Get:desc()
	if self._desc == nil then
		self._desc = self.config.desc;
	end
	return self._desc;
end

function Lua_SkillVo.Get:descName()
	if self._desc_name == nil then
		self._desc_name = self.config.desc_name;
	end
	return self._desc_name;
end

function Lua_SkillVo.Get:slot()
	if self.config.slot == nil then
		return 0;
	end
	return self.config.slot;
end

function Lua_SkillVo.Get:show_tip()
	if self.config.show_tip == nil then
		return 0;
	end
	return self.config.show_tip;
end

function Lua_SkillVo.Get:show_tip_time()
	if self.config.show_tip_time == nil then
		return 0.5;
	end
	return self.config.show_tip_time;
end

function Lua_SkillVo:getMoney(lv)
	if self.config.money == nil or self.config.money[lv] == nil then
		return 0;
	else
		return self.config.money[lv];
	end
end

function Lua_SkillVo:getSavvy(lv)
	if self.config.savvy == nil or self.config.savvy[lv] == nil then
		return 0;
	else
		return self.config.savvy[lv];
	end
end

function Lua_SkillVo:getCurPercent(lv)
	if self.config.detail == nil or self.config.detail[lv] == nil or self.config.detail[lv].effect == nil or self.config.detail[lv].effect[1] == nil then
		return 0;
	else
		return self.config.detail[lv].effect[1].percent;
	end
end

function Lua_SkillVo:getCurBloodPercent(lv)
	if self.config.detail == nil or self.config.detail[lv] == nil or self.config.detail[lv].effect == nil or self.config.detail[lv].effect[1] == nil then
		return 0;
	else
		return self.config.detail[lv].effect[1].blood_percent;
	end
end

function Lua_SkillVo:getCurDamage(lv)
	if self.config.detail == nil or self.config.detail[lv] == nil or self.config.detail[lv].effect == nil or self.config.detail[lv].effect[1] == nil then
		return 0;
	else
		return self.config.detail[lv].effect[1].value;
	end
end

function Lua_SkillVo:getUseLvl(lv)
	if self.skillLevel == 0 then
		return 0;
	end

	if type(self.config.useLvl) == "number" then
		return self.config.useLvl;
	end
	
	if self.config.useLvl == nil or self.config.useLvl[lv] == nil then
		return 0;
	else
		return self.config.useLvl[lv];
	end
end

function Lua_SkillVo.Get:preEffect()
	if self.config.preEffect ~= nil then
		return self.config.preEffect;
	end
	return nil;	
end

function Lua_SkillVo:getActiveLv()
	if self.config.useLvl ~= nil then
		if type(self.config.useLvl) == "number" then
			return self.config.useLvl;
		else
			return self.config.useLvl[1];
		end
	end
	return 1;
end

function Lua_SkillVo.Get:guideFloatingTarget()
	if self.config.guide_floating_target ~= nil then
		return self.config.guide_floating_target;
	end
	return nil;	
end

function Lua_SkillVo.Get:canUpdate()
	if self:hasLearn() == false then
		return false;
	end
	if self.skillLevel >= self.maxLevel then
		return false;
	end
	if self:getSavvy(self.skillLevel) > DataCenter.moneyData:getMoney(Lua_MoneyData.SAVVY) then
		return false;
	end
	if self:getMoney(self.skillLevel) > DataCenter.moneyData:getMoney(Lua_MoneyData.COPPER) then
		return false;
	end
	return true;
end