Lua_ThingVo = class("Lua_ThingVo");
function Lua_ThingVo:ctor(objId, type)
    self.objId = tonumber(tostring(objId));
    self.thingType = type;
end

function Lua_ThingVo:fromMonsterServer(val)
    self.px = val.coord.pixel_x;
    self.py = val.coord.pixel_y;
    self.pz = val.coord.pixel_z;
    self.maxHp = tonumber(tostring(val.max_blood));
    self.hp = tonumber(tostring(val.ai_blood));
    self.camp_id = val.camp_id;
    self.kind = Lua_ThingDefine.MONSTER;
    -- print("self.configId",self.configId);
    self.monsterData = Lua_MonsterConfigData.new(self.configId);
    self.lvl = self.monsterData.level;
    self.name = self.monsterData.name;
    self.noSelect = self.monsterData.noSelect;
    self.reliveSec = val.relive_sec;
    self.reliveEndTime = getTime() + val.relive_sec;
    self.otherName = val.other_name;
    self.otherLvl = val.other_lvl;
    self.cur_value = val.cur_value;
    -- 当前值
    self.total_value = val.total_value;
    -- 总值
    if val.lvl ~= nil then
        self.lvl = val.lvl;
    end
    self.sub_id = tonumber(tostring(val.sub_id));
    -- 附加ID，根据场景不同，有不同含义
    self.reward_belong = val.reward_belong;
    -- 奖励归属与哪个玩家（玩家名）
end
function Lua_ThingVo:fromPetServer(val)
    self.px = val.location.pixel_x;
    self.py = val.location.pixel_y;
    self.pz = val.location.pixel_z;
    self.master_id = val.master_id;
    self.kind = Lua_ThingDefine.PET;
    self.hp = 1;
    self.maxHp = 1;
end
function Lua_ThingVo:fromUserServer(val)
    self.lvl = val.level;
    self.gender = val.sex;
    self.name = val.name;
    self.gender = val.sex;
    self.hp = tonumber(tostring(val.blood));
    self.maxHp = tonumber(tostring(val.max_blood));
    self.fightState = val.fight_state;
    self.vipLv = val.vip_type;
    self.force = tonumber(tostring(val.force));
    self.camp_id = val.camp_id;
    self.leagueId = tonumber(tostring(val.league_id));
    self.leagueName = val.league_name;
    self.px = val.coord.pixel_x;
    self.py = val.coord.pixel_y;
    self.pz = val.coord.pixel_z;
    self.kind = Lua_ThingDefine.USER;
    self.militaryRank = val.military_rank;
    self.labelId = val.shape_info.label;
    self.nameColor = val.name_color;
    self.vipType = val.vip_type;
    self.ascription_state = val.ascription_state;
    self.occupy_state = val.occupy_state;
    self.hooking = val.hooking;
    self.copy_player = val.copy_player;
    self.permission = val.permission;
    self.copy_id = tonumber(tostring(val.shape_info.role_id));
    self.server_name = val.server_name;

    self.wingId = val.shape_info.wing;
    self.fairyId = val.shape_info.fairy_shape;
    self.spoorId = val.shape_info.spoor_shape;
    self.faqiId = val.shape_info.mw_shape;
    self.fashion_weapon_id = val.shape_info.fashion_weapon_id;
    self.fashion_clothes_id = val.shape_info.fashion_clothes_id;
    self.fashionHeadId = val.shape_info.fashion_headdress_id;
    self.mount_id = val.shape_info.mount_shape;
    self.cloak = val.cloak;      
    self.sun_bath_type = val.sun_bath_type; -- 日光浴类型 0未使用 1自身的 2他人的
end

function Lua_ThingVo:fromDropServer(val)
    self.px = val.pixel_x;
    self.py = val.pixel_y;
    self.pz = val.pixel_z;
    self.item_id = val.item_id;
    self.no_viewer_set = val.no_viewer_set;
    self.drop_type = val.drop_type;
    self.no_auto_pickup = val.no_auto_pickup;
    self.left_protect_sec = val.left_protect_sec + 1;
    self.start_time = getTime();
    self.amount = val.amount;
    local rid = DataCenter.roleData.roleId;
    local lid = DataCenter.roleData.leagueId;
    local len = #val.viewer_set;
    if len == 0 then
        self.left_protect_sec = -1;
    else
        for i, v in ipairs(val.viewer_set) do
            local vnum = tonumber(v);
            if vnum == rid or vnum == leagueId then
                self.left_protect_sec = -1;
            end
        end
    end
end

function Lua_ThingVo.Set:ascription_state(val)
    self._ascription_state = val;
end
function Lua_ThingVo.Get:ascription_state()
    if self._ascription_state == 1 then
        return 1;
    end
    local buffVo = self:getBuffById(70005);
    if buffVo ~= nil then
        self.ascriptionEffect = buffVo.effect;
        self.atlasAndSprite = buffVo.atlasAndSprite;
        return 3;
    end
    buffVo = self:getBuffById(80001);
    if buffVo ~= nil then
        self.ascriptionEffect = buffVo.effect;
        self.atlasAndSprite = buffVo.atlasAndSprite;
        return 2;
    end
    return 0;
end

function Lua_ThingVo:canPick(auto)
    if self.thingType ~= Lua_ThingDefine.DROP_ITEM then
        return false;
    end
    if getTime() - self.start_time < self.left_protect_sec then
        return false;
    end
    if auto == true then
        local auto_pick_color = DataCenter.hangUpSettingsData.auto_pick_color;
        local tvo = Lua_ToolVo.createToolVo(self.item_id, 1, 1);
        if tvo.color < auto_pick_color then
            return false;
        end
    end
    return true;
end

function Lua_ThingVo:setCurPosition(px, py, pz)
    self.px = px;
    self.py = py;
    self.pz = pz;
end

function Lua_ThingVo.Get:isDead()
    return self.hp <= 0;
end

function Lua_ThingVo.Get:isCollect()
    if self.monsterData == nil then
        return false;
    end
    return self.monsterData.isCollect;
end

function Lua_ThingVo.Get:eachBloodVal()
    if self.monsterData == nil then
        return 0;
    end
    return self.monsterData.eachBloodVal;
end

function Lua_ThingVo.Get:isShowHpBar()
    if self.monsterData == nil then
        return false;
    end
    return self.monsterData.isShowHpBar;
end

function Lua_ThingVo.Get:boss()
    if self.monsterData == nil then
        return 0;
    end
    return self.monsterData.boss;
end

function Lua_ThingVo:updateBuff(val)
    if val == nil then
        return;
    end

    if self.buffList == nil then
        self.buffList = Array();
    end

    local len = self.buffList:getSize();
    for i = 1, len do
        if self.buffList[i].id == val.id then
            self.buffList[i] = val;
            return;
        end
    end
    self.buffList:add(val);
end

function Lua_ThingVo:getBuffById(val, onlyId)
    if self.buffList == nil then
        return nil;
    end
    local len = self.buffList:getSize();
    for i = 1, len do
        if onlyId == true then
            if self.buffList[i].id == val then
                return self.buffList[i];
            end
        else
            if self.buffList[i].id == val or self.buffList[i].buff_type == val then
                return self.buffList[i];
            end
        end

    end
    return nil;
end

function Lua_ThingVo:removeBuff(id)
    if self.buffList == nil then
        return;
    end

    local len = self.buffList:getSize();
    for i = 1, len do
        if self.buffList[i].id == id then
            self.buffList:remove(i);
            return;
        end
    end
end