-- 生肖装备孔位
Lua_ZodiacHoleVo = class("Lua_ZodiacHoleVo")
function Lua_ZodiacHoleVo:ctor()
    self:superCall("ctor");

    self.zodiacId = 1;
    self.holePart = 1; -- 部位
    self:resetServerInfo();
end

function Lua_ZodiacHoleVo:resetServerInfo()
	self.equipment = nil; -- 生肖装备
	self.intensifyLevel = 0; -- 部位强化等级
	self.intensifyProgress = 0; -- 部位强化进度
end

function Lua_ZodiacHoleVo:updateServerInfo(info)
    if info == nil then
        return;
    end

    self.equipment = info.equipment;
    self.intensifyLevel = info.equip_level;
    self.intensifyProgress = info.lattice_progress;
end

function Lua_ZodiacHoleVo.Get:equipVo()
	if self.equipment ~= nil and self.equipment.id ~= 0 then
		local vo = Lua_ToolVo.createToolVo(self.equipment.id, self.equipment.amount, self.equipment.bind);
		vo.intensifyLevel = self.intensifyLevel;
		vo.isWear = true;
		vo:fromServer(self.equipment);
		return vo;
	end
	return nil;
end

function Lua_ZodiacHoleVo.Get:maxIntensifyLevel()
	return self.equipVo.intensify_limit;
end

-- 是否强化到最大等级
function Lua_ZodiacHoleVo.Get:isMaxIntensify()
	if self.equipVo == nil then
		return false;
	end

	if self.intensifyLevel >= self.maxIntensifyLevel then
		return true;
	end
	return false;
end

-- 是否最高阶
function Lua_ZodiacHoleVo.Get:isMaxUpgrade()
	local nextVo = DataCenter.zodiacUtil:getUpgradeVoById(self.equipVo.id);
	if nextVo == nil then
		return true;
	end
	return false;
end

-- 强化ID
function Lua_ZodiacHoleVo.Get:intensifyId() 
	return self.equipVo.part * 1000 + self.intensifyLevel;
end

function Lua_ZodiacHoleVo.Get:intensifyVo()
	if self.equipVo == nil then
		return nil;
	end
	return DataCenter.zodiacUtil:getIntensifyVoById(self.intensifyId);
end

function Lua_ZodiacHoleVo.Get:nextIntensifyVo()
	if self.equipVo == nil then
		return nil;
	end
	return DataCenter.zodiacUtil:getIntensifyVoById(self.intensifyId + 1);
end

function Lua_ZodiacHoleVo.Get:intensifyInfoArr()
	local arr = Array();

	if self.equipVo ~= nil then
		-- 强化消耗
		local expendStr = nil;
		local costVo = nil;
		if self.isMaxIntensify then
			costVo = nil;
			if self.equipVo.color >= 5 and self.isMaxUpgrade == false then -- 红色品质且未达到最高阶
				expendStr = LanUtil.getValue(143457);
			else
				expendStr = LanUtil.getValue(143456);
			end
		else
			costVo = DataCenter.zodiacUtil.intensifyCostVo;
			local haveNum = DataCenter.zodiacData.intensifyCostCount;
			local needNum = self.intensifyVo.costCount;
			local str = "[192E41]"..haveNum.."/"..needNum.."[-]";
			if haveNum < needNum then
				str = "[F42A2A]"..haveNum.."[-][192E41]/"..needNum.."[-]";
			end
			expendStr = LanUtil.formateStr(LanUtil.getValue(143454), str);
		end
		arr:add({ currLabel = expendStr, costVo = costVo, nextLabel = nil });

		-- 强化等级
		local currLvl = LanUtil.formateStr(LanUtil.getValue(143455), (self.intensifyLevel).."/"..(self.maxIntensifyLevel));
		local nextLvl = nil;
		if self.isMaxIntensify == false then
			nextLvl = "[13A100]"..(self.intensifyLevel + 1).."[-][192E41]/"..(self.maxIntensifyLevel).."[-]";
		end
		arr:add({ currLabel = currLvl, costVo = nil, nextLabel = nextLvl });

		-- 强化属性
		if self.intensifyVo ~= nil then
			local dic = self.intensifyVo.attrsDic;
			if self.isMaxIntensify then
				for k,v in ipairs(Lua_ThingDefine.params) do
					local val = dic[v];
					if val ~= nil then
						if Lua_ThingDefine.isPercentParam(v) then
			                val = val.."%";
			            end
			            local currLabel = "[394463]"..Lua_ThingDefine.getParamName(v).."："..val.."[-]";
			            arr:add({ currLabel = currLabel, costVo = nil, nextLabel = nil });
					end
				end
			else
				if self.nextIntensifyVo ~= nil then
					local _dic = self.nextIntensifyVo.attrsDic;
					for k,v in ipairs(Lua_ThingDefine.params) do
						local val = dic[v];
						local nextVal = _dic[v];
						if val ~= nil and nextVal ~= nil then
							if Lua_ThingDefine.isPercentParam(v) then
				                val = val.."%";
				                nextVal = nextVal.."%";
				            end
				            local currLabel = "[394463]"..Lua_ThingDefine.getParamName(v).."："..val.."[-]";
				            local nextLabel = "[13A100]"..nextVal.."[-]";
				            arr:add({ currLabel = currLabel, costVo = nil, nextLabel = nextLabel });
						end
					end
				end
			end
		end
	end

	return arr;
end

---------- 红点显隐处理 ----------
-- 有装备可穿戴
function Lua_ZodiacHoleVo.Get:isHaveEquipWear()
    local bagData = DataCenter.packData:getBagType(Lua_PackData.ZODIAC_PACK);
    local arr = bagData:getItemsBySubType({Lua_PackTypeDefine.ZODIAC_EQUIP_ITEM});
    if arr:getSize() <= 0 then
        return false;
    end

    local len = arr:getSize();
    for i = 1, len do
        if self.equipVo == nil and arr[i].career == self.zodiacId and arr[i].part == self.holePart then
        	return true;
        end
    end
    return false;
end

-- 有更高阶装备
function Lua_ZodiacHoleVo.Get:isHaveGoodOrderEquip()
	if self.equipVo == nil then
		return false;
	end

    local bagData = DataCenter.packData:getBagType(Lua_PackData.ZODIAC_PACK);
    local arr = bagData:getItemsBySubType({Lua_PackTypeDefine.ZODIAC_EQUIP_ITEM});
    if arr:getSize() <= 0 then
        return false;
    end

    local len = arr:getSize();
    for i = 1, len do
        if arr[i].career == self.zodiacId and arr[i].part == self.holePart and arr[i].order > self.equipVo.order then
        	return true;
        end
    end
    return false;
end

-- 有装备可强化
function Lua_ZodiacHoleVo.Get:isEquipCanIntensify()
	if self.isMaxIntensify == true or self.intensifyVo == nil then
		return false;
	end

	local haveNum = DataCenter.zodiacData.intensifyCostCount;
	local needNum = self.intensifyVo.costCount;
	if haveNum >= needNum then
		return true;
	end
	return false;
end

-- 有装备可升阶
function Lua_ZodiacHoleVo.Get:isEquipCanUpgrade()
	if self.equipVo == nil then
		return false;
	end

	if self.isMaxIntensify == false then--是否满足强化上限
		return false;
	end

	if self.equipVo.color < 5 then
		return false;
	end

	if self.isMaxUpgrade then
		return false;
	end

	local nextVo = DataCenter.zodiacUtil:getUpgradeVoById(self.equipVo.id);
	local costVo = nextVo.costVo;
	local bagData = DataCenter.packData:getBagType(Lua_PackData.ZODIAC_PACK);
    local haveNum = bagData:getItemNum(costVo.id);
    local needNum = costVo.count;
    if haveNum >= needNum then
    	return true;
    else
    	return false;
    end
end