-- 生肖配置
checkRequire("Lua_ZodiacVo");
checkRequire("Lua_ZodiacHoleVo");
checkRequire("Lua_ZodiacSkillVo");
checkRequire("Lua_ZodiacSkillExtendVo");
checkRequire("Lua_ZodiacEquipIntensifyVo");
checkRequire("Lua_ZodiacEquipResolveVo");
checkRequire("Lua_ZodiacEquipUpgradeVo");
Lua_ZodiacUtil = class("Lua_ZodiacUtil");
function Lua_ZodiacUtil:ctor()
    self:superCall("ctor");
end

function Lua_ZodiacUtil:resetZodiacInfo()
    if self._zodiacDic ~= nil then
		for k, v in pairs(self.zodiacInfoDic) do
	    	v:resetServerInfo();
	    end
	end
end

function Lua_ZodiacUtil:resetZodiacSkill()
	if self.skillDic ~= nil then
		for k, v in pairs(self.skillDic) do
	    	v:resetServerInfo();
	    end
	end
end

function Lua_ZodiacUtil:updateZodiacInfo(serverInfo)
	if serverInfo == nil or serverInfo.index == nil then
		return;
	end

	local vo = self.zodiacInfoDic[serverInfo.index];
	if vo ~= nil then
		vo:updateServerInfo(serverInfo);
	end
end

function Lua_ZodiacUtil.Get:zodiacDic()
	if self._zodiacDic == nil then
		self._zodiacDic = {};
		self._zodiacInfoDic = {};
		self._zodiacInfoArr = Array();

		local config = getConfig({ "zodiac" });
		local vo = nil;
		for k,v in pairs(config) do
			vo = Lua_ZodiacVo.new(k, v);
			if self._zodiacDic[vo.mainType] == nil then
				self._zodiacDic[vo.mainType] = Array();
			end
			self._zodiacDic[vo.mainType]:add(vo);
			self._zodiacInfoDic[k] = vo;
			self._zodiacInfoArr:add(vo);
		end

		for k,v in pairs(self._zodiacDic) do
			v:sort("id", false);
		end
	end
	return self._zodiacDic;
end

function Lua_ZodiacUtil.Get:zodiacArr()
	if self._zodiacArr == nil then
		self._zodiacArr = Array();
		local len = 0;
		for k, arr in pairs(self.zodiacDic) do
			len = arr:getSize();
			if len > 0 then
	    		self._zodiacArr:add({ name = arr[1].mainName, sub = arr });
			end
		end
	end
	return self._zodiacArr;
end

function Lua_ZodiacUtil.Get:zodiacInfoDic()
	if self._zodiacInfoDic == nil then
		local dic = self.zodiacDic;
	end
	return self._zodiacInfoDic;
end

function Lua_ZodiacUtil.Get:zodiacInfoArr()
	if self._zodiacInfoArr == nil then
		local dic = self.zodiacDic;
	end
	return self._zodiacInfoArr;
end

function Lua_ZodiacUtil:getZodiacVoById(id)
	local dic = self.zodiacInfoDic;
	if dic ~= nil and dic[id] ~= nil then
		return dic[id];
	end
	return nil;
end

-- 生肖技能数据
function Lua_ZodiacUtil:getSkillVoById(id)
	if self.skillDic == nil then
		self.skillDic = {};
	end
	if self.skillDic[id] == nil then
		local config = getConfig({ "zodiac_skills", id });
		if config == nil then
			return nil;
		end
		self.skillDic[id] = Lua_ZodiacSkillVo.new(id);
	end
	return self.skillDic[id];
end

-- 生肖扩展技能数据
function Lua_ZodiacUtil:getSkillExtendVoById(id)
	if self.skillExtendDic == nil then
		self.skillExtendDic = {};
	end
	if self.skillExtendDic[id] == nil then
		local config = getConfig({ "zodiac_expand", id });
		if config == nil then
			return nil;
		end
		self.skillExtendDic[id] = Lua_ZodiacSkillExtendVo.new(id, config);
	end
	return self.skillExtendDic[id];
end

-- 生肖装备强化数据
function Lua_ZodiacUtil:getIntensifyVoById(id)
	if self.intensifyDic == nil then
		self.intensifyDic = {};
	end
	if self.intensifyDic[id] == nil then
		local config = getConfig({ "zodiac_intensify", id });
		if config == nil then
			return nil;
		end
		self.intensifyDic[id] = Lua_ZodiacEquipIntensifyVo.new(id, config);
	end
	return self.intensifyDic[id];
end

-- 生肖装备分解数据
function Lua_ZodiacUtil:getResolveVoById(id)
	if self.resolveDic == nil then
		self.resolveDic = {};
	end
	if self.resolveDic[id] == nil then
		local config = getConfig({ "zodiac_decompose", id });
		if config == nil then
			return nil;
		end
		self.resolveDic[id] = Lua_ZodiacEquipResolveVo.new(id, config);
	end
	return self.resolveDic[id];
end

-- 生肖装备进阶数据
function Lua_ZodiacUtil:getUpgradeVoById(id)
	if self.upgradeDic == nil then
		self.upgradeDic = {};
	end
	if self.upgradeDic[id] == nil then
		local config = getConfig({ "zodiac_advanced", id });
		if config == nil then
			return nil;
		end
		self.upgradeDic[id] = Lua_ZodiacEquipUpgradeVo.new(id, config);
	end
	return self.upgradeDic[id];
end

-- 分解获得道具总数
function Lua_ZodiacUtil:resolveTotalNum(arr)
    local resolveNum = 0;
    for i = 1, arr:getSize() do
    	local resolveVo = self:getResolveVoById(arr[i].id);
    	resolveNum = resolveNum + resolveVo.resolveNum;
    end
    return resolveNum;
end

function Lua_ZodiacUtil:getCommonConfig(name, _type)
	if self.commonDic == nil then
		self.commonDic = {};
	end
	if self.commonDic[name] == nil then
		local config = getConfig({"zodiac_const", name});
		if config == nil then
			return nil;
		end
		self.commonDic[name] = config;
	end

	if _type == 1 then
		return self.commonDic[name].value;
	else
		return self.commonDic[name].arr;
	end
end

-- 生肖背包大小
function Lua_ZodiacUtil.Get:packSize()
	local packSize = self:getCommonConfig("pack_size", 1);
    if packSize ~= nil then
    	return packSize;
    end
    return 0;
end

-- 强化消耗道具Vo
function Lua_ZodiacUtil.Get:intensifyCostVo()
	if self._costVo == nil then
		local id = self:getCommonConfig("material_id", 1);
		self._costVo = Lua_ToolVo.createToolVo(id);
	end
    return self._costVo;
end

-- 生肖装备技能上限
function Lua_ZodiacUtil.Get:maxSkillLevel()
    local maxSkillLevel = self:getCommonConfig("max_skilllvl", 1);
    if maxSkillLevel ~= nil then
    	return maxSkillLevel;
    end
    return 0;
end

function Lua_ZodiacUtil:getZodiacName(career)
	local langNum = 143411 + career;
	return LanUtil.getValue(langNum);
end

function Lua_ZodiacUtil:getEquipPartName(part)
	local langNum = 143459 + part;
	return LanUtil.getValue(langNum);
end