-- 生肖Vo
Lua_ZodiacVo = class("Lua_ZodiacVo");
function Lua_ZodiacVo:ctor(id, config)
    self.id = id;	
    if config == nil then
    	config = getConfig({ "zodiac", id });
    end
    self.config = config;

    self:resetServerInfo();
end

function Lua_ZodiacVo:resetServerInfo()
    self.skillLevel = 0;
    self.skillState = 0;
    for k,v in pairs(self.holeVoDic) do
        v:resetServerInfo();
    end
end

function Lua_ZodiacVo:updateServerInfo(serverInfo)
    if serverInfo == nil or serverInfo.index ~= self.id then
        return;
    end

    self.skillLevel = serverInfo.skill_level; -- 技能等级 默认0级未激活
    self.skillState = serverInfo.skill_state; -- 技能状态 0未激活，1未使用，2已使用
    local lattices = serverInfo.lattices; -- 部位
    for k,v in pairs(self.holeVoDic) do
        if lattices[k] ~= nil then
            v:updateServerInfo(lattices[k]);
        end
    end
end

function Lua_ZodiacVo.Get:name()
    return self.config.name;
end

function Lua_ZodiacVo.Get:mainType()
    return self.config.mainType;
end

function Lua_ZodiacVo.Get:mainName()
    return self.config.mainName;
end

function Lua_ZodiacVo.Get:skillId()
    return self.config.skill;
end

function Lua_ZodiacVo.Get:headStr()
    local str = "";
    if self.config.headStr ~= nil then
        str = "/images/head/zodiac/" .. self.config.headStr;
    end
    return str;
end

function Lua_ZodiacVo.Get:holeVoDic()
    if self._holeVoDic == nil then
        self._holeVoDic = {};
        self._holeVoArr = Array();
        for i = 1, 4 do
            local vo = Lua_ZodiacHoleVo.new();
            vo.holePart = i; -- 部位
            vo.zodiacId = self.id; -- 生肖id
            self._holeVoDic[i] = vo;
            self._holeVoArr:add(vo);
        end
    end
    return self._holeVoDic;
end

function Lua_ZodiacVo.Get:holeVoArr()
    if self._holeVoArr == nil then
        local dic = self.holeVoDic;
    end
    return self._holeVoArr;
end

function Lua_ZodiacVo:getHoleVoByPart(part)
    local dic = self.holeVoDic;
    if dic ~= nil and dic[part] ~= nil then
        return dic[part];
    end
    return nil;
end

-- 穿戴装备所有生肖之力值
function Lua_ZodiacVo.Get:powersDic()
    local dic;
    local attrDic = {};
    local arr = self.holeVoArr;
    for i = 1, arr:getSize() do
        if arr[i].equipVo ~= nil then
            dic = arr[i].equipVo.zodiacPowersDic;
            for k,v in pairs(dic) do
                if attrDic[k] == nil then
                    attrDic[k] = v;
                else
                    attrDic[k] = attrDic[k] + v;
                end
            end
        end
    end
    return attrDic;
end

-- 穿戴装备所有基础属性值
function Lua_ZodiacVo.Get:baseAttrsDic()
    local dic;
    local attrDic = {};
    local arr = self.holeVoArr;
    for i = 1, arr:getSize() do
        if arr[i].equipVo ~= nil then
            dic = arr[i].equipVo.baseAttrsDic;
            for k,v in pairs(dic) do
                if attrDic[k] == nil then
                    attrDic[k] = v;
                else
                    attrDic[k] = attrDic[k] + v;
                end
            end
        end
    end
    return attrDic;
end

-- 穿戴装备所有基础属性强化值
function Lua_ZodiacVo.Get:intensifyAttrsDic()
    local dic;
    local attrDic = {};
    local arr = self.holeVoArr;
    for i = 1, arr:getSize() do
        if arr[i].intensifyVo ~= nil then
            dic = arr[i].intensifyVo.attrsDic;
            for k,v in pairs(dic) do
                if attrDic[k] == nil then
                    attrDic[k] = v;
                else
                    attrDic[k] = attrDic[k] + v;
                end
            end
        end
    end
    return attrDic;
end

-- 穿戴装备所有极品属性值
function Lua_ZodiacVo.Get:goodAttrsDic()
    local dic;
    local attrDic = {};
    local arr = self.holeVoArr;
    for i = 1, arr:getSize() do
        local vo = arr[i].equipVo;
        if vo ~= nil and vo.equipment.attr ~= nil and #vo.equipment.attr > 0 then
            dic = vo.equipment.attr;
            for j = 1, #dic do
                local id = dic[j].attr_id;
                local value = dic[j].value;

                if attrDic[id] == nil then
                    attrDic[id] = value;
                else
                    attrDic[id] = attrDic[id] + value;
                end
            end
        end
    end
    return attrDic;
end

-- 穿戴装备所有叠加属性
function Lua_ZodiacVo.Get:attrsArr()
    local arr = Array();
    local powersDic = self.powersDic;
    local baseAttrsDic = self.baseAttrsDic;
    local intensifyAttrsDic = self.intensifyAttrsDic;
    local goodAttrsDic = self.goodAttrsDic;

    for i,v in ipairs(Lua_ThingDefine.zodiacParams) do -- 生肖之力
        local val = powersDic[v];
        if val ~= nil and val ~= 0 then
            local list = {};
            list.name = Lua_ThingDefine.getParamName(v);
            list.baseValue = val;
            arr:add(list);
        end
    end

    for i,v in ipairs(Lua_ThingDefine.params) do -- 基础属性+强化
        local baseValue = baseAttrsDic[v];
        local intensifyValue = intensifyAttrsDic[v];
        if baseValue ~= nil and baseValue ~= 0 then
            local list = {};
            list.name = Lua_ThingDefine.getParamName(v);
            if Lua_ThingDefine.isPercentParam(v) then
                baseValue = baseValue .. "%";
                intensifyValue = intensifyValue .. "%";
            end
            list.baseValue = baseValue;
            list.intensifyValue = intensifyValue;
            arr:add(list);
        end
    end

    for k,v in pairs(goodAttrsDic) do -- 极品属性
        local str = Lua_ThingDefine.getParamName(k);
        local val = "[192E41]"..v.."[-]"
        arr:add({ name = LanUtil.formateStr(str, val) });
    end

    return arr;
end

-- 穿戴装备总评分
function Lua_ZodiacVo.Get:totalForce()
    local force = 0;
    local arr = self.holeVoArr;
    for i = 1, arr:getSize() do
        if arr[i].equipVo ~= nil then
            force = force + arr[i].equipVo.zongheForce;
        end
    end
    return force;
end

-- 当前技能数据
function Lua_ZodiacVo.Get:skillInfo()
    local level = self.skillLevel;
    if level == 0 then -- 默认0级 显示1级数据
        level = level + 1;
    end

    local vo = DataCenter.zodiacUtil:getSkillVoById(self.skillId + level);
    if vo ~= nil then
        vo.state = self.skillState;
    end
    return vo;
end

function Lua_ZodiacVo.Get:isSkillMaxLvl()
    local maxLvl = DataCenter.zodiacUtil.maxSkillLevel;
    if self.skillLevel >= maxLvl then
        return true;
    end
    return false;
end

-- 激活下一级技能提示
function Lua_ZodiacVo.Get:skillActivateTips()
    local str = "";
    local orderStr = "";
    if self.isSkillMaxLvl == false then
        local id = self.skillId + self.skillLevel + 1;
        local vo = DataCenter.zodiacUtil:getSkillVoById(id);
        if vo ~= nil then
            orderStr = LanUtil.formateStr(LanUtil.getValue(143451), tostring(vo.needOrder));
            if vo.needOrder > 9 then
                orderStr = LanUtil.formateStr(LanUtil.getValue(143452), tostring(vo.needOrder - 9));
            end
            str = LanUtil.formateStr(LanUtil.getValue(143403), LanUtil.getValue(100 + vo.needNum), orderStr, tostring(vo.lv), tostring(vo.remark));
        end
    end
    return str;
end

















-------------------- 红点显隐处理 --------------------
-- 孔位是否可强化装备
function Lua_ZodiacVo.Get:isEquipCanIntensify()
    local arr = self.holeVoArr;
    local len = arr:getSize();
    for i = 1, len do
        if arr[i].isEquipCanIntensify == true then
            return true;
        end
    end
    return false;
end

-- 孔位是否可升阶装备
function Lua_ZodiacVo.Get:isEquipCanUpgrade()
    local arr = self.holeVoArr;
    local len = arr:getSize();
    for i = 1, len do
        if arr[i].isEquipCanUpgrade == true then
            return true;
        end
    end
    return false;
end

-- 技能是否可使用
function Lua_ZodiacVo.Get:isSkillCanUse()
    if DataCenter.zodiacData.skillHaveUse == false then
        return false;
    end

    if self.skillState == 1 then
        return true;
    end
    return false;
end

-- 孔位是否可穿戴装备
function Lua_ZodiacVo.Get:isHaveEquipWear()
    local arr = self.holeVoArr;
    local len = arr:getSize();
    for i = 1, len do
        if arr[i].isHaveEquipWear == true then
            return true;
        end
    end
    return false;
end

-- 孔位是否有更高阶装备
function Lua_ZodiacVo.Get:isHaveGoodOrderEquip()
    local arr = self.holeVoArr;
    local len = arr:getSize();
    for i = 1, len do
        if arr[i].isHaveGoodOrderEquip == true then
            return true;
        end
    end
    return false;
end