function isNumber(v)
    return type(v) == 'number'
end

function Array(...)
    local new_array = {}

    local __array__ = {...}

    local __methods__ = {}
    function __methods__:typeof()
        return 'Array'
    end
    function __methods__:add(v, at)
        local len = #__array__ + 1
        at = isNumber(at) and at or len
        at = math.min(at, len)
        table.insert(__array__, at, v)
    end
	function __methods__:getSize()
		local len = #__array__;
		return len;
	end
    function __methods__:remove(at)
        at = isNumber(at) and at or #__array__
        return table.remove(__array__, at);
    end
	function __methods__:removeItem(item)
        for i,v in ipairs(__array__) do
			if v == item then
				self:remove(i);
				return;
			end
		end
    end
    function __methods__:getItem(index)
        return __array__[index];
    end
    function __methods__:print()
        table.print(__array__)
    end
    function __methods__:shift()
        return self:remove(1)
    end
    function __methods__:unshift(v)
        return self:insert(v, 1)
    end
    function __methods__:append(...)
        local elements = {...}
        for i= 1, #elements do
            self:insert(elements[i])
        end
    end
	function __methods__:clear()
		while( #__array__ > 0 )
		do
			self:remove(1);
		end
	end
    function __methods__:dispose()
        local len = self:getSize();
        for i = 1, len do
            local v = __array__[i];
            if type(v) == "table" and v.dispose ~= nil and v.isDispose_2 ~= true then
                v:dispose();
            end
        end
    end
    function __methods__:indexOf(v)
        local len = self:getSize();
        for i = 1, len do
            if __array__[i] == v then
                return i;
            end
        end
        return -1;
    end
    --up:true 降序， false：升序
    function __methods__:sort(name, up)
        up = up == nil and true or up;
        local len = self:getSize();
        for i = 1, len do
            for j = i + 1, len do
                local a1 = __array__[i][name];
                local b1 = __array__[j][name];
                local r = a1 < b1;
                if up == false then
                    r = not r;
                end
                if (r) then
                    local temp = __array__[i];
                    __array__[i] = __array__[j];
                    __array__[j] = temp;
                end
            end
        end
    end
    --多权重排序
    function __methods__:sortf(owner,sortfunction)
        local len = self:getSize();
        for i=1,len do
            for j = i + 1,len do
                local a = __array__[i]
                local b = __array__[j]
                if not sortfunction(owner,a,b) then
                    local temp = __array__[i]
                    __array__[i] = __array__[j]
                    __array__[j] = temp
                end
            end
        end
    end
    local mt = {
        __index = function(t, k)
            if isNumber(k) then
                return __array__[k]
            end
            if __methods__[k] then
                return __methods__[k]
            end
        end,
        __newindex = function(t, k, v)
            if nil == __array__[k] then
                print(string.format('warning : [%s] index out of range.', tostring(k)))
                return
            end
            if nil == v then
                print(string.format('warning : can not remove element by using  `nil`.'))
                return
            end
            __array__[k] = v
        end
    }
    setmetatable(new_array, mt)

    return new_array
end