local require = require
local string = string
local table = table
local json = require 'cjson'; 

function LuaGC()
    local c = collectgarbage("count")
    --print("Begin gc count = "..c.." kb")
    collectgarbage("collect")
    c = collectgarbage("count")
    --print("End gc count = "..c.." kb")
end
function getDistance(sx,sy, tx, ty)
    local dx = sx - sy;
    local dy = tx - ty;
    return math.sqrt(dx * dx + dy * dy);
end
function getTime()
    return UnityEngine.Time.realtimeSinceStartup;
end
function decodeJson(str)
    local data = json.decode(str)
    return data;
end

function decodeTabToJson(tab)
    if tab ~= nil then
        return json.encode(tab);
    end
    return nil;
end

function IsNil(uobj)
    return uobj == nil or uobj:Equals(nil)
end
function getConfigInLuaContain(aa,bb,cc,dd,ee,ff,gg,hh)
    local l = getConfigInLua(aa,bb,cc,dd,ee,ff,gg,hh);
    if l == nil then
        return false;
    end
    return true;
end
function getConfigInLuaLen(aa,bb,cc,dd,ee,ff,gg,hh)
    local l = getConfigInLua(aa,bb,cc,dd,ee,ff,gg,hh);
    if l == nil then
        return 0;
    end
    if type(l) ~= "table" then
        return 0;
    end
    return #l;
end
function getConfigInLuaInt(aa,bb,cc,dd,ee,ff,gg,hh)
    local l = getConfigInLua(aa,bb,cc,dd,ee,ff,gg,hh);
    if l == nil then
        return 0;
    end
    if type(l) ~= "number" then
        if type(l) == "table" and type(l[1]) == "number" then
            return l[1];
        end
    end
    return l;
end
function getConfigInLua(aa,bb,cc,dd,ee,ff,gg,hh)
    if hh ~= nil then
        return getConfig({aa,bb,cc, dd, ee, ff, gg, hh});
    elseif gg ~= nil then
        return getConfig({aa,bb,cc, dd, ee, ff, gg});
    elseif ff ~= nil then
        return getConfig({aa,bb,cc, dd, ee, ff});
    elseif ee ~= nil then
        return getConfig({aa,bb,cc, dd, ee});
    elseif dd ~= nil then
        return getConfig({aa,bb,cc, dd});
    elseif cc ~= nil then
        return getConfig({aa,bb,cc});
    elseif bb ~= nil then
        return getConfig({aa,bb});
    end
end
function getRandomRange(val)
    math.randomseed(tostring(getTime()):reverse());
    local s = math.floor(val * math.random()) + 1;
    return s;
end
function getTraceback()
    return debug.traceback();
end
function string.split(str,reps)
    local resultStrList = Array();
    string.gsub(str,'[^'..reps..']+',function ( w )
        resultStrList.add(resultStrList,w)
    end)
    return resultStrList
end
function string.formateDic(s, dic)
    local str = s;
    for k,v in pairs(dic) do
        str = string.gsub(str, "{"..k.."}", v);
    end
    return str;
end
function string.caculateString(str, table, toChinese)
    local arr = string.split(str,"|");
    local rs = "";
    for i = 1, arr:getSize() do
        local isC = string.find(arr[i], "{(.+)}");
        if isC == nil then
            rs = rs..arr[i];
        else
            local funStr = string.sub(arr[i], 2, string.len(arr[i])-1);
            local f = FormulaUtil.createFormula(funStr);
            local r = f:getRsValue(table);
            if toChinese == true then
                rs = rs..Lua_CommonUtil.getNumberTrans(r);
            else
                rs = rs..r;
            end
        end
    end
    return rs;
end
function stringWidth(inputstr)
   local lenInByte = #inputstr
   local width = 0
   local i = 1
   while (i<=lenInByte) 
    do
        local curByte = string.byte(inputstr, i)
        local byteCount = 1;
        if curByte>0 and curByte<=127 then
            byteCount = 1                                           --1字节字符
        elseif curByte>=192 and curByte<223 then
            byteCount = 2                                           --双字节字符
        elseif curByte>=224 and curByte<239 then
            byteCount = 3                                           --汉字
        elseif curByte>=240 and curByte<=247 then
            byteCount = 4                                           --4字节字符
        end

        local char = string.sub(inputstr, i, i+byteCount-1)            

        i = i + byteCount                                 -- 重置下一字节的索引
        width = width + 1                                 -- 字符的个数（长度）
    end
    return width
end
function table.indexOf(tb, val)
    for i,v in ipairs(tb) do
        if v == val then
            return i;
        end
    end
    return -1;
end
function table.length(tb)
    local num = 0;
    for k,v in pairs(tb) do
        num = num + 1;
    end
    return num;
end
function checkRequire(name)        
    if rmodules == nil then
        rmodules = {};
    end
    if rmodules[name] == nil then
        local e = loadstring("return "..name..";");
        local b = e();
        if b == nil then
            local f = loadstring("require \""..name.."\"; return "..name..";");
            local c = f();
            rmodules[name] = c;
        else
            rmodules[name] = b;
        end
    end
    return rmodules[name];
end
function getConfig(args)
    local c = checkRequire(args[1]);
    local len = #args;
    for i=2,len do
        if c == nil then
            break;
        end
        c = c[args[i]];
    end
    return c;
end
function getProtoMsg(msgName)
    checkRequire(msgName);
    local f = loadstring("return ProtoPublic_pb."..msgName.."();");
    local c = f();
    return c;
end
function import(moduleName, currentModuleName)
    local currentModuleNameParts
    local moduleFullName = moduleName
    local offset = 1

    while true do
        if string.byte(moduleName, offset) ~= 46 then
            moduleFullName = string.sub(moduleName, offset)
            if currentModuleNameParts and #currentModuleNameParts > 0 then
                moduleFullName = table.concat(currentModuleNameParts, ".") .. "." .. moduleFullName
            end
            break
        end
        offset = offset + 1

        if not currentModuleNameParts then
            if not currentModuleName then
                local n,v = debug.getlocal(3, 1)
                currentModuleName = v
            end

            currentModuleNameParts = string.split(currentModuleName, ".")
        end
        table.remove(currentModuleNameParts, #currentModuleNameParts)
    end

    return require(moduleFullName)
end

--重新require一个lua文件，替代系统文件。
function reimport(name)
    local package = package
    package.loaded[name] = nil
    package.preload[name] = nil
    return require(name)    
end

function showInfo(obj, pre, rs, index)
    rs = rs == nil and {} or rs;
    pre = pre == nil and "" or pre;
    index = index == nil and 0 or index;
    index = index +1;
    if index > 10 then
        return;
    end
    for k,v in pairs(obj) do
        local strType = type(v)
        local kType = type(k)
        if kType == "string" or kType == "number" or kType == "function" then
            rs[pre.."."..k] = strType
            if strType == "table" and v ~= obj and k ~= "loaded" and k ~= "_listener_for_children" then
                showInfo(v, pre.."."..k, rs, index);
            end
        end
    end
    return rs;
end

function saveToFile(objs, path)
    local cOutputHandle = nil
    local cFile = assert(io.open(path, "w"))
    cOutputHandle = cFile
    cOutputEntry = cFile.write
    local cOutputer = function (strContent)
        if cOutputHandle then
            cOutputEntry(cOutputHandle, strContent)
        else
            cOutputEntry(strContent)
        end
    end
    for i, v in pairs(objs) do
        cOutputer(i.."|"..v.."\n")
    end
end

--判断字符长度，1个中文算2个长度，其他1个长度
function strlen(str)
    local bytes = { string.byte(str, 1, #str) }
    local length, begin = 0, false
    for _, byte in ipairs(bytes) do
        if byte < 128 or byte >= 192 then
            begin = false
            length = length + 1
        elseif not begin then
            begin = true
            length = length + 1
        end
    end
    return length
end
--debug 遍历lua数据
function showInfo(obj, pre, rs, index)
    rs = rs == nil and {} or rs;
    pre = pre == nil and "" or pre;
    index = index == nil and 0 or index;
    index = index +1;
    if index > 10 then
        return;
    end
    for k,v in pairs(obj) do
        local strType = type(v)
        local kType = type(k)
        if kType == "string" or kType == "number" or kType == "function" then
            rs[pre.."."..k] = strType
            if strType == "table" and v ~= obj and k ~= "loaded" and k ~= "_listener_for_children" then
                showInfo(v, pre.."."..k, rs, index);
            end
        end
    end
    return rs;
end
--debug 保存文件
function saveToFile(objs, path)
    local cOutputHandle = nil
    local cFile = assert(io.open(path, "w"))
    cOutputHandle = cFile
    cOutputEntry = cFile.write
    local cOutputer = function (strContent)
        if cOutputHandle then
            cOutputEntry(cOutputHandle, strContent)
        else
            cOutputEntry(strContent)
        end
    end
    for i, v in pairs(objs) do
        cOutputer(i.."|"..v.."\n")
    end
end

--debug 保存当前lua数据
function saveDebugLuaDatas()
    local rs = showInfo(_G, "_G");
    saveToFile(rs, "C:/temp/aaa"..math.floor(getTime())..".txt");
end

-- 时间戳转换成日期格式
function unixTimeConvertToDate(unixTime)
    if unixTime ~= nil and unixTime >= 0 then
        local tb = {}
        tb.year = tonumber(os.date("%Y", unixTime));
        tb.month = tonumber(os.date("%m", unixTime));
        tb.day = tonumber(os.date("%d", unixTime));
        tb.hour = tonumber(os.date("%H", unixTime));
        tb.minute = tonumber(os.date("%M", unixTime));
        tb.second = tonumber(os.date("%S", unixTime));
        return tb;
    end
    return nil;
end

function updateRequire(name)
    if rmodules == nil then
        return;
    end

    if rmodules[name] ~= nil then
        rmodules[name] = nil;
        local package = package;
        package.loaded[name] = nil;
        package.preload[name] = nil;
        local f = loadstring("require \""..name.."\"; return "..name..";");
        local c= f();
        rmodules[name] = c;
    end
end

function strIsNullOrEmpty(str)
    if str == nil or str == "" then
        return true;
    end
    return false;
end