Lua_CommonUtil = {};
Lua_CommonUtil.frameList = Array();
Lua_CommonUtil.delayCollectList = Array();
function Lua_CommonUtil.addTimer(funName, interval, tb, fun, param, runTime)
	if fun == nil then
		return true;
	end

	if runTime == nil or runTime <= 0 then
		runTime = -1;
	end

	local arr = Lua_CommonUtil.frameList;
	local len = arr:getSize();
	local t = nil;
	local hasIn = false;
	for i=1,len do
		if (arr[i].table == tb or tb == nil) and arr[i].fun == fun then
			t = arr[i];
			hasIn = true;
			break;
		end
	end
	if t == nil then
		t = {};
	end
	t.name = funName;
	if interval == nil then
		interval = 0.5;
	end
	t.interval = interval;
	t.table = tb;
	t.fun = fun;
	t.param = param;
	t.lastTime = getTime();
	t.runTime = runTime;
	t.isDispose = false;
	if hasIn == false then
		arr:add(t);
	end
	return hasIn;
end

function Lua_CommonUtil.removeTimer(tb, fun)
	local obj;
	local arr = Lua_CommonUtil.frameList;
	local len = arr:getSize();
	for i = 1, len do
		obj = arr[i];
		if (obj.table == tb or tb == nil) and obj.fun == fun then
			obj.isDispose = true;
			obj.table = nil;
			obj.fun = nil;
			obj.param = nil;
			return;
		end
	end

	arr = Lua_CommonUtil.delayCollectList;
	len = arr:getSize();
	for i = 1, len do
		obj = arr[i];
		if (obj.table == tb or tb == nil) and obj.fun == fun then
			obj.isDispose = true;
			obj.table = nil;
			obj.fun = nil;
			obj.param = nil;
			return;
		end
	end
end

function Lua_CommonUtil.clearAllTimer()
	local obj;
	local arr = Lua_CommonUtil.frameList;
	local len = arr:getSize();
	while (len > 0) do
		obj = arr:remove(len);
		obj.table = nil;
		obj.fun = nil;
		obj.param = nil;
		obj = nil;
		len = len - 1;
	end

	arr = Lua_CommonUtil.delayCollectList;
	len = arr:getSize();
	while (len > 0) do
		obj = arr:remove(len);
		obj.table = nil;
		obj.fun = nil;
		obj.param = nil;
		obj = nil;
		len = len - 1;
	end

	arr = nil;
	obj = nil;
	Lua_CommonUtil.frameList:clear();
	Lua_CommonUtil.delayCollectList:clear();
end

function Lua_CommonUtil.delayCall(interval, tb, fun, param)
	Lua_CommonUtil.addTimer("delayCall", interval, tb, fun, param, 1)
end

function Lua_CommonUtil.delayCollectCall(name, tb, fun, param, collectTime)
	local list = Lua_CommonUtil.delayCollectList;
	local len = list:getSize();
	for i=1,len do
		if list[i].name == name then
			list[i].param = param;
			return;
		end
	end

	local t = {};
	t.name = name;
	t.endTime = collectTime + getTime();
	t.table = tb;
	t.fun = fun;
	t.param = param;
	t.isDispose = false;
	list:add(t);
end

function Lua_CommonUtil.frameScript()
	local arr = Lua_CommonUtil.frameList;
	local len = arr:getSize();
	local nt = getTime();
	local obj;
	while (len > 0) do
		obj = arr[len];
		if obj == nil then
			break;
		end
		
		if obj.isDispose == true or obj.table == nil or obj.isDispose_3 == true then
			obj.table = nil;
			obj.fun = nil;
			obj.param = nil;
			arr:remove(len);
		elseif nt - obj.lastTime > obj.interval then
			obj.lastTime = nt;
			obj.fun(obj.table, obj.param);
			if obj.isDispose ~= true and obj.runTime ~= nil and obj.runTime ~= -1 then
				obj.runTime = obj.runTime - 1;
				if obj.runTime <= 0 then
					obj.isDispose = true;
				end
			end

			-- 防止回调移除导致报错
			if obj.isDispose == true then
				obj.table = tb;
				obj.fun = fun;
				obj.param = param;
				arr:remove(len);
			end
		end

		len = len - 1;
	end

	arr = Lua_CommonUtil.delayCollectList;
	len = arr:getSize();
	while (len > 0) do
		obj = arr[len];
		if obj.isDispose == true or obj.table == nil or obj.isDispose_3 == true then
			obj.table = nil;
			obj.fun = nil;
			obj.param = nil;
			arr:remove(len);
		elseif nt > obj.endTime then
			obj.fun(obj.table, obj.param);
			obj.table = nil;
			obj.fun = nil;
			obj.param = nil;
			arr:remove(len);
		end 

		len = len - 1;
	end
end

function Lua_CommonUtil.getCommonConfig(name, gType)
	local config = getConfig({"common", name});
	if config == nil then
		return nil;
	end
	
	if gType == 1 then
		return config.value;
	elseif gType == 2 then
		return config.strValue;
	else
		return config.arr;
	end
end

function Lua_CommonUtil.getNumberTrans(val, limitNum)
	if limitNum == nil then limitNum = 10000 end
	
	val = tonumber(tostring(val));
	val = math.floor(val);
	if val < limitNum then
		return tostring(val);
	end
	if val < 100000000 then
		local v = math.floor(val / 100);
		v = v / 100;
		return v..LanUtil.getValue(152);
	end
	if val < 1000000000000 then
		local v = math.floor(val / 1000000);
		v = v / 100;
		return v..LanUtil.getValue(153);
	end
	if val < 10000000000000000 then
		local v = math.floor(val / 10000000000);
		v = v / 100;
		return v..LanUtil.getValue(155);
	end
	local v = math.floor(val / 100000000000000);
	local v = v / 100;
	return v..LanUtil.getValue(156);
end

function Lua_CommonUtil.transChineseNumber(num)
	if getLanType() ~= 0 and getLanType()~=2 then
		return tostring(math.floor(num));
	end
	num = tonumber(num);
	if num == 0 then
		return LanUtil.getValue(10000);
	end

	if num <= 10 then
		return LanUtil.getValue(num + 100);
	end

	if num < 20 then
		return LanUtil.getValue(110)..LanUtil.getValue(num - 10 + 100);
	end

	if num < 100 then
		local f = math.floor(num / 10);
		local g = num % 10;
		if g == 0 then
			return LanUtil.getValue(f + 100)..LanUtil.getValue(110);
		else
			return LanUtil.getValue(f + 100)..LanUtil.getValue(110)..LanUtil.getValue(g + 100);
		end
	end

	if num < 1000 then
		local b = math.floor(num / 100);
		local s = num-b*100;
		local g = num % 100;
		local z = s % 10;
		if g == 0 then
			return LanUtil.getValue(b + 100)..LanUtil.getValue(150);
		else
			local f = math.floor(s / 10);
			local m = math.floor(s-f*10);
			if z == 0 then
				return LanUtil.getValue(b + 100)..LanUtil.getValue(150)..LanUtil.getValue(f + 100)..LanUtil.getValue(110);
			else
				if s >9 then
					return LanUtil.getValue(b + 100)..LanUtil.getValue(150)..LanUtil.getValue(f + 100)..LanUtil.getValue(110)..LanUtil.getValue(m + 100); 
				elseif s <= 9 then
					m = math.floor(s);
					return LanUtil.getValue(b + 100)..LanUtil.getValue(150)..LanUtil.getValue(10000)..LanUtil.getValue(m + 100);
				end
			end
		end
	end
	return tostring(num);
end

function Lua_CommonUtil.trnsLongNum(val)
	return string.format("%1.0f", val);
end

function Lua_CommonUtil.fixNumerLen(val, len)
	local str = tostring(val);
	while true do
		local l = string.len(str);
		if l >= len then
			break;
		end
		str = "0"..str;
	end
	return str;
end

function Lua_CommonUtil.checkUnitDistance(sx,sy,sz,tx,ty,tz,dis)
	--判断两个点的距离是否在 检测距离之内
	local dx = sx - tx;
	local dy = sy - ty;
	local dz = sz - tz;
	local cDis = dx * dx + dy * dy + dz * dz;
	return dis > cDis and true or false;
end

function Lua_CommonUtil.checkPreloadScene(lv)
	if getShowTips() == false then
		return;
	end
	
	local list = getConfig({"preLoad", "scene"});
	for i,v in ipairs(list) do
		if v[1] == lv then
			PreLoadManager.getInstance():preLoadScene(v[2]);
		end
	end
	list = getConfig({"preLoad", "image"});
	if list ~= nil then
		for i,v in ipairs(list) do
			if v[1] == lv then
				PreLoadManager.getInstance():preLoadImage(v[2]);
			end
		end
	end
	list = getConfig({"preLoad", "effect"});
	if list ~= nil then
		for i,v in ipairs(list) do
			if v[1] == lv then
				PreLoadManager.getInstance():preLoadEffect(v[2]);
			end
		end
	end
end

function Lua_CommonUtil.transMoney(val)
	local str = tostring(val);
	local strList = {};
	local index = 1;
	while true do
		local len = string.len(str);
		if len > 3 then
			strList[index] = string.sub(str, -3, -1);
			str = string.sub(str, 1, -4);
		else
			strList[index] = str;
			break;
		end
		index = index + 1;
	end
	local len = #strList;
	local rs = "";
	for i,v in ipairs(strList) do
		if i ~= 1 then
			rs = v..",".. rs;
		else
			rs = v;
		end
	end
	return rs;
end